@@ -6,17 +6,18 @@
 (library (theme-d testing test-info)
 
   (export nr-of-tests modules no-run
-	  custom1-programs custom2-programs scripts)
+	  custom1-programs custom2-programs scripts
+	  guile-hashtable-units extra-math-units)
 
   (import (guile))
   
-  (define nr-of-tests 738)
+  (define nr-of-tests 764)
 
   (define modules '(2 3 66 75 76 78 82 83 99 106 107 108 139 140
 		      218 221 224 226 247 280 303 312 316 322 323 359 362
 		      364 365 367 369 375 377 384 391 392 394 398 404 405
 		      446 535 537 539 541 553 554 573 603 604 618 630 692
-		      703 732))
+		      703 732 752 754 760))
 
   ;; These tests are interactive so we don't run them here.
   (define no-run '(114 230 271 274 449))
@@ -29,4 +30,8 @@
 
   (define custom2-programs '(279 281 319 320 399 518 561 697 705 712 713))
 
-  (define scripts '(591 597 598 606 607 716 717 720 730)))
+  (define scripts '(591 597 598 606 607 716 717 720 730))
+
+  (define guile-hashtable-units '(390 587 635 738))
+
+  (define extra-math-units '(684 685 686 687)))
