@@ -43,14 +43,6 @@
 (define is-binder? (get-hrecord-type-predicate <binder>))
 
 
-(define gl-empty-binder
-  (make-hrecord <binder> '() '() #f #t #f #f #f #f #f '() '() '() '() '() '()
-		#f #f '() '() '() '() #t '()))
-
-
-(define gl-binder gl-empty-binder)
-
-
 (define (binder-set-cycle! binder repr)
   (hashq-set! (hfield-ref binder 'ht-all-cycles) repr #t))
 
