@@ -26,7 +26,6 @@
 (add-builtin-def! tc-char '<character>)
 (add-builtin-def! tc-symbol '<symbol>)
 (add-builtin-def! tc-string '<string>)
-(add-builtin-def! tc-eof '<eof>)
 
 
 (add-builtin-def! tc-type-variable '<type-variable>)
@@ -70,15 +69,6 @@
 	      '() '()))
 
 
-(add-symbol! global-builtins-symtbl 'eof
-	     (make-target-object
-	      tc-eof
-	      #t #t
-	      (alloc-builtin-loc 'eof)
-	      #f #f
-	      '() '()))
-
-
 (add-symbol! global-builtins-symtbl 'this
 	     to-this)
 
