@@ -32,7 +32,6 @@
 
 
 (define (do-bind-loop bind tvars iter-var subexprs iter-expr)
-  (dwl4 "do-bind-loop")
   (assert (list? tvars))
   (check-bindings tvars)
   (assert (is-t-type-variable? iter-var))
@@ -64,7 +63,6 @@
 (define (handle-splice-expression binder type)
 ;;  (assert (is-binder? binder))
   (assert (is-t-splice? type))
-;;  (assert (not-null? type))
   (let ((component (tno-field-ref type 'type-component)))
     (assert (not-null? component))
     (if (contains-type-modifiers-fwd? component)
@@ -103,7 +101,6 @@
 
 
 (define (construct-type-repr binder type)
-  (dwl4 "construct-type-repr ENTER")
   (assert (is-binder? binder))
   (assert (is-target-object? type))
   (let ((result
@@ -127,7 +124,6 @@
 
 
 (define (construct-normal-type-list-repr lst)
-  (dwl4 "construct-normal-type-list-repr")
   (strong-assert (not (or-map? is-t-rest? lst)))
   ;; Checking is-type-list? is not needed if we trust that
   ;; type lists are properly simplified before calling this
@@ -142,7 +138,6 @@
   ;; 			      (is-tuple-type-fwd?
   ;; 			       (hfield-ref item 'component-type)))))))
   ;; 		lst)
-  (dwl4 "construct-normal-type-list-repr/1")
   (cond
    ((and-map? (lambda (item)
 		(not (and
@@ -151,8 +146,6 @@
 		       (is-tuple-type0-fwd?
 			(tno-field-ref item 'type-component))))))
 	      lst)
-    (dwl4 "construct-normal-type-list-repr/2")
-    (dvar1-set! lst)
     (let* ((lst2
 	    (apply append
 		   (map (lambda (item)
@@ -171,38 +164,24 @@
 	    (if (contains-type-modifiers-fwd? lst2)
 		(make-type-list-object lst2)
 		(apply make-tuple-type-fwd lst2))))
-      (dwl4 "construct-normal-type-list-repr EXIT 1")
       result))
    ;; We should also handle the situation where there are expressions
    ;; before the splice expression in the argument list.
    ((and (= (length lst) 1)
 	 (is-t-splice? (car lst)))
-    ;;	 (hrecord-is-instance? 
-    ;;	  (hfield-ref (car lst) 'component-type)
-    ;;	  <expr-uniform-list-type>))
-;;    (tno-field-ref (car lst) 'component))
-    (dwl4 "construct-normal-type-list-repr/3")
-    ;; (if (or (contains-type-modifiers-fwd? (car lst))
-    ;; 	    (is-t-type-variable? (car lst)))
-    ;; 	(apply make-tuple-type-fwd lst)
-    ;; 	(tno-field-ref (car lst) 'component)))
-;;    (handle-splice-expression binder (car lst)))
     (tno-field-ref (car lst) 'type-component))
    (else
     (let ((result (make-type-list-object lst)))
-      (dwl4 "construct-normal-type-list-repr EXIT 2")
       result))))
 
 
 (define (do-construct-type-list-repr binder types)
-  (dwl4 "do-construct-type-list-repr ENTER")
   (let ((result
 	 (cond
 	  ((null? types) tc-nil)
 	  ((and
 	    (is-t-rest? (last types))
 	    (> (length types) 1))
-	   (dwl4 "do-construct-type-list-repr/1")
 	   (let ((tuple-types (drop-right types 1))
 		 (tail-type (tno-field-ref (last types) 'type-component)))
 	     (translate-tuple-type-with-tail-fwd
@@ -214,7 +193,6 @@
 	    (tno-field-ref (last types) 'type-component)))
 	  (else
 	   (construct-normal-type-list-repr types)))))
-    (dwl4 "do-construct-type-list-repr EXIT")
     result))
     
 
@@ -225,10 +203,8 @@
 
 
 (define (construct-type-loop-repr binder type)
-  (dwl4 "construct-type-loop-repr")
   (assert (is-binder? binder))
   (assert (is-t-type-loop? type))
-  (dvar1-set! type)
   (let* ((subtype-list0 (tno-field-ref type 'x-subtypes))
 	 (subtype-list
 	  (if (or (list? subtype-list0)
@@ -271,17 +247,8 @@
 
 
 (define (construct-type-join-repr binder type)
-  (dwl4 "construct-type-join-repr")
   (assert (is-binder? binder))
-  (dwl4 "construct-type-join-repr/1")
   (assert (is-t-type-join? type))
-  (dwl4 "construct-type-join-repr/2")
-  (dvar1-set! binder)
-  (dvar2-set! type)
-
-  ;; TO BE REMOVED
-;;  (raise 'j-stop)
-
   (let ((subtypes (tno-field-ref type 'l-subtypes)))
     (if (or
 	 (is-t-type-variable? subtypes)
@@ -290,14 +257,12 @@
 	      (is-t-type-variable? (tno-field-ref (car subtypes)
 						  'type-component))))
 	(begin
-	  (dwl4 "construct-type-join-repr/3")
 	  type)
 	(let ((subexprs1 (map 
 			  (lambda (cur-expr)
 			    (handle-tuples
 			     (construct-type-repr binder cur-expr)))
 			  subtypes)))
-	  (dwl4 "construct-type-join-repr/4")
 	  (if (and-map? list? subexprs1)
 	      (let ((subexprs2 (apply append subexprs1)))
 		(strong-assert (and-map? is-tuple-type0-fwd? subexprs2))
@@ -339,10 +304,6 @@
   (assert (procedure? alloc-var))
   (assert (symbol? name))
   (assert (is-target-object? type))
-  (dvar1-set! binder)
-  (dvar2-set! alloc-var)
-  (dvar3-set! name)
-  (dvar4-set! type)
   (let* ((exact-type? (and 
 		       (not (is-t-type-variable? type))
 		       (is-t-instance? binder type tc-class)
@@ -360,15 +321,12 @@
 
 
 (define (make-argument-bindings binder alloc-var names types)
-  (dwl4 "make-argument-bindings")
   (assert (is-binder? binder))
   (assert (procedure? alloc-var))
   (assert (list? names))
   (assert (and-map? symbol? names))
   (assert (list? types))
   (assert (and-map? is-target-object? types))
-;;  (dvar1-set! names)
-;;  (dvar2-set! types)
   (if (= (length names) (length types))
       (map (lambda (name type)
 	     (make-argument-binding binder alloc-var name type))
@@ -377,9 +335,6 @@
 
 
 (define (check-procedure-result-type? binder t-computed t-declared)
-  (dwl4 "check-procedure-result-type?")
-  (dvar1-set! t-computed)
-  (dvar2-set! t-declared)
   (assert (is-binder? binder))
   (assert (is-target-object? t-declared))
   (assert (is-target-object? t-computed))
@@ -391,12 +346,6 @@
 
 
 (define (generic-find-decl binder generic method-type)
-  (dwl4 "generic-find-decl")
-
-  ;; TBR
-  (dwl4 (tno-field-ref generic 'str-name))
-
-  (dvar1-set! generic)
   (assert (is-binder? binder))
   (assert (is-t-gen-proc? generic))
   (assert (is-target-object? method-type))
@@ -405,12 +354,12 @@
     (do ((cur-methods methods (cdr cur-methods)))
 	((or (null? cur-methods) (not-null? decl)) decl)
       (let* ((cur-method (car cur-methods))
-	     (cur-method-type (get-entity-type cur-method)))
-	(if (hfield-ref cur-method 'incomplete?)
+	     (cur-method1 (car cur-method))
+	     (cur-method-type (get-entity-type cur-method1)))
+	(if (hfield-ref cur-method1 'incomplete?)
 	    ;; is-t-subtype? would not work here
 	    (if (equal-types? binder method-type cur-method-type)
 		(begin
-		  (dwl4 "generic-find-decl/6")
 		  (set! decl cur-method))))))))
 
 
@@ -422,26 +371,28 @@
 
 
 (define (update-generic! binder generic new-methods)
-  (let* ((new-method-classes (map get-entity-type new-methods))
+  (let* ((new-method-classes
+	  (map (lambda (p-method)
+		 (assert (pair? p-method))
+		 (get-entity-type (car p-method)))
+	       new-methods))
 	 (new-class (make-gen-proc-class-object new-method-classes)))
     (hfield-set! generic 'type new-class)
     (tno-field-set! generic 'l-methods new-methods)))
 
 
-(define (add-new-method-to-generic! binder to-generic to-method)
-  (dwl4 "add-new-method-to-generic!")
+(define (add-new-method-to-generic! binder to-generic to-method static?)
   (assert (is-binder? binder))
   (assert (is-target-object? to-generic))
   (assert (is-target-object? to-method))
   (assert (eq? (get-object-type (get-object-type to-generic))
 	       tmc-gen-proc))
   (let* ((old-methods (tno-field-ref to-generic 'l-methods))
-	 (new-methods (cons to-method old-methods)))
+	 (new-methods (cons (cons to-method static?) old-methods)))
     (update-generic! binder to-generic new-methods)))
 
 
-(define (define-declared-method! binder generic decl method)
-  (dwl4 "define-declared-method!")
+(define (define-declared-method! binder generic decl method static?)
   (assert (is-binder? binder))
   (assert (is-target-object? generic))
   (assert (is-target-object? method))
@@ -449,52 +400,51 @@
 	       (eq? (get-object-type
 		     (get-object-type generic))
 		    tmc-gen-proc)))
+  (assert (boolean? static?))
+  (strong-assert (eq? static? (cdr decl)))
   (let* ((old-methods (tno-field-ref generic 'l-methods))
 	 (methods0 (remove-list-element old-methods decl))
-	 (new-methods (cons method methods0)))
+	 (new-methods (cons (cons method static?) methods0)))
     (update-generic! binder generic new-methods)))
 
 
-(define (add-method-to-generic! binder generic method)
-  (dwl4 "add-method-to-generic!")
+(define (add-method-to-generic! binder generic method static?)
   (assert (is-binder? binder))
   (assert (is-target-object? generic))
   (assert (is-target-object? method))
   (assert (and (eq? (get-entity-type
 		     (get-entity-type generic))
 		    tmc-gen-proc)))
-  (dwl4 "add-method-to-generic!/1")
-  (dvar1-set! to)
+  (assert (boolean? static?))
   (let ((decl (generic-find-decl binder
 				 generic
 				 (get-entity-type method))))
-    (dwl4 "add-method-to-generic!/2")
     (if (null? decl)
 	(begin
-	  (add-new-method-to-generic! binder generic method)
+	  (add-new-method-to-generic! binder generic method static?)
 	  method)
 	(begin
-	  (set-object! decl method)
-	  (define-declared-method! binder generic decl method)
-	  decl))))
+	  (set-object! (car decl) method)
+	  (define-declared-method! binder generic decl method static?)
+	  (car decl)))))
 
 
-(define (add-method-to-generic2! binder generic decl method)
-  (dwl2 "add-method-to-generic2!")
+(define (add-method-to-generic2! binder generic decl method static?)
   (assert (is-binder? binder))
   (assert (is-target-object? generic))
-  (assert (or (null? decl) (is-target-object? decl)))
+  (assert (or (null? decl)
+	      (and (pair? decl)
+		   (is-target-object? (car decl))
+		   (boolean? (cdr decl)))))
   (assert (is-target-object? method))
   (if (null? decl)
       (begin
-	(dwl2 "add-method-to-generic2!/1")
-	(add-new-method-to-generic! binder generic method)
+	(add-new-method-to-generic! binder generic method static?)
 	method)
       (begin
-	(dwl2 "add-method-to-generic2!/2")
-	(set-object1! decl method)
-	(define-declared-method! binder generic decl method)
-	decl)))
+	(set-object1! (car decl) method)
+	(define-declared-method! binder generic decl method static?)
+	(car decl))))
 
 
 (define (get-method-declaration address t-method-type)
