@@ -29,16 +29,6 @@
       (let ((ht-source-exprs (hfield-ref gl-expander 'ht-source-exprs)))
 	(if (not-null? ht-source-exprs)
 	    (let ((sexpr1 (hashq-ref ht-source-exprs sexpr)))
-	      
-	      ;; TBR
-	      ;; (display "get-source-expr\n")
-	      ;; (display sexpr)
-	      ;; (newline)
-	      ;; (display sexpr1)
-	      ;; (newline)
-	      ;; (display (eq? sexpr gl-x1))
-	      ;; (newline)
-
 	      (if sexpr1 sexpr1 sexpr))
 	    sexpr))))
 
@@ -252,6 +242,18 @@
 			   (string-append "  " (symbol->string x) "\n")
 			   "  ?\n"))
 		     l-undefined)))))))
+       ((eq? x-head 'illegal-incomplete-value)
+	(let ((s-name (cdr (assq 's-name (cdr exc)))))
+	  (string-append
+	   "Illegal reference to an incomplete constant in the definition of "
+	   "variable "
+	   (symbol->string s-name))))
+       ((eq? x-head 'illegal-incomplete-ref)
+	(let ((s-name (cdr (assq 's-name (cdr exc)))))
+	  (string-append
+	   "Illegal reference to an incomplete variable in the definition of "
+	   "variable "
+	   (symbol->string s-name))))
        (else
 	(if (= (length exc) 1)
 	    (if (symbol? x-head)
