@@ -34,16 +34,11 @@
 
 ;; Optimizes the expression in case there are 0 or 1 subexpressions.
 (define (make-compound-expression subexprs)
-  (dwl2 "make-compound-expression ENTER")
   (let ((len (length subexprs)))
     (cond
      ((= len 0)
-      (dwl2 "make-compound-expression EXIT 1")
-      (dwl2 (unspecified? empty-expression))
       empty-expression)
      ((= len 1)
-      (dwl2 "make-compound-expression EXIT 2")
-      (dwl2 (unspecified? (car subexprs)))
       (car subexprs))
      (else
       (let* ((last-expr (last subexprs))
@@ -59,7 +54,6 @@
 	      (and-map? entity-always-returns? subexprs))
 	     (never-returns?
 	      (or-map? entity-never-returns? subexprs)))
-	(dwl2 "make-compound-expression EXIT 3")
 	(make-hrecord
 	 <compound-expression>
 	 last-type
@@ -76,13 +70,11 @@
 
 
 (define (do-wrap-compound-expression s-subexprs translate)
-  (dwl2 "do-wrap-compound-expression ENTER")
   (assert (list? s-subexprs))
   (assert (procedure? translate))
   (let* ((t-subexprs (map* translate s-subexprs))
 	 (result
 	  (make-compound-expression t-subexprs)))
-    (dwl2 "do-wrap-compound-expression EXIT")
     result))
 
 
@@ -118,15 +110,12 @@
 
 (define (bind-variable-with-object! compiler symtbl rebind? read-only? s-name
 				    type value)
-  (dwl3 "bind-variable-with-object!")
-  (dwl3 s-name)
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (boolean? rebind?))
   (assert (symbol? s-name))
   (assert (hrecord-is-instance? type <target-object>))
   (assert (or (null? value) (hrecord-is-instance? value <target-object>)))
-  (dwl3 "bind-variable-with-object!/1")
   (if rebind?
       (let ((variable (get-symbol symtbl s-name))
 	    (binder (compiler-get-binder compiler)))
@@ -144,6 +133,7 @@
 	       (is-t-subtype? binder type old-type)
 	       (= (length (tno-field-ref type 'l-all-fields))
 		  (length (tno-field-ref old-type 'l-all-fields))))
+	      ;; TBR: tmp1 setting
 	      (let* ((tmp1 (begin (dvar1-set! variable)
 				  (dwl3 "bind-variable-with-object!/4") 0))
 		     (old-value (hfield-ref variable 'value))
@@ -184,14 +174,11 @@
 	       value
 	       #f)))
 	(add-symbol! symtbl s-name variable)
-	(dwl3 "bind-variable-with-object! EXIT")
 	variable)))
 
 
 (define (translate-define-gen-proc compiler symtbl name)
-  (dwl4 "translate-define-gen-proc")
   (assert (symbol? name))
-  (dwl4 name)
   (let* ((address (compiler-alloc-loc compiler name #t))
 	 (var (make-new-gen-proc address #f))
 	 (to (make-object-with-address (hfield-ref var 'value) address)))
@@ -225,18 +212,12 @@
 
 (define (translate-forward-declaration compiler symtbl var-name r-type
 				       read-only? volatile?)
-  (dwl2 "translate-forward-declaration ENTER")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (symbol? var-name))
   (assert (is-target-object? r-type))
   (assert (boolean? read-only?))
   (assert (boolean? volatile?))
-
-  ;; TO BE REMOVED
-  (set! gl-ctr10 (+ gl-ctr10 1))
-  (dwl2 gl-ctr10)
-  
   (let ((binder (compiler-get-binder compiler)))
     (cond
      ((not (symbol? var-name))
@@ -329,7 +310,6 @@
 		     #f
 		     #f)))
 		 (else
-		  (dwl4 "translate-forward-declaration/1")
 		  (strong-assert (is-normal-variable? old-ent))
 		  (let* ((address (hfield-ref old-ent 'address))
 			 (var
@@ -377,7 +357,6 @@
 	     (var (make-normal-variable4 address r-type #f
 					 read-only? volatile?
 					 #t to #f)))		  
-	  (dwl4 "translate-forward-declaration/1")
 	  (if read-only?
 	      (begin
 		(add-symbol! symtbl var-name to)
@@ -385,7 +364,6 @@
 	      (begin
 		(add-symbol! symtbl var-name var)
 		(add-public-decl! compiler var)))
-	  (dwl4 "translate-forward-declaration EXIT")
 	  (make-hrecord
 	   <forward-declaration>
 	   tt-none
@@ -470,7 +448,8 @@
 		 (and (member? gl-never-returns attr-lst)
 		      (not (member? gl-always-returns attr-lst))
 		      (not (member? gl-may-return attr-lst))))
-		(static-method? (member? gl-static-method attr-lst)))
+		;; (static-method? (member? gl-static-method attr-lst)))
+		(static-method? #f))
 	    (if (or
 		 (and (not pure?) force-pure?)
 		 (and always-returns? never-returns?))
@@ -537,3 +516,34 @@
 
 (define (check-toplevel toplevel?)
   (if (not toplevel?) (raise 'illegal-toplevel-form)))
+
+
+(define (is-legal-value0? compiler address)
+  (or
+   (null? address)
+   (and (memq (hfield-ref compiler 'unit-type)
+	      '(proper-program script))
+	(let ((module (hfield-ref address 'module)))
+	  (and (not-null? module)
+	       (not (equal?
+		     module
+		     (hfield-ref compiler 'toplevel-unit-name))))))
+   (let ((module (hfield-ref address 'module)))
+     (and (not-null? module)
+	  (member? module
+		   (hfield-ref compiler 'l-prelinked-bodies))))))
+
+
+(define (is-legal-value-object? compiler x)
+  (if (and (is-target-object? x) (hfield-ref x 'incomplete?))
+      (is-legal-value0? compiler (hfield-ref x 'address))
+      #t))
+
+   
+(define (is-legal-value-ref? compiler x)
+  (if (hrecord-is-instance? x <variable-reference>)
+      (let ((var (hfield-ref x 'variable)))
+	(if (hfield-ref var 'forward-decl?)
+	    (is-legal-value0? compiler (hfield-ref var 'address))
+	    #t))
+      #t))
