@@ -25,10 +25,9 @@
 	(begin
 	  (cond
 	   ((hrecord-is-instance? location <keyword>)
-	    (begin (dwl4 "*2*") location))
+	    location)
 	   ((hrecord-is-instance? location <normal-variable>)
 	    (begin
-	      (dwl4 "*3*")
 	      (if (not (check-normal-variable? location))
 		  (begin
 		    (dvar1-set! location)
@@ -48,7 +47,6 @@
 	    location)
 	   (else
 	    (begin
-	      (dwl4 "*5*")
 	      (raise 'internal-invalid-binding)))))
         (begin
 	  (set-error-info! compiler expr)
@@ -56,15 +54,13 @@
 
 
 (define (translate-atom compiler symtbl toplevel? quoted? sexpr)
-  (dwl4 "translate-atom")
   (if (and (not quoted?) (symbol? sexpr))
-      (begin (dwl4 "*1*") (translate-location compiler symtbl sexpr))
+      (begin (translate-location compiler symtbl sexpr))
       (let* ((type (get-primitive-type sexpr))
 	     ;; Should type be an expression or a variable in the following?
 	     (to (make-primitive-object
 		  type
 		  sexpr)))
-	(dwl4 "translate-atom EXIT")
 	to)))
 
 
@@ -82,7 +78,6 @@
       (raise 'internal-error)
       (let ((proc (hrecord-type-inquire
 		   xlat-table (hrecord-type-of expr-head))))
-	(dwl4 "translate-list-expr/1")
 	(if (not (eq? (hrecord-type-of expr-head) <keyword-quote>))
 	    (begin
 	      (if (not (list? expr-tail))
@@ -93,7 +88,6 @@
 		   (proc compiler symtbl toplevel? expr-head expr-tail)
 		   (xlat-default-fwd compiler symtbl toplevel?
 				     expr-head expr-tail))))
-	  (dwl4 "translate-list-expr exit")
 	  result))))
 
 
@@ -101,8 +95,6 @@
 ;; If the expression is a list translate the head
 ;; and call translate-expr recursively (dispatch used).
 (define (translate-expr compiler symtbl toplevel? expr)
-  (dwl3 "translate-expr")
-  (dwl3 expr)
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (boolean? toplevel?))
@@ -125,12 +117,10 @@
 	       (hfield-set! compiler 'current-expr prev-expr)
 	       res2)))
 	  ((source-code-element? expr)
-	   (dwl3 "HEP2")	   
 	   (translate-atom compiler symtbl #f #f expr))
 	  (else
 	   (dvar1-set! expr)
 	   (raise 'invalid-dispatch)))))
-    (dwl3 "translate-expr exit")
     result))
 
 
@@ -138,7 +128,6 @@
 
 
 (define (wrap-compound-expression compiler env s-subexprs)
-  (dwl2 "wrap-compound-expression")
   (assert (list? s-subexprs))
   (assert (hrecord-is-instance? env <environment>))
   (do-wrap-compound-expression
@@ -149,13 +138,11 @@
 
 (define (translate-define-mutable-expression
          compiler symtbl toplevel? expr-tail volatile?)
-  (dwl3 "translate-define-mutable-expression ENTER")
   (if (not (= (length expr-tail) 3))
       (raise 'invalid-define-mutable-expr)
       (let ((s-name (car expr-tail))
             (s-type (cadr expr-tail))
             (s-value (caddr expr-tail)))
-	(dwl3 "translate-define-mutable-expression/1")
         (if (not (s-symbol? s-name))
             (raise 'invalid-variable-name)
 	    (begin
@@ -164,7 +151,10 @@
 		     (translate-expr compiler symtbl #f s-type))
 		    (value-expr 
 		     (translate-expr compiler symtbl #f s-value)))
-		(dwl3 "translate-define-mutable-expression/2")
+		(if (not (is-legal-value-ref? compiler value-expr))
+		    (raise (list 'illegal-incomplete-ref
+				 (cons 's-name s-name)
+				 (cons 'address '()))))
 		(if (is-known-object? type)
 		    (let* ((bound-value (get-symbol symtbl s-name))
 			   (rebind? (check-existing-binding? compiler
@@ -175,7 +165,6 @@
 					 #f
 					 (get-entity-type bound-value)))
 			   (binder (compiler-get-binder compiler)))
-		      (dwl3 "translate-define-mutable-expression/4")
 		      (cond
 		       ((and rebind? (is-target-object? bound-value))
 			(raise 'definition-mutability-mismatch))
@@ -197,9 +186,6 @@
 				     (cons 'tt-new type)
 				     (cons 'tt-old old-type))))
 		       (else
-			(dwl3 "translate-define-mutable-expression/5")
-			;; (set! gl-debug1 bound-value)
-			;; (raise 'stop1)
 			(let* ((variable
 				(if (not (eq? bound-value #f))
 				    (begin
@@ -217,10 +203,6 @@
 				       volatile?
 				       #f #f '() '()
 				       #f #f))))
-			       (tmp1
-				(begin
-				  (dwl3 "translate-define-mutable-expression/6")
-				  0))
 			       (result
 				(make-normal-var-def
 				 type
@@ -230,14 +212,11 @@
 			  (if (not rebind?)
 			      (add-symbol! symtbl s-name variable))
 			  (hfield-set! compiler 's-cur-toplevel-def '())
-			  (dwl3 "translate-define-mutable-expression EXIT")
 			  result))))
 		    (raise 'define-mutable:invalid-type))))))))
 
 
 (define (translate-define-expression compiler symtbl toplevel? expr-tail)
-  (dwl2 "translate-define-expression ENTER")
-  (dwl2 (car expr-tail))
   (let ((arg-count (length expr-tail)))
     (if (not (or (= arg-count 2) (= arg-count 3)))
 	(raise 'invalid-define)
@@ -246,7 +225,6 @@
 	       (s-type (if has-type-spec? (cadr expr-tail) '()))
 	       (s-value (if has-type-spec? (caddr expr-tail) (cadr expr-tail)))
 	       (binder (compiler-get-binder compiler)))
-	  (dwl2 "translate-define-expression/1")
 	  (if (not (s-symbol? s-name))
 	      (raise 'invalid-variable-name)
 	      (begin
@@ -326,6 +304,16 @@
 			     #f
 			     to2
 			     #f)))
+		      (if (and
+			   rebind?
+			   (not (is-legal-value-object? compiler to-new)))
+			  (raise (list 'illegal-incomplete-value
+				       (cons 's-name s-name)
+				       (cons 'address address))))
+		      (if (not (is-legal-value-ref? compiler value-expr))
+			  (raise (list 'illegal-incomplete-ref
+				       (cons 's-name s-name)
+				       (cons 'address address))))
 		      ;; We bind the variable name to an object.
 		      (if (not rebind?)
 			  (add-symbol! symtbl s-name to-new)
@@ -335,36 +323,26 @@
 			    ;; expression is a declared value.
 			    (hfield-set! bound-value 'incomplete? #f)))
 		      (hfield-set! compiler 's-cur-toplevel-def '())
-		      (dwl2 "translate-define-expression EXIT")
 		      (make-normal-var-def
 		       tt-declared variable value-expr rebind?)))))))))))
 
 
 (define (translate-constructor-expr compiler symtbl to-class)
-  (dwl1 "translate-constructor-expr")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (is-target-object? to-class))
   (let ((binder (compiler-get-binder compiler)))
-    (dwl1 "translate-constructor-expr/1")
-    (dvar1-set! to-class)
     (cond
      ((is-t-apti? to-class)
-      (dwl1 "translate-constructor-expr/2")
       (if (hfield-ref compiler 'inside-param-def?)
 	  (get-empty-constructor to-class)
 	  (raise 'illegal-abstract-class-for-constructor)))
      ((not (is-known-object? to-class))
-      (dwl1 "translate-constructor-expr/3")
       (raise 'illegal-class-for-constructor))
      ((and (not (hfield-ref compiler 'inside-param-def?))
 	   (not (is-t-instance? binder to-class tc-class)))
-      (dwl1 "translate-constructor-expr/4")
-      (dvar1-set! compiler)
-      (dvar2-set! symtbl)
       (raise 'constructor-not-a-class))
      ((is-t-type-variable? to-class)
-      (dwl1 "translate-constructor-expr/5")
       (make-hrecord <expr-constructor>
 		    tt-general-proc-with-value
 		    #f
@@ -376,7 +354,6 @@
 		    '()
 		    to-class))
      ((is-t-instance? binder to-class tpc-pair)
-      (dwl1 "translate-constructor-expr/6")
       (let ((type (translate-simple-proc-class-expression
 		   binder
 		   (tno-field-ref to-class 'l-tvar-values)
@@ -392,7 +369,6 @@
 		      '()
 		      to-class)))
      (else
-      (dwl1 "translate-constructor-expr/7")
       (let ((type-constructor
 	     (tno-field-ref to-class 'type-constructor))
 	    (access
@@ -480,21 +456,16 @@
 
 
 (define (translate-field compiler env s-field)
-  (dwl4 "translate-field")
   (if (pair? s-field)
       (let ((len (length s-field)))
-	(dwl4 "translate-field/1")
 	(if (or (= len 4) (= len 5))
 	    (let* ((field-name 
 		    (car s-field))
-		   (tmp1 (begin (dwl4 "translate-field/1-1") 0))
 		   (r-field-type
 		    (translate-expr compiler env #f 
 				    (cadr s-field)))
-		   (tmp2 (begin (dwl4 "translate-field/1-2") 0))
 		   (r-read-access (list-ref s-field 2))
 		   (r-write-access (list-ref s-field 3))
-		   (tmp3 (begin (dwl4 "translate-field/1-3") 0))
 		   (has-init-value? (= len 5))
 		   (r-init-value
 		    (if has-init-value?
@@ -534,14 +505,12 @@
 
 
 (define (translate-field-list compiler s-field-list env)
-  (dwl4 "translate-field-list")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (list? s-field-list))
   (assert (hrecord-is-instance? env <environment>))
   (let ((result
 	 (map (lambda (s-field) (translate-field compiler env s-field))
 	      s-field-list)))
-    (dwl4 "translate-field-list EXIT")
     result))
 
 
@@ -549,7 +518,6 @@
 			    r-superclass t-field-list
 			    inheritable? immutable? eq-by-value?
 			    ctr-access)
-  (dwl4 "do-translate-class")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <environment>))
   (assert (symbol? s-name))
@@ -572,8 +540,6 @@
 	  (bind-object! compiler env s-name decl to tc-class))
 	 (binder (compiler-get-binder compiler)))
     (make-constructor! binder decl)
-    (dwl4 "do-translate-class/1")
-    (dwl4 s-name)
     (make-hrecord <class-definition>
 		  tt-none #t #t '()
 		  #f #f #f '()
@@ -581,11 +547,9 @@
 
 
 (define (translate-define-class compiler symtbl expr-tail)
-  (dwl4 "translate-define-class")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (list? expr-tail))
-  (dwl4 "translate-define-class/1")
   (if (= (length expr-tail) 8)
       (let ((s-name (car expr-tail))
 	    (s-superclass (cadr expr-tail))
@@ -595,7 +559,6 @@
 	    (ctr-access (list-ref expr-tail 5))
 	    (s-zero-proc (list-ref expr-tail 6))
 	    (s-field-list (list-ref expr-tail 7)))
-	(dwl4 "translate-define-class/2")
 	(if (or
 	     (not (boolean? inheritable?))
 	     (not (boolean? immutable?))
@@ -617,18 +580,15 @@
 		      (assert (not (eq? bound-value #f)))
 		      (get-entity-value bound-value))
 		    (hfield-ref (hfield-ref decl 'variable) 'value))))
-	  (dwl4 "translate-define-class/3")
 	  (let* ((to-superclass
 		  (translate-expr compiler symtbl #f s-superclass))
 		 (binder (compiler-get-binder compiler)))
-	    (dwl4 "translate-define-class/4")
 	    (if (not
 		 (and (is-target-object? to-superclass)
 		      (is-t-instance? binder to-superclass tc-class)))
 		(raise 'invalid-superclass))
 	    (let ((t-field-list (translate-field-list compiler s-field-list
 						      symtbl)))
-	      (dwl4 "translate-define-class/5")
 	      (cond
 	       ((entity-is-none1? (compiler-get-binder compiler)
 				  to-superclass)
@@ -659,13 +619,6 @@
 		      (raise 'invalid-immutable-class))
 		  (if (not (is-null-sexpr? s-zero-proc))
 		      (begin
-
-			;; TBR
-			;; (dwl4 "zero HEP")
-			;; (dvar1-set! var)
-			;; (dvar2-set! to-clas)
-			;; (raise 'stop-zero)
-
 			(let* ((zero-proc-body
 				(translate-expr compiler symtbl #f s-zero-proc))
 			       (zero-proc-class
@@ -722,33 +675,19 @@
 					s-attr
 					s-body
 					s-kind s-name)
-  (dwl3 "translate-procedure-expression")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <environment>))
   (strong-assert (list? s-arglist))
   (strong-assert (list? s-body))
   (check-env env)
-  (dwl3 "translate-procedure-expression/1")
-
-  ;; TBR
-  ;; (if gl-flag6?
-  ;;     (begin
-  ;; 	(dvar1-set! s-arglist)
-  ;; 	(dvar2-set! env)
-  ;; 	(raise 'stop6)))
-
   (let* ((names (map car s-arglist))
 	 (s-arg-descs (map cadr s-arglist))
 	 (arg-descs
 	  (map (lambda (subexpr)
 		 (translate-expr compiler env #f subexpr))
 	       s-arg-descs))
-	 (tmp1 (begin (dwl3 "translate-procedure-expression/2") 0))
 	 (binder (compiler-get-binder compiler))
 	 (impl-arg-types (get-impl-arg-types binder arg-descs)))
-    (dvar1-set! arg-descs)
-    (dvar2-set! impl-arg-types)
-    (dwl3 "translate-procedure-expression/4")
     (let* ((alloc-var (lambda (name toplevel?)
 			(compiler-alloc-loc compiler name toplevel?)))
 	   (arg-bindings
@@ -766,7 +705,6 @@
 	   (appl-always-returns? (hfield-ref attr 'always-returns?))
 	   (appl-never-returns? (hfield-ref attr 'never-returns?))
 	   (static-method? (hfield-ref attr 'static-method?))
-	   (tmp1 (begin (dwl3 "translate-procedure-expression/4-1") 0))
 	   (proc-type (translate-simple-proc-class-expression
 		       binder
 		       arg-descs t-result-type
@@ -774,35 +712,27 @@
 		       appl-always-returns?
 		       appl-never-returns?
 		       static-method?))
-	   (tmp1 (begin (dwl3 "translate-procedure-expression/4-2") 0))
 	   (env-with-args
 	    (if pure-proc?
 		(make-pure-proc-env
 		 env arg-bindings)
 		(make-environment
 		 env arg-bindings))))
-      (dwl3 "translate-procedure-expression/4-3")
       (let* ((cur-letrec-env (hfield-ref compiler
 					 'current-letrec-env))
 	     (old-inside-proc?
 	      (if (null? cur-letrec-env)
 		  #f
 		  (hfield-ref cur-letrec-env 'inside-proc?))))
-	(dwl3 "translate-procedure-expression/4-4")
 	(if (not-null? cur-letrec-env)
 	    (hfield-set! cur-letrec-env 'inside-proc? #t))
-	(dwl2 "translate-procedure-expression/4-5")
 	(let ((t-body
 	       (wrap-compound-expression compiler env-with-args
 					 s-body))
 	      (inside-param-def? (hfield-ref compiler 'inside-param-def?)))
-	  (dwl2 "translate-procedure-expression/4-6")
-	  (dwl2 s-body)
-	  (dwl2 (unspecified? t-body))
 	  (if (not-null? cur-letrec-env)
 	      (hfield-set! cur-letrec-env 'inside-proc?
 			   old-inside-proc?))
-	  (dwl3 "translate-procedure-expression/5")
 	  ;; If purity specifier is gl-force-pure
 	  ;; the procedure body is allowed to be nonpure.
 	  (cond
@@ -821,12 +751,8 @@
 		 (not (entity-never-returns? t-body)))
 	    (raise 'proc-attribute-mismatch))
 	   (else
-	    (dwl2 "translate-procedure-expression/6-0")
-	    (dwl2 s-body)
-	    (dwl2 (unspecified? t-body))
 	    (let ((body-never-returns?
 		   (entity-never-returns? t-body)))
-	      (dwl2 "translate-procedure-expression/6")
 	      (if (and (not (hfield-ref compiler 'inside-param-def?))
 		       (not body-never-returns?)
 		       (not (check-procedure-result-type?
@@ -846,7 +772,6 @@
 			(need-revision?
 			 (hfield-ref compiler
 				     'inside-param-def?)))
-		    (dwl3 "translate-procedure-expression/7")
 		    (make-hrecord <procedure-expression>
 				  proc-type #t #t '()
 				  #t #t need-revision? to
@@ -870,33 +795,19 @@
 					    s-attr
 					    s-body
 					    s-kind s-name)
-  (dwl3 "translate-procedure-expression-aut")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <environment>))
   (strong-assert (list? s-arglist))
   (strong-assert (list? s-body))
   (check-env env)
-  (dwl3 "translate-procedure-expression-aut/1")
-
-  ;; TBR
-  ;; (if gl-flag6?
-  ;;     (begin
-  ;; 	(dvar1-set! s-arglist)
-  ;; 	(dvar2-set! env)
-  ;; 	(raise 'stop6)))
-
   (let* ((names (map car s-arglist))
 	 (s-arg-descs (map cadr s-arglist))
 	 (arg-descs
 	  (map (lambda (subexpr)
 		 (translate-expr compiler env #f subexpr))
 	       s-arg-descs))
-	 (tmp1 (begin (dwl3 "translate-procedure-expression-aut/2") 0))
 	 (binder (compiler-get-binder compiler))
 	 (impl-arg-types (get-impl-arg-types binder arg-descs)))
-    (dvar1-set! arg-descs)
-    (dvar2-set! impl-arg-types)
-    (dwl3 "translate-procedure-expression-aut/4")
     (let* ((alloc-var (lambda (name toplevel?)
 			(compiler-alloc-loc compiler name toplevel?)))
 	   (arg-bindings
@@ -909,24 +820,20 @@
 	   (appl-always-returns? (hfield-ref attr 'always-returns?))
 	   (appl-never-returns? (hfield-ref attr 'never-returns?))
 	   (static-method? (hfield-ref attr 'static-method?))
-	   (tmp1 (begin (dwl3 "translate-procedure-expression-aut/4-1") 0))
 	   (env-with-args
 	    (if pure-proc?
 		(make-pure-proc-env
 		 env arg-bindings)
 		(make-environment
 		 env arg-bindings))))
-      (dwl3 "translate-procedure-expression-aut/4-3")
       (let* ((cur-letrec-env (hfield-ref compiler
 					 'current-letrec-env))
 	     (old-inside-proc?
 	      (if (null? cur-letrec-env)
 		  #f
 		  (hfield-ref cur-letrec-env 'inside-proc?))))
-	(dwl3 "translate-procedure-expression-aut/4-4")
 	(if (not-null? cur-letrec-env)
 	    (hfield-set! cur-letrec-env 'inside-proc? #t))
-	(dwl2 "translate-procedure-expression-aut/4-5")
 	(let* ((t-body
 		(wrap-compound-expression compiler env-with-args
 					  s-body))
@@ -939,13 +846,9 @@
 			   appl-never-returns?
 			   static-method?))
 	       (inside-param-def? (hfield-ref compiler 'inside-param-def?)))
-	  (dwl2 "translate-procedure-expression-aut/4-6")
-	  (dwl2 s-body)
-	  (dwl2 (unspecified? t-body))
 	  (if (not-null? cur-letrec-env)
 	      (hfield-set! cur-letrec-env 'inside-proc?
 			   old-inside-proc?))
-	  (dwl3 "translate-procedure-expression-aut/5")
 	  ;; If purity specifier is gl-force-pure
 	  ;; the procedure body is allowed to be nonpure.
 	  (cond
@@ -964,18 +867,13 @@
 		 (not (entity-never-returns? t-body)))
 	    (raise 'proc-attribute-mismatch))
 	   (else
-	    (dwl2 "translate-procedure-expression-aut/6-0")
-	    (dwl2 s-body)
-	    (dwl2 (unspecified? t-body))
 	    (let ((body-never-returns?
 		   (entity-never-returns? t-body)))
-	      (dwl2 "translate-procedure-expression-aut/6")
 	      (let ((to (make-procedure proc-type #t #f '()
 					s-name '()))
 		    (need-revision?
 		     (hfield-ref compiler
 				 'inside-param-def?)))
-		(dwl3 "translate-procedure-expression-aut/7")
 		(make-hrecord <procedure-expression>
 			      proc-type #t #t '()
 			      #t #t need-revision? to
@@ -1002,7 +900,6 @@
 				   s-attr
 				   s-kind s-name
 				   aut-result-type?)
-  (dwl4 "translate-param-proc-expr ENTER")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (boolean? aut-result-type?))
@@ -1036,7 +933,6 @@
 	       to-param-proc-class
 	       '()
 	       '()))
-	     (tmp1 (begin (dwl4 "translate-param-proc-expr/1") 0))
 	     (r-proc (make-param-proc2 r-type-params
 				       to-param-proc-class r-proc0
 				       s-kind
@@ -1045,13 +941,11 @@
 	(tno-field-set! to-param-proc 'x-value-expr r-proc0)
 	(compiler-set-fixed-tvars! compiler old-fixed-tvars)
 	(hfield-set! compiler 'inside-param-def? inside-param-def-old?)
-	(dwl4 "translate-param-proc-expr EXIT")
 	r-proc))))
 
 
 (define (translate-general-proc-type1 compiler env1 simple? s-arg-list
 				      s-result-type s-attributes)
-  (dwl4 "translate-general-proc-type1")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env1 <environment>))
   (assert (boolean? simple?))
@@ -1064,10 +958,11 @@
 	 (pure-proc? (hfield-ref parsed-attr 'pure?))
 	 (appl-always-returns? (hfield-ref parsed-attr 'always-returns?))
 	 (appl-never-returns? (hfield-ref parsed-attr 'never-returns?))
-	 ;; Maybe we should not allow attribute "static" with procedure types.
 	 (static-method? (hfield-ref parsed-attr 'static-method?))
 	 (result-type (translate-expr compiler env1 #f s-result-type)))
-    (dwl4 "translate-general-proc-type/2")
+    (if (not (and-map? (lambda (argdesc) (is-type? binder argdesc))
+		       arg-desc-exprs))
+	(raise 'procedure-type-arg-syntax-error))
     (translate-general-proc-type-expression
      binder
      simple?
@@ -1080,7 +975,6 @@
 
 
 (define (translate-general-proc-type compiler env1 expr-tail simple?)
-  (dwl4 "translate-general-proc-type")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env1 <environment>))
   (assert (boolean? simple?))
@@ -1097,7 +991,6 @@
 (define (do-translate-param-proc-class compiler local-env
 				       type-params s-arg-list s-result-type
 				       s-attr)
-  (dwl4 "do-translate-param-proc-class")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? local-env <environment>))
   (let* ((r-type-params (map cdr type-params))
@@ -1126,7 +1019,6 @@
 (define (do-translate-param-proc-class2 compiler env1
 					s-tvars s-arg-list s-result-type
 					s-attr)
-  (dwl4 "do-translate-param-proc-class2")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env1 <environment>))
   (let* ((type-params (make-type-vars compiler s-tvars))
@@ -1138,7 +1030,6 @@
 
 
 (define (translate-param-proc-class compiler env1 expr-tail)
-  (dwl4 "translate-param-proc-class")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env1 <environment>))
   (if (or (not (pair? expr-tail)) (not (= (length expr-tail) 4)))
@@ -1153,15 +1044,12 @@
 
 
 (define (parse-let-var-nonconstant compiler env1 varspec volatile?)
-  (dwl2 "parse-let-var-nonconstant ENTER")
   (if (not (= (length varspec) 3))
       (raise 'invalid-let-variable)
       (let ((name (car varspec)))
 	(if (not (symbol? name)) (raise 'invalid-let-var-name))
 	(let* ((to-name (make-primitive-object tc-symbol name))
-	       (tmp1 (begin (dwl4 "parse-let-var-nonconstant/1") 0))
-	       (type (translate-expr compiler env1 #f (cadr varspec)))
-	       (tmp2 (begin (dwl4 "parse-let-var-nonconstant/2") 0)))
+	       (type (translate-expr compiler env1 #f (cadr varspec))))
 	  (if (not (is-type?
 		    (compiler-get-binder compiler) type))
 	      (raise (list 'invalid-let-var-type (cons 's-name name))))
@@ -1225,18 +1113,14 @@
 				variable
 				variable type init-expr
 				gl-false)))))))
-	    (dwl2 "parse-let-var-nonconstant EXIT")
 	    result)))))
 
 
 (define (parse-let-var-constant compiler env1 varspec)
-  (dwl2 "parse-let-var-constant")
-  (dwl2 varspec)
   (if (not (or (= (length varspec) 2) (= (length varspec) 3)))
       (raise 'invalid-let-variable)
       (let ((has-type-spec? (= (length varspec) 3))
 	    (name (car varspec)))
-	(dwl2 "parse-let-var-constant/1")
 	(if (not (symbol? name)) (raise 'invalid-let-var-name))
 	(let* ((to-name (make-primitive-object tc-symbol name))
 	       (sexpr-init (if has-type-spec? (caddr varspec) (cadr varspec)))
@@ -1256,7 +1140,6 @@
 	       (type-var (if (not-null? type-declared)
 			     type-declared
 			     type-actual)))
-	  (dwl2 "parse-let-var-constant/2")
 	  (if (and has-type-spec?
 		   (not (is-type?
 			 (compiler-get-binder compiler) type-declared)))
@@ -1286,26 +1169,15 @@
 			(free-tvars?
 			 (or (contains-free-tvars? type-actual)
 			     (contains-free-tvars? type-declared))))
-		    (dwl2 "parse-let-var-constant/5")
-;;		    (set! gl-counter28 (+ gl-counter28 1))
-;;		    (dwl2 gl-counter28)
-;;		    (dvar1-set! type-declared)
-;;		    (dvar2-set! type-actual)
-
-		    ;; TBR
-;;		    (if (= gl-counter28 2) (raise 'stop-28))
-
 		    (cond
 		     ((and (not type-dispatched?)
 			   (not (hfield-ref compiler 'inside-param-def?)))
 		      (raise 'let:illegal-nondispatched-expression))
 		     ((entity-is-none1? binder type-actual)
-		      (dwl2 "parse-let-var-constant/5-1")
 		      (raise (list 'let:initializer-none
 				   (cons 's-name name))))
 		     ((and (not-null? type-declared)
 			   (entity-is-none1? binder type-declared))
-		      (dwl2 "parse-let-var-constant/5-2")
 		      (raise 'let:type-none))
 		     ((and (not type-dispatched?)
 			   (hfield-ref compiler 'inside-param-def?))
@@ -1327,7 +1199,6 @@
 			    (or (not type-dispatched?) free-tvars?))
 		       (or (null? type-declared)
 			   (is-t-subtype? binder type-actual type-declared)))
-		      (dwl2 "parse-let-var-constant/5-3")
 		      (make-normal-variable3
 		       address
 		       type-var
@@ -1342,7 +1213,6 @@
 				   (cons 's-name name)
 				   (cons 'tt-declared type-declared)
 				   (cons 'tt-actual type-actual))))))))
-	    (dwl2 "parse-let-var-constant EXIT")
 	    (list to-name variable
 		  (if known-init? init-expr2 variable)
 		  type-declared init-expr
@@ -1361,7 +1231,6 @@
 
 
 (define (get-bindings vars)
-  (dwl2 "get-bindings")
   (map (lambda (var)
 	 (assert (is-t-primitive-object? (car var)))
 	 (cons (get-contents (car var)) (caddr var)))
@@ -1371,36 +1240,21 @@
 (define (translate-let-expression compiler env1 expr-tail constant-bindings?
 				  volatile?)
   ;; TBD: Raise an exception if both constant-bindings? and volatile? are #t.
-  (dwl2 "t-let-e")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env1 <environment>))
   (assert (list? expr-tail))
   (assert (not (and constant-bindings? volatile?)))
   (check-env env1)
-  (dwl2 "t-let-e/1")
   (if (< (length expr-tail) 2)
       (raise 'too-short-let)
       (let* ((s-vars (car expr-tail))
 	     (s-body (cdr expr-tail))
 	     (varspecs (parse-let-vars compiler env1 constant-bindings?
 				       volatile? s-vars))
-	     (tmp1 (begin (dwl2 "t-let-e/2") 0))
 	     (bindings (get-bindings varspecs))
-	     (tmp2 (begin (dwl2 "t-let-e/3") 0))
 	     (local-env (make-environment env1 bindings))
 	     (init-exprs
 	      (map pick5th varspecs)))
-	(dwl2 "t-let-e/4")
-
-	;; TBR
-	;; (if (eq? (caar s-vars) 'lst1-1533)
-	;;     (begin
-	;;       (dwl2 constant-bindings?)
-	;;       (dvar1-set! env1)
-	;;       (dvar2-set! expr-tail)
-	;;       (dvar3-set! bindings)
-	;;       (raise 'stop1533)))
-
 	(let* ((t-body
 		(wrap-compound-expression compiler local-env s-body))
 	       (subexpr-type (get-entity-type t-body))
@@ -1443,7 +1297,6 @@
 (define (translate-letrec-expression compiler env expr-tail
 				     constant-bindings? volatile? order?)
   ;; TBD: Raise an exception if both constant-bindings? and volatile? are #t.
-  (dwl4 "translate-letrec-expression")
   (if (< (length expr-tail) 2)
       (raise 'too-short-letrec)
       (let* ((s-varspecs (car expr-tail))
@@ -1451,13 +1304,11 @@
 	     (letrec-vars-parse-result
 	      (parse-letrec-vars compiler env s-varspecs constant-bindings?
 				 volatile?))
-	     (tmp1 (begin (dwl4 "translate-letrec-expression/1") 0))
 	     (letrec-vars (car letrec-vars-parse-result))
 	     (new-env (cadr letrec-vars-parse-result))
 	     (t-body
 	      (wrap-compound-expression
 	       compiler new-env s-body))
-	     (tmp2 (begin (dwl4 "translate-letrec-expression/2") 0))
 	     (subexpr-type (get-entity-type t-body))
 	     (exact-type? (hfield-ref t-body 'exact-type?))
 	     (subexpr-pure? (is-pure-entity? t-body))
@@ -1470,11 +1321,9 @@
 	     (always-returns?
 	      (and (entity-always-returns? t-body)
 		   (and-map? entity-always-returns? init-exprs)))
-	     (tmp2 (begin (dwl4 "translate-letrec-expression/3") 0))
 	     (never-returns?
 	      (or (entity-never-returns? t-body)
 		  (or-map? entity-never-returns? init-exprs))))
-	(dwl4 "translate-letrec-expression/n")
 	(if (and (not type-dispatched?)
 		 (not (hfield-ref compiler 'inside-param-def?)))
 	    (raise 'letrec:illegal-nondispatched-expr))
@@ -1497,8 +1346,6 @@
 
 
 (define (translate-genproc-appl compiler symtbl expr-head expr-tail)
-  (dwl4 "translate-genproc-appl")
-  (dwl4 expr-tail)
   ;; It is essential to use map* here.
   ;; tarkista seuraava
   (let ((arglist (map* (lambda (expr)
@@ -1506,7 +1353,6 @@
 		       expr-tail))
 	(inside-param-def? (hfield-ref compiler 'inside-param-def?))
 	(binder (compiler-get-binder compiler)))
-    (dwl4 "translate-genproc-appl/1")
     ;; TBD: Should we check that expr-head is a target object?
     (translate-general-genproc-appl
      binder
@@ -1514,7 +1360,6 @@
 
 
 (define (translate-param-proc-appl compiler symtbl expr-head expr-tail)
-  (dwl4 "translate-param-proc-appl")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (is-entity? expr-head))
@@ -1529,11 +1374,9 @@
 
 
 (define (translate-simple-proc-appl compiler symtbl expr-head expr-tail)
-  (dwl3 "translate-simple-proc-appl ENTER")
   (let ((arguments (map* (lambda (expr)
 			   (translate-expr compiler symtbl #f expr))
 			 expr-tail)))
-    (dvar1-set! expr-head)
     (let ((result '()))
       (set! result
 	    ;; Procedures field-ref and field-set!
@@ -1555,15 +1398,12 @@
 		   #t
 		   inside-param-def?
 		   inside-param-def?)))
-	    (dwl3 "translate-simple-proc-appl EXIT 1")
 	    result2)
 	  (begin
-	    (dwl3 "translate-simple-proc-appl EXIT 2")
 	    result)))))
 
 
 (define (translate-pair-class compiler symtbl expr-tail)
-  (dwl4 "translate-pair-class")
   (if (>= (length expr-tail) 1)
       (let ((args
 	     (map*
@@ -1578,8 +1418,6 @@
 ;; It is legal to give <none> as a member of a union type.
 ;; In that case the union type will be equal to <none>.
 (define (translate-union compiler symtbl expr-tail)
-  (dwl4 "translate-union")
-  (dwl4 expr-tail)
   (if (null? expr-tail)
       tt-none
       (let ((subexprs (map*
@@ -1625,8 +1463,6 @@
 
 
 (define (translate-param-class-instance compiler symtbl expr-head expr-tail)
-  (dwl4 "translate-param-class-instance")
-  (dwl4 expr-tail)
   (assert (is-target-object? expr-head))
   (let* ((r-param-class expr-head)
 	 (r-type-params
@@ -1643,8 +1479,6 @@
 
 
 (define (translate-param-sgn-instance compiler symtbl expr-head expr-tail)
-  (dwl4 "translate-param-sgn-instance")
-  (dwl4 expr-tail)
   (assert (is-target-object? expr-head))
   (let* ((r-param-sgn expr-head)
 	 (r-type-params
@@ -1660,7 +1494,6 @@
 
 (define (translate-param-logical-type-instance compiler symtbl
 					       expr-head expr-tail)
-  (dwl4 "translate-param-logical-type-instance")
   (assert (is-target-object? expr-head))
   (let* ((r-param-ltype expr-head)
 	 (r-type-params
@@ -1678,7 +1511,6 @@
 
 
 (define (translate-uniform-list compiler symtbl toplevel? expr-tail)
-  (dwl4 "translate-uniform-list")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (list? expr-tail))
@@ -1703,18 +1535,15 @@
 
 
 (define (translate-primitive-procedure compiler symtbl expr-tail check?)
-  (dwl4 "translate-primitive-procedure")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (list? expr-tail))
   (assert (boolean? check?))
   (check-env symtbl)
-  (dwl4 "tpp/1")
   (if (not (list? expr-tail))
       (raise 'invalid-procedure-definition)
       (let ((target-name (car expr-tail))
 	    (header (cdr expr-tail)))
-	(dwl4 "tpp/2")
 	(if (or (not (list? header)) (not (= (length header) 3)))
 	    (raise 'invalid-procedure-header)
 	    (let ((s-arg-desc-expr (list-ref header 0))
@@ -1749,7 +1578,6 @@
 				 appl-always-returns?
 				 appl-never-returns?
 				 static-method?)))
-		(dwl4 "tpp/10")
 		(if (and has-result? check?)
 		    (begin
 		      (get-checked-prim-proc target-name proc-type))
@@ -1759,13 +1587,11 @@
 
 
 (define (translate-param-prim-proc compiler symtbl expr-tail check?)
-  (dwl4 "translate-param-prim-proc")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (list? expr-tail))
   (assert (boolean? check?))
   (check-env symtbl)
-  (dwl4 "tpp/1")
   (if (not (and (list? expr-tail) (= (length expr-tail) 5)))
       (raise 'invalid-procedure-definition)
       (let ((target-name (car expr-tail))
@@ -1773,7 +1599,6 @@
 	    (s-arg-types (list-ref expr-tail 2))
 	    (s-result-type (list-ref expr-tail 3))
 	    (s-attr (list-ref expr-tail 4)))
-	(dwl4 "tpp/2")
 	(let* ((proc-type 
 		(do-translate-param-proc-class2 compiler symtbl
 						s-tvars
@@ -1785,7 +1610,6 @@
 			     'type-result))
 	       ;; Should we use entity-is-none1? in the following?
 	       (has-result? (not (target-type=? result-type tt-none))))
-	  (dwl4 "tpp/3")
 	  (if (and has-result? check?)
 	      (begin
 		(get-checked-prim-proc target-name proc-type))
@@ -1794,7 +1618,7 @@
 		 target-name proc-type)))))))
 
 
-(define (translate-assertion compiler symtbl condition strong?)
+(define (translate-assertion compiler symtbl condition cond-to-print strong?)
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? symtbl <environment>))
   (assert (boolean? strong?))
@@ -1815,120 +1639,7 @@
 		    tt-none #t #t '()
 		    #t #f #f '()
 		    #f #f
-		    r-condition condition strong?)))))
-
-
-(define (make-exec/cc-body-proc r-body r-body-proc-type r-jump-proc-type
-				jump-var s-jump-proc-name)
-  (let* ((names (list s-jump-proc-name))
-	 (to (make-target-object
-	      r-body-proc-type #t #f '()
-	      #f #f #f '())))
-    (make-hrecord <procedure-expression>
-		  r-body-proc-type
-		  (entity-type-dispatched? r-body)
-		  #f
-		  '()
-		  #t #t #f to
-		  names
-		  (list r-jump-proc-type)
-		  (list jump-var)
-		  (get-entity-type r-body)
-		  r-body
-		  'local
-		  '()
-		  '()
-		  (is-pure-entity? r-body)
-		  #f
-		  #f
-		  #f
-		  #f)))
-
-
-(define (translate-exec/cc compiler symtbl toplevel? args)
-  (dwl4 "translate-exec/cc ENTER")
-  (assert (hrecord-is-instance? compiler <compiler>))
-  (assert (hrecord-is-instance? symtbl <environment>))
-  (assert (boolean? toplevel?))
-  (if (not (= (length args) 3))
-      (raise 'exec/cc:invalid-number-of-arguments)
-      (let ((s-jump-proc-name (car args))
-	    (s-jump-type (cadr args))
-	    (s-body (caddr args)))
-	(dwl4 "translate-exec/cc-1")
-	(if (not (symbol? s-jump-proc-name))
-	    (raise 'exec/cc:invalid-proc-name)
-	    (let* ((r-jump-type (translate-expr compiler symtbl #f s-jump-type))
-		   (binder (compiler-get-binder compiler))
-		   (jump-takes-arg? (not (entity-is-none1? binder r-jump-type)))
-		   (r-jump-proc-type
-		    (if jump-takes-arg?
-			(translate-simple-proc-class-expression
-			 binder (list r-jump-type) tt-none #t #f #t #f)
-			(translate-simple-proc-class-expression
-			 binder '() tt-none #t #f #t #f)))
-		   ;; The jump variable is lexical.
-		   (jump-var (make-normal-variable1
-			      (compiler-alloc-loc compiler s-jump-proc-name #f)
-			      r-jump-proc-type
-			      #t
-			      #t
-			      '()))
-		   (local-env (make-environment
-			       symtbl
-			       (list
-				(cons s-jump-proc-name jump-var))))
-		   (r-body (translate-expr compiler local-env #f s-body))
-		   (r-body-type (get-entity-type r-body))
-		   (pure? (is-pure-entity? r-body))
-		   (tmp3 (begin (dwl4 "translate-exec/cc-3") 0))
-		   (r-result-type
-		    (if (or (entity-is-none1? binder r-body-type)
-			    (entity-is-none1? binder r-jump-type))
-			tt-none
-			(get-union-of-types
-			 binder (list r-body-type r-jump-type))))
-		   (tmp4 (begin (dwl4 "translate-exec/cc-4") 0))
-		   (r-body-proc-type
-		    (translate-simple-proc-class-expression
-		     binder (list r-jump-proc-type) r-body-type pure? #f #f #f))
-		   (r-body-proc
-		    (make-exec/cc-body-proc
-		     r-body r-body-proc-type r-jump-proc-type jump-var
-		     s-jump-proc-name))
-		   (final? (is-final-class?
-			    binder r-result-type))
-		   (proc (make-var-ref-to-var
-			  (cond
-			   ((entity-is-none1? binder r-result-type)
-			    var-call/cc-without-result)
-			   (pure?
-			    var-call/cc)
-			   (else
-			    var-call/cc-nonpure)))))
-
-	      (dwl4 "translate-exec/cc EXIT")
-
-	      (make-hrecord <proc-appl>
-			    r-result-type
-			    (entity-type-dispatched? r-body-proc)
-			    final?
-			    '()
-
-			    pure?
-			    #f
-			    #f
-			    '()
-
-			    #f
-			    #f
-
-			    proc
-			    (list r-body-proc)
-			    '()
-			    (list r-body-proc-type)
-			    #f
-			    '()))))))
+		    r-condition cond-to-print strong?)))))
 
 
 (define (parse-signature-member-sexpr compiler symtbl s-member)
