@@ -18,10 +18,12 @@
 	  tno-field-ref
 	  theme-compile-unit
 	  gl-compiler
+	  target-object-as-string
 	  <target-object>)
   
   (import (guile)
 	  (rnrs exceptions)
+	  (only (rnrs) for-all exists)
 	  (srfi srfi-1)
 	  (srfi srfi-13)
 	  (srfi srfi-43)
@@ -257,12 +259,6 @@
   (load-theme-file "theme-d-compilation-utilities")
 
 
-  ;; *** Call with current continuation ***
-
-  ;; (dwl4 "Call with current continuation")
-  (load-theme-file "theme-d-call-cc")
-
-
   ;; *** Compilation 1 ***
 
   ;; (dwl4 "Compilation 1")
