@@ -46,16 +46,10 @@
 
 
 (define (detect-cycles binder expr ht-cycles lst-visited)
-;;  (dwli2 "detect-cycles ENTER")
   (assert (is-binder? binder))
   (assert (hash-table? ht-cycles))
   (assert (list? lst-visited))
-
-  ;; TBR
-  ;; (set! gl-counter12 (+ gl-counter12 1))
-  ;; (if (= gl-counter12 4629)
-  ;;     (begin
-  ;; 	(set! gl-flag17? #t)))
+  
   ;; (if gl-flag16?
   ;;     (begin
   ;; 	(dwi "det ")
@@ -73,35 +67,9 @@
   ;; 	(dwc " ")
   ;; 	(dwc (hashq expr 10000000))
   ;; 	(dwli-newline)))
-
-  ;; TBR
-  ;; (if gl-flag16?
-  ;;     (begin
-  ;; 	(dwl1 "detect-cycles ENTER")
-  ;; 	(if (hrecord? expr)
-  ;; 	    (dwl1 (hrecord-type-name-of expr))
-  ;; 	    (dwl1 "?"))
-  ;; 	(if (is-target-object? expr)
-  ;; 	    (dwl1 (target-object-as-string expr)))))
 	
   (let ((old-indent gl-indent))
     (set! gl-indent (+ gl-indent 1))
-
-    ;; TBR
-    ;; (if (hrecord? expr)
-    ;; 	(begin
-    ;; 	  (dwi "hrecord type: ")
-    ;; 	  (dwc (hrecord-type-name-of expr))
-    ;; 	  (dwli2-newline)))
-    ;; (if (is-target-object? expr)
-    ;; 	(begin
-    ;; 	  (dwi "target object: ")
-    ;; 	  (dwc (debug-get-string expr))
-    ;; 	  (dwli2-newline)))
-    ;; (dwi "detect-cycles input hash: ")
-    ;; (dwc (hashq expr 1000000))
-    ;; (dwli2-newline)
-
     (let ((cycle (hashq-ref ht-cycles expr)))
       (cond
        ((not (eqv? cycle #f)) '())
@@ -124,16 +92,10 @@
        			 lst-new-visited)
        	  (detect-cycles binder (get-pair-second-type expr) ht-cycles
        			 lst-new-visited)))
-       ((and (is-known-object? expr)
-       	     (is-tc-pair? (get-entity-type expr)))
-
-	;; TBR
-	;; (dwl2 "detect-cycles/1")
-	;; (set! gl-counter20 (+ gl-counter20 1))
-	;; (dwl2 gl-counter20)
-	;; (dvar1-set! expr)
-	;; (raise 'stop-det)
-
+       ((and
+	 (not (is-t-primitive-object? expr))
+	 (is-known-object? expr)
+       	 (is-tc-pair? (get-entity-type expr)))
        	(let ((lst-new-visited (cons expr lst-visited)))
        	  (detect-cycles binder (tno-field-ref expr 'first) ht-cycles
        			 lst-new-visited)
@@ -150,11 +112,9 @@
 	  (for-each det (hfield-ref expr 'params))
 	  (for-each det (hfield-ref expr 'static-arg-types))))
        ((is-t-param-class-instance? expr)
-;;	(dwli "detect-cycles/1")
        	(let* ((lst-new-visited (cons expr lst-visited))
        	       (det (lambda (expr1) (detect-cycles binder expr1 ht-cycles
        						   lst-new-visited))))
-;;	  (dwli "detect-cycles/2")
        	  (det (tno-field-ref expr 'cl-superclass))
        	  (for-each det
        	  	    (map (lambda (fld) (tno-field-ref fld 'type))
@@ -182,33 +142,22 @@
 	  (det (hfield-ref expr 'result-type))
 	  (det (hfield-ref expr 'body))))
        (else
-;;	(dwli "detect-cycles/4")
 	(let* ((lst-subexprs (get-subexpressions expr))
 	       (lst-new-visited (cons expr lst-visited)))
-	  ;;	  (dwli "detect-cycles/5")
 	  (detect-cycles binder (hfield-ref expr 'type) ht-cycles
 			 lst-new-visited)
-;;	  (dwli "detect-cycles/6")
 	  (for-each (lambda (expr1) (detect-cycles binder expr1 ht-cycles
 						   lst-new-visited))
 		    lst-subexprs))))
-
-      ;; TBR
-;;      (if gl-flag16?
-;;	  (dwl1 "detect-cycles EXIT"))
-	    
       (set! gl-indent old-indent))))
 
 
 (define (make-cycle-object obj)
-  (dwl4 "make-cycle-object")
   (assert (is-target-object? obj))
   (make-incomplete-object (get-expr-type obj) #f))
 
 
 (define (update-cycle-object! sgt element)
-  (dvar1-set! sgt)
-  (dvar2-set! element)
   (assert (is-target-object? sgt))
   (assert (is-target-object? element))
   (set-object1! sgt element)
