@@ -29,19 +29,22 @@
 
 
 (define gl-l-active-debug-categories
-;;  (list 'type-deduction 'tvar-binding))
-;;  (list 'tvar-binding))
-;;  (list 'subtyping))
-;;  '(expand scan))
-;;  (list 'type-deduction))
-;;  (list 'i-s2))
-  '(scan2 expand2 core-lang2))
-;;  '(expand))
-;;  '(match-type))
-;;  '())
+  ;;  (list 'type-deduction 'tvar-binding))
+  ;;  (list 'tvar-binding))
+  ;;  (list 'subtyping))
+  ;;  '(expand scan))
+  ;; (list 'type-deduction))
+  ;;  (list 'i-s2))
+  ;;  '(scan2 expand2 core-lang2))
+  ;;  '(expand))
+  ;;  '(match-type))
+  ;; '(debug1 phase2))
+  ;; '(debug10))
+  '())
+;;  '(debug-union))
 
 ;; (define (debug-get-string x) (target-object-as-string x))
-(define debug-get-string (lambda (x) '()))
+(define debug-get-string (lambda (x) ""))
 
 
 (define do-nothing1 (lambda (x) #f))
@@ -171,6 +174,7 @@
    ((= level 0) "")
    ((< level 0) (raise 'internal-error))
    (else
+    ;; Should we have get-indentation-prefix0 in the following?
     (string-append " " (get-indentation-prefix (- level 1))))))
 
 (define (get-indentation-prefix level)
@@ -240,6 +244,8 @@
   (if (memq cat gl-l-active-debug-categories)
       (newline)))
 
+(define d2-newline d2wli-newline)
+
 
 (define dwli2 (lambda (obj) '()))
 ;;(define dwli2 dwli)
