@@ -202,17 +202,9 @@
 
 
 (define (tno-field-ref to fld)
-  ;; (dwl4 "tno-field-ref")
-  ;; (dvar1-set! to)
-  ;; (dvar2-set! fld)
-;;  (dwl2 "*1*")
   (assert (hrecord-is-instance? to <target-object>))
-;;  (dwl2 "*2*")
   (assert (not (hfield-ref to 'incomplete?)))
-;;  (dwl2 "*3*")
   (assert (symbol? fld))
-;;  (dwl2 "*4*")
-  ;; (dwl4 "tno-field-ref/1")
   (let ((binding
 	 (assv fld (hfield-ref to 'al-field-values))))
     (if binding
@@ -224,7 +216,6 @@
 
 (define (tno-field-set! to fld value)
   (assert (hrecord-is-instance? to <target-object>))
-  (dwl4 "*2*")
   (assert (not (hfield-ref to 'incomplete?)))
   (assert (symbol? fld))
   (let ((binding
@@ -244,8 +235,6 @@
 			       value value-expr exported?
 			       changed-in-inst?)
 
-  (dwl4 "make-normal-variable0")
-  (dwl4 (hfield-ref address 'source-name))
   (assert (hrecord-is-instance? address <address>))
   ;; Is it necessary to accept null types?
   (assert 
@@ -257,11 +246,8 @@
   (assert (boolean? volatile?))
   (assert (boolean? forward-decl?))
   (assert (boolean? letrec-variable?))
-  (dwl4 "make-normal-variable0/1")
-  (dvar2-set! value)
   (assert (or (null? value)
 	      (hrecord-is-instance? value <target-object>)))
-  (dwl4 "make-normal-variable0/2")
   (assert (or (null? value-expr) (is-entity? value-expr)))
   (assert (boolean? exported?))
   (assert (boolean? changed-in-inst?))
@@ -283,7 +269,6 @@
 (define (make-normal-variable address type exact-type? read-only?
 			      forward-decl?
 			      value exported?)
-  (dwl4 "make-normal-variable")
   (make-normal-variable0
    address
    type
@@ -307,8 +292,6 @@
 (define (make-normal-variable2 address type exact-type? read-only?
 			       forward-decl?
 			       value value-expr exported?)
-
-  (dwl4 "make-normal-variable2")
   (make-normal-variable0
    address
    type
@@ -327,8 +310,6 @@
 (define (make-normal-variable3 address type type-dispatched? exact-type?
 			       read-only? forward-decl?
 			       value value-expr)
-
-  (dwl3 "make-normal-variable3")
   (make-normal-variable0
    address
    type
@@ -348,7 +329,6 @@
 			       volatile?
 			       forward-decl?
 			       value exported?)
-  (dwl4 "make-normal-variable4")
   (make-normal-variable0
    address
    type
@@ -373,8 +353,6 @@
 (define (make-normal-variable6 address type type-dispatched? exact-type?
 			       read-only? volatile? forward-decl?
 			       value value-expr)
-
-  (dwl3 "make-normal-variable6")
   (make-normal-variable0
    address
    type
@@ -393,8 +371,6 @@
 (define (make-normal-variable7 address type exact-type? read-only? volatile?
 			       forward-decl?
 			       value value-expr exported?)
-
-  (dwl4 "make-normal-variable7")
   (make-normal-variable0
    address
    type
@@ -414,7 +390,6 @@
 			       volatile?
 			       forward-decl?
 			       value exported?)
-  (dwl4 "make-normal-variable8")
   (make-normal-variable0
    address
    type
@@ -441,7 +416,6 @@
 				volatile?
 				forward-decl?
 				value exported?)
-  (dwl4 "make-normal-variable10")
   (make-normal-variable0
    address
    type
