@@ -32,7 +32,6 @@
 	 condition-expr then-expr else-expr
 	 boolean-cond?
 	 do-type-check?)
-  (dwl4 "translate-if-expression")
   (assert (is-binder? binder))
   (let ((pure-cond? (is-pure-entity? condition-expr)))
     (cond
@@ -76,7 +75,6 @@
 	      (or (entity-never-returns? condition-expr)
 		  (and (entity-never-returns? then-expr)
 		       (entity-never-returns? else-expr)))))
-	(dwl4 "translate-if-expression EXIT")
 	(make-hrecord
 	 <if-form>
 	 type
@@ -93,77 +91,13 @@
      (else (begin (dvar1-set! condition-expr) (raise 'invalid-if-condition))))))
 
 
-(define (translate-guard-general-expression binder body exc-var repr-handler
-					    type-check?)
-  (dwl4 "translate-guard-general-expression ENTER")
-  (assert (is-binder? binder))
-  (assert (is-entity? body))
-  (assert (hrecord-is-instance? exc-var <normal-variable>))
-  (assert (is-entity? repr-handler))
-  (assert (boolean? type-check?))
-  (dwl4 "translate-guard-general-expression/1")
-  ;; The order of subexprs should not have any significance.
-  (let* ((subexprs (list body repr-handler))
-	 (type-dispatched?
-	  (and-map? entity-type-dispatched? subexprs))
-	 (always-returns?
-	  (and-map? entity-always-returns? subexprs))
-	 (never-returns?
-	  (and-map? entity-never-returns? subexprs)))
-    (if type-check?
-	(begin
-	  (dwl4 "translate-guard-general-expression/2")
-	  (let ((result-type
-		 (get-union-type-from-expressions binder subexprs))
-		(pure?
-		 (and
-		  (is-pure-entity? body)
-		  (is-pure-entity? repr-handler))))
-	    (dwl4 "translate-guard-general-expression EXIT 1")
-	    (dvar1-set! result-type)
-	    (make-hrecord <expr-guard-general>
-			  result-type
-			  type-dispatched?
-			  (is-final-class? binder result-type)
-			  '()
-			  pure?
-			  #f
-			  (not type-check?)
-			  '()
-			  always-returns?
-			  never-returns?
-			  body
-			  exc-var
-			  repr-handler)))
-	(begin
-	  (dwl4 "translate-guard-general-expression EXIT 2")
-	  ;; We set type-dispatched? = #f because we don't compute
-	  ;; the result type.
-	  (make-hrecord <expr-guard-general>
-			tc-object
-			#f
-			#f
-			'()
-			#f
-			#f
-			#t
-			'()
-			always-returns?
-			never-returns?
-			body
-			exc-var
-			repr-handler)))))
-
-
 ;; The following procedure should also work for general procedure
 ;; applications.
-;; Argument runtime-arglist-typecheck? is not used.
 (define (translate-simple-proc-appl-expression binder
 					       proc arg-list static-arg-types
 					       type-check?
 					       inside-param-def?
 					       runtime-arglist-typecheck?)
-  (dwl2 "translate-simple-proc-appl-expression")
   (assert (is-binder? binder))
   (assert (is-entity? proc))
   (assert (list? arg-list))
@@ -174,10 +108,7 @@
   (assert (boolean? type-check?))
   (assert (boolean? inside-param-def?))
   (assert (boolean? runtime-arglist-typecheck?))
-  (dwl2 "translate-simple-proc-appl-expression/0")
-  (dvar1-set! proc)
   (let* ((proc-type (get-entity-type proc))
-	 (tmp1 (begin (dwl2 "translate-simple-proc-appl-expression/0-1") 0))
 	 (static-arg-types1
 	  (if (eq? static-arg-types #f)
 	      (map get-expr-type arg-list)
@@ -188,15 +119,11 @@
 	 (type-dispatched? (entity-type-dispatched? proc))
 	 (arg-list-type-dispatched?
 	  (and-map? entity-type-dispatched? arg-list))
-	 (tmp2 (begin (dwl2 "translate-simple-proc-appl-expression/0-2")
-		      (dvar1-set! proc)
-		      0))
 	 (always-returns?
 	  (and
 	   (tno-field-ref proc-type 'appl-always-returns?)
 	   (entity-always-returns? proc)
 	   (and-map? entity-always-returns? arg-list)))
-	 (tmp3 (begin (dwl2 "translate-simple-proc-appl-expression/0-3") 0))
 	 (never-returns?
 	  (or
 	   (tno-field-ref proc-type 'appl-never-returns?)
@@ -206,8 +133,6 @@
 	 (pure-args?
 	  (and-map? is-pure-entity? arg-list))
 	 (pure? (and pure-proc? pure-args?)))
-    (dwl2 "translate-simple-proc-appl-expression/0-1.5")
-    (dvar1-set! proc)
     (let* ((arg-list-type (tno-field-ref proc-type 'type-arglist))
 	   (l-arg-types (map get-entity-type arg-list))
 	   (l-sgn (pick-signatures l-arg-types))
@@ -233,27 +158,12 @@
 	   (result-type (tno-field-ref proc-type 'type-result))
 	   (tt-actual-arglist
 	    (translate-actual-arglist-type arg-list)))
-
-      ;; (if (eq? (hfield-ref (hfield-ref proc 'address) 'source-name)
-      ;; 	   'my-proc1)
-      ;;      (begin
-      ;;  	(dvar1-set! arg-list-type)
-      ;;  	(dvar2-set! result-type)
-      ;; 	(dvar3-set! tt-actual-arglist)
-      ;; 	(dvar4-set! binder)
-      ;; 	(dwl2 type-check?)
-      ;;      	(raise 'stop1)))
-
-      (dwl2 "translate-simple-proc-appl-expression/1")
       (cond
        ((and type-check? (not inside-param-def?)
 	     (or (not type-dispatched?)
 		 (not arg-list-type-dispatched?)))
-	(dvar1-set! proc)
-	(dvar2-set! arg-list)
 	(raise 'illegal-nondispatched-proc-appl))
        ((not type-dispatched?)
-	(dwl2 "translate-simple-proc-appl-expression/2")
 	(make-hrecord <proc-appl>
 		      result-type
 		      #f
@@ -272,7 +182,6 @@
 		      #t
 		      '()))
        ((and contains-sgn? arg-free-tvars?)
-	(dwl2 "translate-simple-proc-appl-expression/2")
 	(make-hrecord <proc-appl>
 		      result-type
 		      #t
@@ -346,10 +255,6 @@
 			#f
 			'())))
        (else
-	(dvar1-set! binder)
-	(dvar2-set! tt-actual-arglist)
-	(dvar3-set! arg-list-type)
-	(dvar4-set! (list proc arg-list))
 	(raise
 	 (let* ((to-proc (get-entity-value proc))
 		(s-proc-name
@@ -367,7 +272,6 @@
 				 (hfield-ref address 'source-name)
 				 '()))))
 		     '())))
-	   (dvar1-set! proc)
 	   (list 'type-mismatch-in-proc-appl s-proc-name
 		 (cons 'actual-type tt-actual-arglist)
 		 (cons 'declared-type arg-list-type)))))))))
@@ -430,7 +334,6 @@
 
 
 (define	(make-tvars-unique binder type-vars inst-type)
-  (dwli2 "make-tvars-unique ENTER")
   (assert (hrecord-is-instance? binder <binder>))
   (assert (and (list? type-vars) (and-map? is-t-type-variable? type-vars))) 
   (assert (is-entity? inst-type))
@@ -444,24 +347,13 @@
 				  (let ((new-tvar
 					 (make-type-variable
 					  (alloc-loc 'g1 #f))))
-				    ;; (if (= (hfield-ref
-				    ;; 	    (hfield-ref new-tvar 'address)
-				    ;; 	    'number)
-				    ;; 	   41)
-				    ;; 	(begin
-				    ;; 	  (dvar1-set! type-vars)
-				    ;; 	  (dvar2-set! inst-type)
-				    ;; 	  (raise 'stop41)))
 				    new-tvar)))
 			  type-vars)))
-      (dwli2 "make-tvars-unique/1")
       (let ((result
 	     (cons
 	      (bind-type-vars-no-check binder bindings inst-type)
 	      (map cdr bindings))))
-	(dwli2 "make-tvars-unique/2")
 	(set! gl-show-indented-debug-info? old-debug?)
-      (dwli2 "make-tvars-unique EXIT")
       result))))
 
 
@@ -476,7 +368,6 @@
 					   always-returns?
 					   never-returns?
 					   l-default-params)
-  (dwl2 "translate-normal-param-proc-appl2")
   (assert (is-binder? binder))
   (assert (is-entity? r-inst-type))
   (assert (and (list? r-type-var-values)
@@ -528,7 +419,6 @@
 						always-returns?
 						never-returns?
 						l-default-params)
-  (dwl2 "translate-param-proc-appl-inside-param")
   (assert (is-binder? binder))
   (assert (is-entity? r-inst-type))
   (assert (and (list? r-type-var-values)
@@ -585,7 +475,6 @@
 				    always-returns?
 				    never-returns?
 				    type-check?)
-  (dwl2 "make-general-gen-proc-appl")
   (assert (is-binder? binder))
   (assert (is-entity? gen-proc))
   (assert (and (list? arglist)
@@ -621,7 +510,6 @@
 				      always-returns?
 				      never-returns?
 				      type-check?)
-  (dwl4 "make-dynamic-param-proc-appl")
   (assert (is-binder? binder))
   (assert (is-entity? to-param-proc))
   (assert (and (list? arglist)
@@ -853,7 +741,6 @@
 
 (define (do-translate-param-proc-appl1 binder inside-param-def?
 				       e-proc arglist l-default-params)
-  (dwl2 "do-translate-param-proc-appl1")
   (assert (is-binder? binder))
   (assert (boolean? inside-param-def?))
   (assert (is-entity? e-proc))
@@ -868,7 +755,6 @@
 	      (cons 's-proc-name
 		    (get-proc-name2 e-proc))))
       (let ((t-proc (get-entity-value e-proc)))
-	(dwl2 "do-translate-param-proc-appl1/1")
 	;; Maybe we should remove the following test.
 	(if (null? t-proc)
 	    (raise 'internal-invalid-procedure-1)
@@ -893,10 +779,6 @@
 		   (pure-proc? (tno-field-ref inst-type 'pure-proc?))
 		   (pure-args? (and-map? is-pure-entity? arglist))
 		   (pure? (and pure-proc? pure-args?)))
-	      ;; (display "arg list: ")
-	      ;; (display (target-object-as-string arg-list-type00))
-	      ;; (newline)
-	      (dwl2 "do-translate-param-proc-appl1/2")
 	      (cond
 	       ((is-tuple-type? binder arg-list-type00)
 		(if (not (= (length arglist)
@@ -989,7 +871,6 @@
 
 
 (define (check-param-proc-type binder e-proc arglist l-default-params)
-  (dwl2 "check-param-proc-type")
   (assert (hrecord-is-instance? binder <binder>))
   (assert (is-entity? e-proc))
   (assert (and (list? arglist)
@@ -1033,16 +914,6 @@
 	  (let ((deductions (get-new-type-var-assoc-table))
 		(l-old-fixed-tvars (hfield-ref binder 'fixed-tvars)))
 ;;	    (hfield-set! binder 'fixed-tvars src-tvars)
-
-	    ;; TBR
-	    ;; (if flag1?
-	    ;; 	(begin
-	    ;; 	  (dvar1-set! (list binder deductions))
-	    ;; 	  (dvar2-set! all-tvars)
-	    ;; 	  (dvar3-set! new-arg-types)
-	    ;; 	  (dvar4-set! arg-list-type0)
-	    ;; 	  (raise 'stop1)))
-
 	    (deduce-argument-types binder deductions
 				   all-tvars
 				   new-arg-types arg-list-type0)
@@ -1109,17 +980,12 @@
 	     (else
 	       (dvar1-set! new-arg-types)
 	       (dvar2-set! arg-list-type0)
-	       ;;		    (dvar3-set! e-proc)
-	       ;;		    (dvar3-set! (list arg-types inst-type))
-	       ;;		    (dvar4-set! arglist)
 	       (dvar3-set! deductions)
 	       (dvar4-set! new-type-vars)
 	       (raise 'could-not-deduce-all-tvars))))))))
 
 
 (define (get-arg-type-list arglist)
-  (dwl4 "get-arg-type-list")
-  (dwl4 (pair? arglist))
   (map (lambda (arg) (get-entity-type arg)) arglist))
 
 
@@ -1141,7 +1007,6 @@
 
 (define (make-gen-proc-appl-best-match binder method
 				       arglist result-type pure?)
-  (dwl4 "make-gen-proc-appl-best-match")
   (assert (is-binder? binder))
   (assert (is-target-object? method))
   (let* ((type-dispatched?
@@ -1205,7 +1070,6 @@
 					    appl-always-returns?
 					    appl-never-returns?
 					    regular? type-check?)
-  (dwl2 "make-general-generic-proc-dispatch")
   (let ((to-result-type
 	 (cond
 	  ((is-tc-simple-proc? proc-type)
@@ -1241,7 +1105,6 @@
 ;; as argument types
 (define (do-translate-normal-genproc-appl binder
 					  gen-proc arglist arg-types)
-  (dwl2 "do-translate-normal-genproc-appl")
   (let ((selection (select-best-method
 		    binder
 		    arg-types
@@ -1249,7 +1112,6 @@
     ;; MIETI puhtauden periytyminen metodeilla.
     (cond
      ((null? selection)
-      (dwl2 "do-translate-normal-genproc-appl/1")
       (if (or-map? contains-free-tvars-fwd? arg-types)
 	  (make-general-gen-proc-appl binder gen-proc arglist
 				      tc-object #f #f #f #f #f)
@@ -1259,10 +1121,8 @@
 			 (cons 'arg-types arg-types))))))
      ((= (length selection) 1)
       (let ((best-match (car selection)))
-	(assert (pair? best-match))
+	(assert (and (pair? best-match) (is-method-record? (car best-match))))
 	(let ((mtc (cdr best-match)))
-	  (dwl2 "do-translate-normal-genproc-appl/3")
-	  (dvar1-set! best-match)
 	  (if (not (is-tc-simple-proc? mtc))
 	      (raise 'invalid-procedure-1)
 	      (let ((result-type (tno-field-ref mtc 'type-result))
@@ -1270,12 +1130,11 @@
 		     (and (tno-field-ref mtc 'pure-proc?)
 			  (and-map? is-pure-entity? arglist)))
 		    (method (car best-match)))
-		(dwl2 "do-translate-normal-genproc-appl/4")
-		(if (or (tno-field-ref mtc 'static-method?)
+		(if (or (cdr method)
 			(is-exact-match? binder arg-types mtc))
 		    (make-gen-proc-appl-best-match
 		     binder
-		     method arglist result-type pure?)
+		     (car method) arglist result-type pure?)
 		    (let ((always-returns?
 			   (and (tno-field-ref mtc 'appl-always-returns?)
 				(and-map? entity-always-returns? arglist)))
@@ -1288,7 +1147,6 @@
 		       #t
 		       pure? always-returns? never-returns? #t))))))))
      (else
-      (dwl2 "do-translate-normal-genproc-appl/5")
       ;; Method ambiguity is not a compile time error (?).
       ;; Methods defined after calling the generic procedure
       ;; may remove the (run time) ambiguity.
@@ -1323,7 +1181,6 @@
 
 (define (do-translate-genproc-appl binder
 				   gen-proc arglist arg-types)
-  (dwl2 "do-translate-genproc-appl")
   (assert (is-binder? binder))
   (strong-assert (is-target-object? gen-proc))
   (assert (list? arglist))
@@ -1338,7 +1195,6 @@
 	(if (null? l-signatures)
 	    (do-translate-normal-genproc-appl binder gen-proc arglist arg-types)
 	    (begin
-	      (dwl2 "do-translate-genproc-appl/2")
 	      (if (not (contains-free-tvars-general? arglist))
 		  (let* ((p-match (match-call-with-signatures binder
 							      gen-proc
@@ -1375,17 +1231,14 @@
 					 appl-always-returns?
 					 appl-never-returns?
 					 type-check?)
-  (dwl2 "translate-generic-proc-dispatch")
   (assert (is-binder? binder))
   (assert (is-entity? generic-proc))
   (assert (list? arg-types))
   (assert (and-map? is-entity? arg-types))
-  (dwl2 "translate-generic-proc-dispatch/1")
   (cond
    ((not (hrecord-is-instance? generic-proc <target-object>))
     (raise 'invalid-generic-procedure))
    ((or (not type-check?) (or-map? contains-free-tvars-fwd? arg-types))
-    (dwl2 "translate-generic-proc-dispatch EXIT 5")
     (make-general-generic-proc-dispatch binder generic-proc arg-types
 					(get-general-generic-class
 					 with-result? appl-pure?)
@@ -1399,14 +1252,14 @@
 		      binder
 		      arg-types
 		      (tno-field-ref generic-proc 'l-methods))))
-      (dwl2 "translate-generic-proc-dispatch/3")
       ;; MIETI puhtauden periytyminen metodeilla.
       (cond
        ((null? selection)
 	(raise 'generic-static-dispatch-error-2))
        ((= (length selection) 1)
 	(let ((best-match (car selection)))
-	  (assert (pair? best-match))
+	  (assert
+	   (and (pair? best-match) (is-method-record? (car best-match))))
 	  (let* ((mtc0 (cdr best-match))
 		 (pure-proc-match? (tno-field-ref mtc0 'pure-proc?))
 		 (always-returns-match?
@@ -1423,8 +1276,7 @@
 		       pure-proc-match?
 		       always-returns-match?
 		       never-returns-match?
-		       (tno-field-ref mtc0 'static-method?)))))
-	    (dwl2 "translate-generic-proc-dispatch/4")
+		       #f))))
 	    (cond
 	     ((not (proc-attr-inherit?
 		    pure-proc-match?
@@ -1439,11 +1291,10 @@
 	     ;; mtc should always be a simple procedure class
 	     ((not (is-tc-simple-proc? mtc))
 	      (raise 'invalid-procedure-2))
-	     ((is-exact-match? binder arg-types mtc)
-	      (dwl2 "translate-generic-proc-dispatch EXIT 1")
-	      (car best-match))
+	     ((or (cdar best-match)
+		  (is-exact-match? binder arg-types mtc))
+	      (caar best-match))
 	     (else
-	      (dwl2 "translate-generic-proc-dispatch EXIT 2")
 	      (make-general-generic-proc-dispatch
 	       binder
 	       generic-proc arg-types mtc with-result?
@@ -1485,7 +1336,6 @@
 		    appl-never-returns?
 		    #f))
 	      (raise 'invalid-attributes-in-dispatch))
-	  (dwl2 "translate-generic-proc-dispatch EXIT 3")
 	  (make-general-generic-proc-dispatch
 	   binder
 	   generic-proc arg-types proc-type with-result?
@@ -1494,7 +1344,6 @@
 	   appl-never-returns?
 	   #t #t))))))
    (else
-    (dwl2 "translate-generic-proc-dispatch EXIT 4")
     (make-general-generic-proc-dispatch binder generic-proc arg-types
 					(get-general-generic-class
 					 with-result? appl-pure?)
@@ -1507,7 +1356,6 @@
 
 (define (translate-general-genproc-appl binder
 					gen-proc arglist type-check?)
-  (dwl3 "translate-general-genproc-appl")
   (assert (hrecord-is-instance? binder <binder>))
   (if (and (not-null? arglist)
 	   (contains-none-value? binder arglist))
@@ -1536,7 +1384,6 @@
 				       binder
 				       type-check? inside-param-def?
 				       runtime-arglist-typecheck?)
-  (dwl3 "do-translate-simple-proc-appl")
   (assert (hrecord-is-instance? proc <entity>))
   (assert (and (list? arguments) (and-map? is-entity? arguments)))
   (assert (or (eq? static-arg-types #f)
@@ -1554,6 +1401,7 @@
 		    (if (not-null? address)
 			(hfield-ref address 'source-name)
 			'()))))))
+   ;; TBD: Change eqv? to eq?
    ((eqv? proc tp-class-of)
     (translate-class-of-appl binder proc arguments))
    ((eqv? proc tp-is-subtype)
@@ -1621,7 +1469,6 @@
    ((eqv? proc tp-field-set)
     (raise 'internal-invalid-field-set!))
    (else
-    (dwl3 "do-translate-simple-proc-appl/1")
     (translate-simple-proc-appl-expression binder
 					   proc arguments
 					   static-arg-types
@@ -1633,7 +1480,6 @@
 (define (translate-param-proc-instance binder to-param-proc
 				       r-type-var-values
 				       type-check?)
-  (dwl4 "translate-param-proc-instance")
   (assert (is-binder? binder))
 ;;  (assert (is-static-entity? to-param-proc))
   (assert (and (list? r-type-var-values)
@@ -1673,7 +1519,6 @@
 (define (translate-param-proc-dispatch binder to-param-proc
 				       r-argument-types
 				       type-check?)
-  (dwl2 "translate-param-proc-dispatch")
   ;; Not sure if incomplete objects work here.
   (assert (is-target-object? to-param-proc))
   (assert (and (list? r-argument-types)
@@ -1702,23 +1547,18 @@
       (hfield-set! binder 'fixed-tvars l-old-fixed)
       ;; Is it OK not to check that all type variables have been
       ;; deduced correctly?
-      (dwl2 "translate-param-proc-dispatch/1")
       (let* ((tvar-bindings (hfield-ref deductions 'bindings))
-	     (tmp1 (begin (dwl2 "translate-param-proc-dispatch/1-1") 0))
 	     (bound-inst-type (bind-type-vars binder
 					      tvar-bindings
 					      inst-type))
-	     (tmp2 (begin (dwl2 "translate-param-proc-dispatch/1-2") 0))
 	     (r-type-var-values (get-type-var-values-from-deductions2
 				 type-variables deductions)))
-	(dwl2 "translate-param-proc-dispatch/2")
 	(if type-check?
 	    (let* ((tt-actual-arglist
 		    (apply make-tuple-type
 			   r-argument-types))
 		   (tt-declared-arglist (tno-field-ref bound-inst-type
 						       'type-arglist)))
-	      (dwl2 "translate-param-proc-dispatch/3")
 	      (if (check-arglist-types? binder tt-actual-arglist
 					tt-declared-arglist)
 		  ;; Should we use r-argument-types instead of
@@ -1732,7 +1572,6 @@
 				r-argument-types)
 		  (raise 'param-proc-dispatch-type-mismatch)))
 	    (begin
-	      (dwl2 "translate-param-proc-dispatch/4")
 	      (make-hrecord <expr-param-proc-dispatch>
 			    bound-inst-type
 			    #t
@@ -1755,7 +1594,6 @@
 
 
 (define (optimize-match-type binder tt-value l-types l-proper-clauses)
-  (dwl3 "optimize-match-type ENTER")
   (let* ((n-clauses (length l-types))
 	 (tt-cur '())
 	 (found? #f)
@@ -1778,7 +1616,6 @@
 				  (list-ref l-clause 2)
 				  opt?))))
 	(if opt? (set! found? #t))))
-    (dwl3 "optimize-match-type EXIT")
     (cons found? l-result)))
 
 
@@ -1824,14 +1661,12 @@
 (define (translate-match-type-expr binder strong? expr-to-match
 				   lst-proper-clauses
 				   expr-else type-check?)
-  (dwl3 "translate-match-type-expr ENTER")
   (let* ((lst-types (map cadr lst-proper-clauses))
 	 (tt-value (get-entity-type expr-to-match))
 	 (x-opt (optimize-match-type binder tt-value lst-types
 				     lst-proper-clauses))
 	 (opt? (car x-opt))
 	 (l-processed-clauses (cdr x-opt)))
-    (dwl3 "translate-match-type-expr/1")
     (if (and type-check?
 	     strong?
 	     (is-empty-expr? expr-else)
