@@ -122,11 +122,11 @@
 
 
 (define-hrecord-type <method-definition> (<expression>)
-  gen-proc procexpr declared? old-address include?)
+  gen-proc procexpr static-method? declared? old-address include?)
 
 
 (define-hrecord-type <method-declaration> (<expression>)
-  gen-proc method include?)
+  gen-proc method static-method? include?)
 
 
 (define-hrecord-type <field-ref-expr> (<dynamic-expression>)
@@ -149,10 +149,6 @@
   clas)
 
 
-(define-hrecord-type <expr-guard-general> (<dynamic-expression>)
-  body exception-var handler)
-
-
 (define-hrecord-type <force-pure-expr> (<dynamic-expression>)
   repr-component)
 
