@@ -31,8 +31,6 @@
 
 
 (define (add-binding s-name address)
-  (dwl3 "add-binding")
-  (dwl3 s-name)
   (assert (symbol? s-name))
   (let* ((x-id (ex:source->syntax1 s-name)) 
 	 (x-mapping (ex:make-global-mapping2 'variable x-id #f address))
@@ -44,7 +42,6 @@
   
 ;; This procedure does not count forward declarations of methods.
 (define (generic-contains-method? address-env r-gen-proc addr-method)
-  (dwl4 "generic-contains-method?")
   (assert (hrecord-is-instance? address-env <address-environment>))
   (assert (hrecord-is-instance? r-gen-proc <target-object>))
   (assert (hrecord-is-instance? addr-method <address>))
@@ -61,12 +58,10 @@
 
 
 (define (parse-internal-variable compiler address-env expr)
-  (dwl4 "parse-internal-variable")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 8)
 		      (eq? (car expr) 'internal-variable)))
-  (dwl4 "parse-internal-variable/1")
   (let ((p-address (list-ref expr 1))
 	(p-type (list-ref expr 2))
 	(type-dispatched? (list-ref expr 3))
@@ -74,7 +69,6 @@
 	(read-only? (list-ref expr 5))
 	(volatile? (list-ref expr 6))
 	(forward-decl? (list-ref expr 7)))
-    (dwl4 "parse-internal-variable/2")
     (let* ((module (get-current-module-name compiler))
 	   (r-address (parse-address module p-address))
 	   (r-type (parse-repr-fwd compiler address-env p-type))
@@ -83,7 +77,6 @@
 				    exact-type? read-only? volatile?
 				    forward-decl?
 				    '() #f)))
-      (dwl4 "parse-internal-variable EXIT")
       var)))
 
 
@@ -95,7 +88,6 @@
 
 
 (define (do-parse-param-class-instance compiler r-param-type r-params)
-  (dwl4 "do-parse-param-class-instance")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (is-target-object? r-param-type))
   (assert (and (list? r-params) (and-map? is-target-object? r-params)))
@@ -107,7 +99,6 @@
 
 
 (define (do-parse-param-type-instance compiler address-env decl expr-class)
-  (dwl4 "do-parse-param-type-instance")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? decl) (= (length decl) 3)))
@@ -126,7 +117,6 @@
 		     (do-parse-param-class-instance compiler r-param-type
 						    r-params)
 		     (raise 'unsupported-type))))
-	    (dwl4 "do-parse-param-type-instance EXIT")
 	    result)
 	  (begin
 	    (dvar1-set! module)
@@ -136,15 +126,12 @@
 
 
 (define (do-parse-var-ref compiler address-env address)
-  (dwl4 "do-parse-var-ref")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (assert (hrecord-is-instance? address <address>))
-  (dvar1-set! address)
   (let ((gv (search-global compiler address)))
     (if (not (eq? gv #f))
 	(begin
-	  (dwl4 "do-parse-var-ref EXIT 1")
 	  (strong-assert (hrecord-is-instance? gv <normal-variable>))
 	  (make-hrecord
 	   <variable-reference>
@@ -164,7 +151,6 @@
 	      ;; Set need-revision? = #f
 	      (cond
 	       ((hrecord-is-instance? var <normal-variable>)
-		(dwl4 "do-parse-var-ref EXIT 2")
 		(make-hrecord
 		 <variable-reference>
 		 (get-entity-type var)
@@ -176,7 +162,6 @@
 		 (hfield-ref var 'value)
 		 var))
 	       ((is-t-type-variable? var)
-		(dwl4 "do-parse-var-ref EXIT 3")
 		(raise 'var-ref-internal-error))
 	       ;; (make-hrecord
 	       ;;  <variable-reference>
@@ -200,7 +185,6 @@
 
 
 (define (parse-var-ref compiler address-env decl)
-  (dwl4 "parse-var-ref")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? decl) (= (length decl) 2)))
@@ -210,7 +194,6 @@
 
 
 (define (parse-object-ref compiler address-env pexpr)
-  (dwl4 "parse-object-ref")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? pexpr) (= (length pexpr) 2)))
@@ -228,7 +211,6 @@
 
 
 (define (parse-tvar compiler address-env pexpr)
-  (dwl4 "parse-tvar")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? pexpr) (= (length pexpr) 2)))
@@ -244,28 +226,8 @@
 
 
 (define (parse-primitive-value compiler address-env decl)
-  (dwl4 "parse-primitive-value")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
-  (strong-assert (and (list? decl) (memv (length decl) '(3 4))))
-  (let* ((type (parse-repr-fwd compiler address-env (list-ref decl 1)))
-	 (ent-contents (parse-repr-fwd compiler address-env (list-ref decl 2)))
-	 (l-opt-contents (if (= (length decl) 4)
-			     (list-ref decl 3)
-			     '()))
-	 (prim-expr (make-primitive-object-w-opt type ent-contents
-						 l-opt-contents)))
-    ;; Maybe we could use equal-types? here.
-    (assert (is-t-subtype? (compiler-get-binder compiler)
-			   (get-entity-type ent-contents) type))
-    prim-expr))
-
-
-(define (parse-primitive-atom compiler address-env decl)
-  (dwl3 "parse-primitive-atom")
-  (assert (hrecord-is-instance? compiler <compiler>))
-  (assert (hrecord-is-instance? address-env <address-environment>))
-  (dwl3 decl)
   (strong-assert (and (list? decl) (= (length decl) 2)))
   (let* ((contents (cadr decl))
 	 (type (get-primitive-type contents))
@@ -274,7 +236,6 @@
 
 
 (define (parse-pair compiler address-env decl)
-  (dwl4 "parse-pair")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? decl) (= (length decl) 3)))
@@ -311,7 +272,6 @@
 
 
 (define (parse-var-def compiler parse-variable! def address read-only?)
-  (dwl4 "parse-var-def")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (procedure? parse-variable!))
   (strong-assert (and (list? def) (= (length def) 5)
@@ -336,7 +296,6 @@
 
 
 (define (parse-field compiler address-env field)
-  (dwl4 "parse-field")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? field) (= (length field) 6)))
@@ -358,7 +317,6 @@
 
 
 (define (parse-field-list compiler address-env field-list)
-  (dwl4 "parse-field-list")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (list? field-list))
@@ -367,7 +325,6 @@
 
 
 (define (parse-class-decl compiler parse-variable! decl address)
-  (dwl4 "parse-class-decl")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (procedure? parse-variable!))
   (strong-assert (and (list? decl) (= (length decl) 8)
@@ -391,19 +348,13 @@
 		   t-superclass t-fields
 		   inheritable? immutable? eq-by-value?
 		   ctr-access))
-
-		 ;; TBR
-		 ;;		 (tmp1 (begin (set! gl-var1 to) 0))
-
 		 (to-decl (parse-variable! to '() tc-class))
 		 (binder (compiler-get-binder compiler)))
 	    (make-constructor! binder to-decl)
-	    (dwl4 "parse-class-decl EXIT")
 	    to)))))
 
 
 (define (parse-param-class-decl compiler parse-variable! decl address)
-  (dwl4 "parse-param-class-decl")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (procedure? parse-variable!))
   (strong-assert (and (list? decl) (= (length decl) 3)
@@ -480,7 +431,6 @@
 
 
 (define (parse-param-proc-class compiler address-env decl)
-  (dwl4 "parse-param-proc-class ENTER")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? decl)
@@ -488,23 +438,16 @@
 		      (eq? (car decl) 'param-proc-class)))
   (let ((p-type-vars (list-ref decl 1))
 	(p-inst-type (list-ref decl 2)))
-    (dwl4 "parse-param-proc-class/1")
     (let* ((module (get-current-module-name compiler))
 	   (r-type-vars (parse-type-variables module p-type-vars))
 	   (local-env (construct-local-address-env address-env r-type-vars))
-	   (tmp2 (begin (dwl4 "parse-param-proc-class/2")
-			(dvar2-set! p-inst-type)
-			0))
 	   (r-inst-type (parse-repr-fwd compiler local-env p-inst-type))
-	   (tmp3 (begin (dwl4 "parse-param-proc-class/3") 0))
 	   (to-ppc (make-param-proc-class-object "instance of :param-proc"
 						 r-type-vars r-inst-type)))
-      (dwl4 "parse-param-proc-class EXIT")
       to-ppc)))
 
 
 (define (parse-general-proc-type compiler address-env expr simple?)
-  (dwl4 "parse-general-proc-type ENTER")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 7)))
@@ -520,7 +463,6 @@
     (strong-assert (boolean? pure-proc?))
     (strong-assert (boolean? appl-always-returns?))
     (strong-assert (boolean? appl-never-returns?))
-    (dwl4 "parse-general-proc-type/2")
     (let ((result
 	   (translate-general-proc-type-expression0
 	    simple?
@@ -530,7 +472,6 @@
 	    appl-always-returns?
 	    appl-never-returns?
 	    static-method?)))
-      (dwl4 "parse-general-proc-type EXIT")
       result)))
 
 
@@ -556,7 +497,6 @@
 
 
 (define (parse-pair-class compiler address-env expr)
-  (dwl4 "parse-pair-class")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 3)))
@@ -584,21 +524,16 @@
 
 
 (define (parse-vector compiler address-env expr)
-  (dwl4 "parse-vector")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? address-env <address-environment>))
   (strong-assert (list? expr))
   (if (not (= (length expr) 2))
       (raise 'internal-invalid-vector))
-  (dvar1-set! expr)
-  (dwl4 "parse-uniform-vector/1")
   (let* ((member-type-expr (list-ref expr 1)) 
 	 (member-type-repr
 	  (parse-repr-fwd compiler address-env member-type-expr)))
-    (dwl4 "parse-uniform-vector/2")
     (let ((result
 	   (translate-vector-expression0 member-type-repr)))
-      (dwl4 "parse-uniform-vector/3")
       result)))
 
 
@@ -651,7 +586,6 @@
 
 
 (define (parse-zero-setting compiler env expr)
-  (dwl4 "parse-zero-setting")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 4)
@@ -710,7 +644,6 @@
 
 
 (define (parse-force-pure-expr compiler env expr)
-  (dwl4 "parse-force-pure-expr")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 2)
@@ -720,7 +653,6 @@
 
 
 (define (parse-rest compiler env expr)
-  (dwl4 "parse-rest")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 2)
@@ -732,7 +664,6 @@
 
 
 (define (parse-cycle compiler env pexpr)
-  (dwl4 "parse-cycle")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? pexpr) (= (length pexpr) 4)
@@ -755,7 +686,6 @@
 
 
 (define (parse-splice compiler env expr)
-  (dwl4 "parse-splice")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 2)
@@ -767,7 +697,6 @@
 
 
 (define (parse-type-list compiler env expr)
-  (dwl4 "parse-type-list")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 2)
@@ -781,7 +710,6 @@
 
 
 (define (parse-type-loop compiler env expr)
-  (dwl4 "parse-type-loop")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 4)
@@ -801,7 +729,6 @@
 
 
 (define (parse-type-join compiler env expr)
-  (dwl4 "parse-type-join")
   (assert (hrecord-is-instance? compiler <compiler>))
   (assert (hrecord-is-instance? env <address-environment>))
   (strong-assert (and (list? expr) (= (length expr) 2)
@@ -827,8 +754,6 @@
 	    (parse-tvar compiler address-env decl))
 	   ((primitive-value)
 	    (parse-primitive-value compiler address-env decl))
-	   ((primitive-atom)
-	    (parse-primitive-atom compiler address-env decl))
 	   ((pair)
 	    (parse-pair compiler address-env decl))
 	   ((param-class-instance)
@@ -880,8 +805,6 @@
 	   ((type-join)
 	    (parse-type-join compiler address-env decl))
 	   (else
-	    (dwl4 decl)
-	    (dvar1-set! decl)
 	    (raise 'unknown-interface-element-2)))))
     (assert (is-entity? result))
     result))
@@ -896,8 +819,6 @@
 				  exact-type? read-only? volatile?
 				  toplevel-bindings?
 				  value value-expr)
-  (dwl4 "interface-bind-variable! ENTER")
-  (dwl4 name)
   (cond
    ((null? name)
     (let* ((ent
@@ -918,7 +839,6 @@
 	  (address-env-add-binding2! env-all address ent))
       ent))
    (reimport?
-    (dwl4 "interface-bind-variable!/1")
     (let* ((env-all (hfield-ref compiler 'env-all))
 	   (env (hfield-ref compiler 'env))
 	   (new-ent (address-env-get-item env-all address))
@@ -935,7 +855,6 @@
 	new-ent)
        (else new-ent))))
    (declared?
-    (dwl4 "interface-bind-variable!/2")
     (let* ((env-all (hfield-ref compiler 'env-all))
 	   (env (hfield-ref compiler 'env))
 	   (old-ent (address-env-get-item env-all address))
@@ -961,38 +880,22 @@
 	  (if (and toplevel? toplevel-bindings? (eq? old-ent2 #f))
 	      (begin
 		(add-symbol! env name var)))
-	  (dwl4 "interface-bind-variable! exit 1")
 	  old-ent))
        ((is-target-object? old-ent)
 	(assert (is-target-object? value))
 	(set-object1! old-ent value)
-	
-	;; TBR
-	(if (eq? name '<complex>)
-	    (begin
-	      (set! gl-var1 old-ent)
-	      (set! gl-var2 value)))
-	;;	      (dvar1-set! old-ent)
-	;;	      (dvar2-set! value)
-	;;	      (raise 'stop)))
-	;;	    (dwl4 "complex HEP"))
-
 	(if (and toplevel? toplevel-bindings? (eq? old-ent2 #f))
 	    (begin
 	      ;; Should we use old-ent instead of value?
 	      (add-symbol! env name value)))
-	(dwl4 "interface-bind-variable! exit 2")
 	old-ent)
        (else (raise 'internal-error)))))
    (else
-    (dwl4 "interface-bind-variable!/3")
     (let* ((ent
 	    (if (and read-only? (not-null? value))
 		(begin
-		  (dwl4 "interface-bind-variable!/3-1")
 		  value)
 		(begin
-		  (dwl4 "interface-bind-variable!/3-2")
 		  (make-normal-variable7
 		   address
 		   type
@@ -1005,17 +908,12 @@
 		   #f))))
 	   (env (hfield-ref compiler 'env))
 	   (env-all (hfield-ref compiler 'env-all)))
-      (dwl4 "interface-bind-variable!/4")
       (address-env-add-binding2! env-all address ent)
-      (dvar1-set! env)
-      (dvar2-set! env-all)
-      (dwl4 "interface-bind-variable!/5")
       (if (and toplevel? toplevel-bindings?)
 	  (begin
 	    (if (symbol-exists? env name)
 		(raise 'duplicate-definition-1)
 		(add-symbol! env name ent))))
-      (dwl4 "interface-bind-variable! exit 3")
       ent))))
 
 
@@ -1049,8 +947,6 @@
 
 (define (import-general-variable compiler def toplevel? reimport? export?
 				 toplevel-bindings?)
-  (dwl3 "import-general-variable")
-  (dwl3 reimport?)
   (let* ((sym (list-ref def 1))
 	 (forward-decl? (list-ref def 2))
 	 (declared? (list-ref def 3))
@@ -1061,8 +957,6 @@
 	 (contents (list-ref def 8))
 	 (content-type (car contents)))
     (hfield-set! compiler 'variable-to-import sym)
-    (dwl3 content-type)
-    (dwl3 sym)
     (strong-assert (or (symbol? sym) (null? sym)))
     (strong-assert (boolean? forward-decl?))
     (strong-assert (boolean? declared?))
@@ -1072,18 +966,15 @@
     (strong-assert (boolean? volatile?))
     (strong-assert (list? contents))
     (strong-assert (symbol? content-type))
-    (dwl3 "import-general-variable/1")
     (let* ((module-name (hfield-ref compiler 'module-name))
 	   (env-all (hfield-ref compiler 'env-all))
 	   (address (parse-address module-name p-address))
 	   (var (address-env-get-item env-all address)))
-      (dwl3 "import-general-variable/2")
       (cond
        ((and (not reimport?)
 	     (not (eq? var #f))
 	     (not (is-forward-decl-entity? var)))
 	(hfield-set! compiler 'variable-to-import '())
-	(dwl3 "import-general-variable EXIT 1")
 	'())
        ;; The following check is probably unnecessary.
        ((not (pair? contents))
@@ -1105,8 +996,6 @@
 					    read-only?
 					    volatile?
 					    toplevel-bindings?))))
-	  (dwl3 "import-general-variable/3")
-	  (dwl3 content-type)
 	  (let ((result
 		 (case content-type
 ;;		   ((obj-ref)
@@ -1128,22 +1017,14 @@
 					    address))
 		   (else
 		    (raise 'invalid-declaration)))))
-	    (dwl3 "import-general-variable/4")
 	    (hfield-set! compiler 'variable-to-import '())
-	    ;;	  (dwl4 (hfield-ref (hfield-ref (hfield-ref result 'variable)
-	    ;;					'address)
-	    ;;			    'source-name))
-	    (dvar1-set! result)
 	    (if (and toplevel-bindings? (not reimport?) (symbol? sym))
 		(add-binding sym address))
-	    (dwl3 (hrecord-type-name-of result))
-	    (dwl3 "import-general-variable EXIT 2")
 	    result)))))))
 
 
 (define (import-gen-proc-def compiler def toplevel? reimport? export?
 			     toplevel-bindings?)
-  (dwl4 "import-gen-proc-def")
   (assert (hrecord-is-instance? compiler <compiler>))
   (strong-assert (and (list? def) (= (length def) 2)))
   (let* ((p-address (cadr def))
@@ -1153,7 +1034,6 @@
 	 (a (symbol-hash-ref (hfield-ref compiler 'ht-globals-by-name) name)))
     (cond
      (reimport?
-      (dwl4 "gp/1")
       (let ((old-var (get-symbol (hfield-ref compiler 'env) name)))
 	(if (eq? old-var #f)
 	    (let ((global-var (search-global compiler address)))
@@ -1163,12 +1043,10 @@
 		      (add-symbol! (hfield-ref compiler 'env) name
 				   global-var)))))))
      ((not (eq? a #f))
-      (dwl4 "gp/2")
       (if (eq? (search-global compiler address) #f)
 	  (let ((ht (compiler-get-globals-by-address compiler)))
 	    (address-hash-set! ht address a))))
      (else
-      (dwl4 "gp/3")
       (assert (eq? (search-global compiler address) #f))
       (let* ((to-clas (make-gen-proc-class-object '()))
 	     (str-name (symbol->string name))
@@ -1190,9 +1068,8 @@
 ;; is already defined. Checking reimport? should take care of that.
 
 (define (import-method compiler def reimport?)
-  (dwl4 "import-method")
   (assert (hrecord-is-instance? compiler <compiler>))
-  (strong-assert (and (list? def) (= (length def) 5)
+  (strong-assert (and (list? def) (= (length def) 6)
 		      (eq? (car def) 'method)))
   ;; Methods are not bound to variables
   ;; even though their internal representations are.
@@ -1201,8 +1078,10 @@
       (let* ((p-gen-proc (list-ref def 1))
 	     (p-type (list-ref def 2))
 	     (p-procexpr (list-ref def 3))
+	     (static? (list-ref def 4))
 	     (module-name (hfield-ref compiler 'module-name))
 	     (address-env (hfield-ref compiler 'env-all)))
+	(strong-assert (boolean? static?))
 	(let* ((addr-gen-proc (parse-address module-name p-gen-proc))
 	       (to-gen-proc (address-hash-ref
 			     (hfield-ref (hfield-ref compiler 'binder)
@@ -1223,14 +1102,14 @@
 			   #f #f
 			   #f '()))
 			 (binder (compiler-get-binder compiler))
-			 (to (add-method-to-generic! binder to-gen-proc to0)))
+			 (to (add-method-to-generic! binder to-gen-proc to0
+						     static?)))
 		    to))))))))
 
 
 (define (import-method-declaration compiler decl level reimport?)
-  (dwl4 "import-method-declaration")
   (assert (hrecord-is-instance? compiler <compiler>))
-  (strong-assert (and (list? decl) (= (length decl) 4)
+  (strong-assert (and (list? decl) (= (length decl) 5)
 		      (eq? (car decl) 'declare-method)))
   ;; Methods are not bound to variables
   ;; even though their internal representations are.
@@ -1238,7 +1117,9 @@
   (if (not reimport?)
       (let ((p-gen-proc (list-ref decl 1))
 	    (p-address (list-ref decl 2))
-	    (p-method-type (list-ref decl 3)))
+	    (p-method-type (list-ref decl 3))
+	    (static? (list-ref decl 4)))
+	(strong-assert (boolean? static?))
 	(let* ((address-env (hfield-ref compiler 'env-all))
 	       (binder (compiler-get-binder compiler))
 	       (module-name (get-current-module-name compiler))
@@ -1249,9 +1130,6 @@
 					      p-method-type))
 	       (address (parse-address module-name p-address))
 	       (t-method (get-method-declaration address r-method-type)))
-	  (dvar1-set! decl)
-	  (dvar2-set! gen-proc)
-	  (dvar3-set! addr-gen)
 	  (strong-assert (is-target-object? gen-proc))
 	  (address-env-add-binding! address-env t-method)
 	  (if (eq? level 'toplevel-interface)
@@ -1265,7 +1143,8 @@
 			     gen-proc r-method-type)))
 	      (add-new-method-to-generic! binder
 					  gen-proc
-					  t-method))))))
+					  t-method
+					  static?))))))
 
 
 (define (reexport-syntax s-name)
@@ -1320,7 +1199,6 @@
 
 (define (import-decl compiler decl level reimport? export?
 		     toplevel-bindings?)
-  (dwl3 "import-decl")
   (assert (hrecord-is-instance? compiler <compiler>))
   (strong-assert (and (list? decl) (= (length decl) 3)))
   (assert (memq level '(toplevel toplevel-interface normal)))
@@ -1341,12 +1219,8 @@
     (strong-assert (boolean? export?))
     (strong-assert read-only?)
     (assert (or (eq? old-ent #f) (is-target-object? old-ent)))
-    (dwl3 "import-decl/1")
-    (dwl3 name)
-    (dwl3 export?)
     (cond
      (reimport?
-      (dwl3 "import-decl/2")
       (if (eq? old-ent #f)
 	  (raise 'reimported-variable-not-found)
 	  (if export?
@@ -1354,7 +1228,6 @@
 		(let ((old-ent2 (get-symbol env name)))
 		  (if (eq? old-ent2 #f)
 		      (begin
-			(dwl4 "import-decl/2-1")
 			(if toplevel-bindings?
 			    (add-symbol! env name old-ent)))
 		      (if (not (address=? address
@@ -1363,7 +1236,6 @@
 		(if (eq? level 'toplevel-interface)
 		    (add-public-decl! compiler old-ent))))))
      ((not (eq? old-ent #f))
-      (dwl3 "import-decl/3")
       (let ((old-type (get-entity-type old-ent)))
 	(cond
 	 ((not (hfield-ref old-ent 'incomplete?))
@@ -1404,7 +1276,6 @@
 			    (raise 'import-decl-duplicate-variable)))))))))))
      ;;		  (add-public-decl! compiler old-var))))))))
      (else
-      (dwl3 "import-decl/4")
       (let ((to (make-target-object
 		 r-type
 		 #t
@@ -1417,10 +1288,8 @@
 		 #f
 		 '())))
 	(address-env-add-binding! env-all to)
-	(dwl4 level)
 	(if (eq? level 'toplevel-interface)
 	    (add-public-decl! compiler to))
-	(dwl3 "import-decl/4-1")
 	(if toplevel-bindings? (add-binding name address))
 	(if export?
 	    (begin
@@ -1436,7 +1305,6 @@
 
 (define (import-mutable-decl compiler decl level reimport? export?
 			     toplevel-bindings?)
-  (dwl4 "import-mutable-decl")
   (assert (hrecord-is-instance? compiler <compiler>))
   (strong-assert (and (list? decl) (= (length decl) 3)))
   (assert (memq level '(toplevel toplevel-interface normal)))
@@ -1456,11 +1324,8 @@
 	 (binder (compiler-get-binder compiler)))
     (strong-assert (boolean? export?))
     (strong-assert (not (and read-only? volatile?)))
-    (dwl4 name)
-    (dwl4 "import-mutable-decl/1")
     (cond
      (reimport?
-      (dwl4 "import-mutable-decl/2")
       (if (eq? old-var #f)
 	  (raise 'reimported-variable-not-found)
 	  (if export?
@@ -1475,7 +1340,6 @@
 		(if (eq? level 'toplevel-interface)
 		    (add-public-decl! compiler old-var))))))
      ((not (eq? old-var #f))
-      (dwl4 "import-mutable-decl/3")
       (let ((old-type (get-entity-type old-var)))
 	(cond
 	 ((not (is-forward-decl? old-var))
@@ -1516,7 +1380,6 @@
 			    (raise 'import-mutable-decl-duplicate-variable)))))))))))
      ;;		  (add-public-decl! compiler old-var))))))))
      (else
-      (dwl4 "import-mutable-decl/4")
       (let* ((to (make-target-object
 		  r-type
 		  #t
@@ -1547,8 +1410,6 @@
 
 (define (import-prim-class-def compiler expr level reimport? export?
 			       toplevel-bindings?)
-  (dwl4 "parse-prim-class-def")
-  (dwl4 export?)
   (assert (hrecord-is-instance? compiler <compiler>))
   (strong-assert (and (list? expr) (= (length expr) 15)
 		      (eq? (car expr) 'prim-class-def)))
@@ -1569,8 +1430,6 @@
 	(equal-objects-target-name (list-ref expr 12))
 	(equal-contents-target-name (list-ref expr 13))
 	(p-zero-address (list-ref expr 14)))
-    (dwl4 "parse-prim-class-def/1")
-    (dwl4 name)
     (strong-assert (string? name))
     (strong-assert (or (symbol? target-name) (null? target-name)))
     (strong-assert (boolean? goops?))
@@ -1590,7 +1449,6 @@
 		   (old-address (if (not (eq? old-var #f))
 				    (hfield-ref old-var 'address)
 				    #f)))
-	      (dwl4 "parse-prim-class-def/2")
 	      (cond
 	       ((eq? new-var #f)
 		(raise 'reimported-variable-not-found))
@@ -1613,7 +1471,6 @@
 		     (r-superclass (parse-repr-fwd compiler env-all
 						   p-superclass)))
 		(strong-assert (is-target-object? r-superclass))
-		(dwl4 "parse-prim-class-def/3")
 		(let* ((module (get-current-module-name compiler))
 		       (r-address (parse-address module p-address))
 		       (r-zero-address
@@ -1628,19 +1485,15 @@
 			    #t #f))
 		       (binder (compiler-get-binder compiler))
 		       (env (hfield-ref compiler 'env)))
-		  (dwl4 "parse-prim-class-def/4")
 		  ;; Custom primitive classes are always declared forward.
 		  (address-env-bind-object! binder env-all #t to)
 		  (if toplevel-bindings?
 		      (add-binding (hfield-ref r-address 'source-name)
 				   r-address))
 		  (hashq-set! ht s-search to)
-		  (dwl4 "parse-prim-class-def/5")
 		  (if (and export? toplevel-bindings?)
 		      (let* ((sym-name2 (hfield-ref r-address 'source-name))
 			     (to-old (get-symbol env sym-name2)))
-			(dwl4 "parse-prim-class-def/5-1")
-			(dwl4 sym-name2)
 			(if (eq? to-old #f)
 			    (raise 'internal-error-with-variables)
 			    (begin
@@ -1648,8 +1501,7 @@
 			      (if (hfield-ref to-old 'incomplete?)
 				  ;; The binding above may have changed to-old,
 				  ;; too.
-				  (set-object1! to-old to))))))
-		  (dwl4 "parse-prim-class-def/6")))
+				  (set-object1! to-old to))))))))
 	      (if goops?
 		  (raise (list 'multiple-goops-class-definitions target-name))
 		  (raise (list 'multiple-prim-class-definitions
@@ -1693,9 +1545,7 @@
 	    
 (define (import-binding compiler def level reimport? export?
 			toplevel-bindings?)
-  (dwl3 "import-binding")
   (assert (memq level '(toplevel toplevel-interface normal)))
-  (dwl4 (car def))
   (if (not (pair? def))
       (raise 'compiled-module-syntax-error)
       (let ((def-type (car def))
@@ -1735,8 +1585,6 @@
 
 (define (import-all-bindings compiler decls level reimport? export?
 			     toplevel-bindings?)
-  (dwl4 "import-all-bindings")
-  (dwl4 reimport?)
   (for-each
    (lambda (binding)
      (import-binding compiler binding level reimport? export?
@@ -1752,10 +1600,9 @@
 		   (hfield-ref compiler 'module-search-path)
 		   (get-actual-module-name module-name)
 		   pcode-interface-ext)))
-    (dwl3 filename)
-    (dwl4 "load-module-interface/0")
     (if (eq? filename #f)
 	(begin
+	  ;; TBD: Move the output to the error module.
 	  (display "filename: ")
 	  (display filename)
 	  (newline)
@@ -1768,13 +1615,11 @@
 	       (name0
 		(theme-read module-file))
 	       (name1 (get-actual-module-name name0)))
-	  (dwl4 "load-module-interface/1")
 	  (cond ((eof-object? name0)
 		 (raise 'unexpected-end-of-module))
 		((not (module-name=? name1 module-name))
 		 (raise 'module-name-mismatch))
 		(else
-		 (dwl4 "load-module-interface/2")
 		 ;; First read the script flag.
 		 (theme-read module-file)
 		 (let* ((first-free-loc (theme-read module-file))
@@ -1783,9 +1628,7 @@
 			(l-used-modules (theme-read module-file))
 			(l-prelinked-bodies (theme-read module-file))
 			(defs (theme-read module-file)))
-		   (dwl4 "load-module-interface/3")
 		   (theme-close-input-port module-file)
-		   (dwl4 "load-module-interface/4")
 		   (strong-assert (and (integer? first-free-loc)
 				       (>= first-free-loc 0)))
 		   (if (eof-object? defs)
@@ -1823,32 +1666,23 @@
 
 
 (define (update-current-env module-name modules)
-;;  (dwli "update-current-env")
-  (dwl3 "update-current-env")
-  (dwl3 module-name)
   (let* ((modules2 (filter-equal-values modules))
 	 (ht-all-exports (hfield-ref gl-expander 'ht-all-exports))
 	 (al-new-env '())
 	 (l-cur-visited '()))
     (do ((l-cur modules2 (cdr l-cur))) ((null? l-cur))
       (let ((module (car l-cur)))
-	(dwli "update-current-env/1")
-	(dwli module)
 	(if (not (member module l-cur-visited))
 	    (let ((alo-exports
 		   (hash-ref ht-all-exports module)))
-	      (dwli "update-current-env/2")
-	      (dvar1-set! alo-exports)
 	      (assert (is-alo? alo-exports))
-	      (dwli "update-current-env/3")
 	      (set! al-new-env
 		    (append al-new-env (hfield-ref alo-exports 'contents)))
 	      (set! l-cur-visited (cons module l-cur-visited))))))
     (let ((x-mod (get-module module-name)))
       (set-car! (car x-mod)
 		(append al-new-env (caar x-mod)))
-      (ex:set-usage-env x-mod))
-    (dwli "update-current-env EXIT")))
+      (ex:set-usage-env x-mod))))
 
 
 (define (import-module compiler module-name hierarchy level export?
@@ -1945,7 +1779,6 @@
 		(if (not reimport?)
 		    (if (eq? level 'toplevel-interface)
 			(begin
-			  (dwli "toplevel HEP")
 			  (update-current-env
 			   actual-module-name
 			   (append imports imports-with-reexports
@@ -1953,22 +1786,6 @@
 			(update-current-env
 			 actual-module-name
 			 (append imports imports-with-reexports))))
-
-;;		(ex:set-usage-env (get-module0 actual-module-name))
-
-		;; (if (equal? actual-module-name
-		;; 	    '(tests test404))
-		;;     (begin
-		;;       (dwl3 reimport?)
-		;;       (dwl3 level)
-		;;       (dwl3 imports)
-		;;       (dwl3 imports-with-reexports)
-		;;       (dwl3 l-interface-imports)
-		;;       (dvar1-set! imports)
-		;;       (raise 'stop-404)))
-
-		(dwli "*1*")
-
 		(let ((alo-old-exports
 		       (hfield-ref gl-expander 'alo-current-exports))
 		      (alo-new-exports
@@ -1981,19 +1798,12 @@
 			       alo-new-exports)
 		  (if (not reimport?)
 		      (begin
-			(dwl3 "exports set")
-			(dwl3 actual-module-name)
 			(hash-set! (hfield-ref gl-expander 'ht-all-exports)
 				   actual-module-name alo-new-exports)))
-		  (dwli "*2*")
-
 		  (hfield-set! gl-expander 'tup-default-module
 			       actual-module-name)
 		  (import-all-bindings compiler defs level
 				       reimport? export? toplevel-bindings?)
-
-		  (dwli "*3*")
-
 		  (hfield-set! gl-expander 'alo-current-exports
 				   alo-old-exports))
 		(hfield-set! compiler 'imported-modules
@@ -2008,8 +1818,6 @@
 
 
 (define (import-toplevel-modules compiler module-names toplevel-bindings?)
-  (dwl3 "import-toplevel-modules")
   (for-each (lambda (mod) (import-module compiler mod '() 'toplevel #t
 					 toplevel-bindings?))
 	    module-names))
-
