@@ -28,16 +28,12 @@
 
 (define-hrecord-type <keyword-define-volatile> (<keyword>))
 
-;; (define-hrecord-type <keyword-define-proc> (<keyword>))
-
 (define-hrecord-type <keyword-define-gen-proc> (<keyword>))
 
-;; (define-hrecord-type <keyword-define-method> (<keyword>))
-
-;; (define-hrecord-type <keyword-define-param-method> (<keyword>))
-
 (define-hrecord-type <keyword-add-method> (<keyword>))
 
+(define-hrecord-type <keyword-add-static-method> (<keyword>))
+
 (define-hrecord-type <keyword-procedure> (<keyword>))
 
 (define-hrecord-type <keyword-procedure-aut> (<keyword>))
@@ -54,8 +50,6 @@
 
 (define-hrecord-type <keyword-define-goops-class> (<keyword>))
 
-;; (define-hrecord-type <keyword-define-normal-goops-class> (<keyword>))
-
 (define-hrecord-type <keyword-param-proc> (<keyword>))
 
 (define-hrecord-type <keyword-param-proc-aut> (<keyword>))
@@ -78,12 +72,6 @@
 
 (define-hrecord-type <keyword-let-volatile> (<keyword>))
 
-;; let* and let*-mutable are implemented as macros.
-
-;; (define-hrecord-type <keyword-let*> (<keyword>))
-
-;; (define-hrecord-type <keyword-let*-variables> (<keyword>))
-
 (define-hrecord-type <keyword-letrec> (<keyword>))
 
 (define-hrecord-type <keyword-letrec-variables> (<keyword>))
@@ -120,10 +108,6 @@
 
 (define-hrecord-type <keyword-until> (<keyword>))
 
-;; (define-hrecord-type <keyword-cond> (<keyword>))
-
-;; (define-hrecord-type <keyword-do> (<keyword>))
-
 (define-hrecord-type <keyword-declare> (<keyword>))
 
 (define-hrecord-type <keyword-declare-mutable> (<keyword>))
@@ -132,16 +116,14 @@
 
 (define-hrecord-type <keyword-declare-method> (<keyword>))
 
-(define-hrecord-type <keyword-constructor> (<keyword>))
+(define-hrecord-type <keyword-declare-static-method> (<keyword>))
 
-;; (define-hrecord-type <keyword-make> (<keyword>))
+(define-hrecord-type <keyword-constructor> (<keyword>))
 
 (define-hrecord-type <keyword-def-param-class> (<keyword>))
 
 (define-hrecord-type <keyword-def-param-logical-type> (<keyword>))
 
-;; (define-hrecord-type <keyword-def-param-proc> (<keyword>))
-
 (define-hrecord-type <keyword-def-param-proc-alt> (<keyword>))
 
 (define-hrecord-type <keyword-define-signature> (<keyword>))
@@ -169,10 +151,6 @@
 
 (define-hrecord-type <keyword-type-join> (<keyword>))
 
-(define-hrecord-type <keyword-guard-general> (<keyword>))
-
-(define-hrecord-type <keyword-exec/cc> (<keyword>))
-
 (define-hrecord-type <keyword-zero> (<keyword>))
 
 (define-hrecord-type <keyword-force-pure-expr> (<keyword>))
@@ -185,6 +163,10 @@
 
 (define-hrecord-type <keyword-strong-assert> (<keyword>))
 
+(define-hrecord-type <keyword-do-assert> (<keyword>))
+
+(define-hrecord-type <keyword-do-strong-assert> (<keyword>))
+
 (define-hrecord-type <keyword-define-syntax> (<keyword>))
 
 (define-hrecord-type <keyword-module-ref> (<keyword>))
@@ -192,12 +174,10 @@
 (define skw-define 'define)
 (define skw-define-variable 'define-mutable)
 (define skw-define-volatile 'define-volatile)
-;; (define skw-define-proc 'define-simple-proc)
 (define skw-define-class 'define-class)
 (define skw-define-gen-proc 'define-generic-proc)
-;; (define skw-define-method 'define-simple-method)
-;; (define skw-define-param-method 'define-param-method)
 (define skw-add-method 'add-method)
+(define skw-add-static-method 'add-static-method)
 (define skw-procedure 'lambda)
 (define skw-procedure-aut 'lambda-automatic)
 (define skw-primitive-procedure 'prim-proc)
@@ -206,7 +186,6 @@
 (define skw-unchecked-param-prim-proc 'unchecked-param-prim-proc)
 (define skw-define-prim-class 'define-prim-class)
 (define skw-define-goops-class 'define-goops-class)
-;; (define skw-define-normal-goops-class 'define-normal-goops-class)
 (define skw-param-proc 'param-lambda)
 (define skw-param-proc-aut 'param-lambda-automatic)
 (define skw-if 'if)
@@ -220,9 +199,6 @@
 (define skw-let 'let)
 (define skw-let-variables 'let-mutable)
 (define skw-let-volatile 'let-volatile)
-;; let* and let*-mutable are implemented as macros.
-;; (define skw-let* 'let*)
-;; (define skw-let*-variables 'let*-mutable)
 (define skw-letrec 'letrec)
 (define skw-letrec-variables 'letrec-mutable)
 (define skw-letrec-volatile 'letrec-volatile)
@@ -241,17 +217,14 @@
 (define skw-quote 'quote)
 (define skw-set 'set!)
 (define skw-until 'until)
-;; (define skw-cond 'cond)
-;; (define skw-do 'do)
 (define skw-declare 'declare)
 (define skw-declare-mutable 'declare-mutable)
 (define skw-declare-volatile 'declare-volatile)
 (define skw-declare-method 'declare-method)
+(define skw-declare-static-method 'declare-static-method)
 (define skw-constructor 'constructor)
-;; (define skw-make 'make)
 (define skw-def-param-class 'define-param-class)
 (define skw-def-param-logical-type 'define-param-logical-type)
-;; (define skw-def-param-proc 'define-param-proc)
 (define skw-def-param-proc-alt 'define-param-proc-alt)
 (define skw-define-signature 'define-signature)
 (define skw-define-param-signature 'define-param-signature)
@@ -267,16 +240,14 @@
 (define skw-type-list ':tuple)
 (define skw-type-loop 'type-loop)
 (define skw-type-join 'join-tuple-types)
-(define skw-guard-general 'guard-general)
-(define skw-exec/cc 'exec/cc)
-(define skw-execute-with-current-continuation
-  'execute-with-current-continuation)
 (define skw-zero 'zero)
 (define skw-force-pure-expr 'force-pure-expr)
 (define skw-static-type-of 'static-type-of)
 (define skw-prevent-stripping 'prevent-stripping)
 (define skw-assert 'assert)
 (define skw-strong-assert 'strong-assert)
+(define skw-do-assert '_assert)
+(define skw-do-strong-assert '_strong-assert)
 (define skw-module-ref '@)
 (define skw-let-syntax 'let-syntax)
 (define skw-letrec-syntax 'letrec-syntax)
@@ -291,12 +262,10 @@
   `((,skw-define ,<keyword-define>)
     (,skw-define-variable ,<keyword-define-variable>)
     (,skw-define-volatile ,<keyword-define-volatile>)
-;;    (,skw-define-proc ,<keyword-define-proc>)
     (,skw-define-class ,<keyword-define-class>)
     (,skw-define-gen-proc ,<keyword-define-gen-proc>)
-;;    (,skw-define-method ,<keyword-define-method>)
-;;    (,skw-define-param-method ,<keyword-define-param-method>)
     (,skw-add-method ,<keyword-add-method>)
+    (,skw-add-static-method ,<keyword-add-static-method>)
     (,skw-procedure ,<keyword-procedure>)
     (,skw-procedure-aut ,<keyword-procedure-aut>)
     (,skw-primitive-procedure ,<keyword-primitive-procedure>)
@@ -306,7 +275,6 @@
     (,skw-unchecked-param-prim-proc ,<keyword-unchecked-param-prim-proc>)
     (,skw-define-prim-class ,<keyword-define-prim-class>)
     (,skw-define-goops-class ,<keyword-define-goops-class>)
-;;    (,skw-define-normal-goops-class ,<keyword-define-normal-goops-class>)
     (,skw-param-proc ,<keyword-param-proc>)
     (,skw-param-proc-aut ,<keyword-param-proc-aut>)
     (,skw-if ,<keyword-if>)
@@ -320,8 +288,6 @@
     (,skw-let ,<keyword-let>)
     (,skw-let-variables ,<keyword-let-variables>)
     (,skw-let-volatile ,<keyword-let-volatile>)
-;;    (,skw-let* ,<keyword-let*>)
-;;    (,skw-let*-variables ,<keyword-let*-variables>)
     (,skw-letrec ,<keyword-letrec>)
     (,skw-letrec-variables ,<keyword-letrec-variables>)
     (,skw-letrec-volatile ,<keyword-letrec-volatile>)
@@ -344,13 +310,10 @@
     (,skw-declare-mutable ,<keyword-declare-mutable>)
     (,skw-declare-volatile ,<keyword-declare-volatile>)
     (,skw-declare-method ,<keyword-declare-method>)
-;;    (,skw-cond ,<keyword-cond>)
-;;    (,skw-do ,<keyword-do>)
+    (,skw-declare-static-method ,<keyword-declare-static-method>)
     (,skw-constructor ,<keyword-constructor>)
-;;    (,skw-make ,<keyword-make>)
     (,skw-def-param-class ,<keyword-def-param-class>)
     (,skw-def-param-logical-type ,<keyword-def-param-logical-type>)
-;;    (,skw-def-param-proc ,<keyword-def-param-proc>)
     (,skw-def-param-proc-alt ,<keyword-def-param-proc-alt>)
     (,skw-define-signature ,<keyword-define-signature>)
     (,skw-define-param-signature ,<keyword-define-param-signature>)
@@ -365,9 +328,6 @@
     (,skw-type-list ,<keyword-type-list>)
     (,skw-type-loop ,<keyword-type-loop>)
     (,skw-type-join ,<keyword-type-join>)
-    (,skw-guard-general ,<keyword-guard-general>)
-    (,skw-exec/cc ,<keyword-exec/cc>)
-    (,skw-execute-with-current-continuation ,<keyword-exec/cc>)
     (,skw-zero ,<keyword-zero>)
     (,skw-force-pure-expr ,<keyword-force-pure-expr>)
     (,skw-static-type-of ,<keyword-static-type-of>)
@@ -375,7 +335,9 @@
     (,skw-define-syntax ,<keyword-define-syntax>)
     (,skw-module-ref ,<keyword-module-ref>)
     (,skw-assert ,<keyword-assert>)
-    (,skw-strong-assert ,<keyword-strong-assert>)))
+    (,skw-strong-assert ,<keyword-strong-assert>)
+    (,skw-do-assert ,<keyword-do-assert>)
+    (,skw-do-strong-assert ,<keyword-do-strong-assert>)))
 
 
 (for-each (lambda (pair)
@@ -394,14 +356,12 @@
 (define gl-may-return 'may-return)
 (define gl-always-returns 'always-returns)
 (define gl-never-returns 'never-returns)
-(define gl-static-method 'static)
 (define gl-match-type-else 'else)
 
 
 (define gl-proc-attributes
   (list gl-pure gl-force-pure gl-nonpure
-	gl-may-return gl-always-returns gl-never-returns
-	gl-static-method))
+	gl-may-return gl-always-returns gl-never-returns))
 
 
 (define gl-access-specifiers (list 'public 'module 'hidden))
