@@ -13,9 +13,13 @@
 	(th-scheme-utilities hrecord))
 
 
-(define gl-l-all-int-lang '(tree-il-2.2 tree-il-2.0 scheme))
+(define gl-l-all-int-lang '(tree-il-3.0 tree-il-2.2 tree-il-2.0
+					scheme scheme-no-opt
+					racket bigloo))
 
-(define gl-l-tree-il-lang '(tree-il-2.2 tree-il-2.0))
+(define gl-l-tree-il-lang '(tree-il-3.0 tree-il-2.2 tree-il-2.0))
+
+(define gl-l-scheme-lang '(scheme scheme-no-opt racket bigloo))
 
 (define gl-i-ht-used-size 20000)
 
@@ -62,6 +66,10 @@
   (memq (hfield-ref linker 's-intermediate-language) gl-l-tree-il-lang))
 
 
+(define (use-racket? linker)
+  (eq? (hfield-ref linker 's-intermediate-language) 'racket))
+
+
 (define (get-first-free-loc linker module-name)
   (let* ((actual-module-name (get-actual-module-name module-name))
 	 (ext (get-pcode-suffix 'body))
@@ -84,9 +92,13 @@
 
 (define (get-interm-file-ext s-int)
   (assert (memq s-int gl-l-all-int-lang))
-  (if (memq s-int gl-l-tree-il-lang)
-      tree-il-file-ext
-      scheme-file-ext))
+  (cond
+   ((memq s-int gl-l-tree-il-lang)
+    tree-il-file-ext)
+   ((eq? s-int 'racket)
+    racket-file-ext)
+   (else
+    scheme-file-ext)))
 
 
 (define (get-pcode-unit-type source-filename)
@@ -99,29 +111,146 @@
      (else (raise 'unable-to-compute-unit-type)))))
 
 
-(define (compile-program-prefix-tree-il linker script?)
-  (list
-   (if script?
-       '(set! (toplevel gl-script?) (const #t))
-       '(set! (toplevel gl-script?) (const #f)))       
-   (if (hfield-ref linker 'runtime-pretty-backtrace?)
-       '(set! (toplevel gl-pretty-backtrace-support?) (const #t))
-       '(set! (toplevel gl-pretty-backtrace-support?) (const #f)))))
+(define (parse-guile-module-name str-module-name)
+  (strong-assert (string? str-module-name))
+  (let ((i-len (string-length str-module-name)))
+    (if (and (> i-len 2)
+	     (eqv? (string-ref str-module-name 0) #\()
+	     (eqv? (string-ref str-module-name (- i-len 1)) #\)))
+	(let* ((str2
+		(substring str-module-name 1 (- i-len 1))))
+	  (map string->symbol (split-string str2 #\space)))
+	(raise (list 'invalid-guile-module-name
+		     (cons 'str-module-name str-module-name))))))
 
-	       
-(define (compile-program-prefix-scheme linker script?)
-  (list
-   '(import (guile))
-   '(import (srfi srfi-1))
-   '(import (rnrs exceptions))
-   '(import (rnrs conditions))
-   '(import (th-scheme-utilities stdutils))
-   (if script?
-       '(set! gl-script? #t)
-       '(set! gl-script? #f))
-   (if (hfield-ref linker 'runtime-pretty-backtrace?)
-       '(set! gl-pretty-backtrace-support? #t)
-       '(set! gl-pretty-backtrace-support? #f))))
+
+(define (compile-program-prefix-tree-il linker script? l-str-custom-modules)
+  (assert (boolean? script?))
+  (assert (and (list? l-str-custom-modules)
+	       (for-all string? l-str-custom-modules)))
+  (let ((l-result
+	 (list
+	  (tc-tree-il-import-target-module
+	   linker '(rnrs))
+	  (tc-tree-il-import-target-module
+	   linker '(srfi srfi-1))
+	  (tc-tree-il-import-target-module
+	   linker '(oop goops))
+	  (tc-tree-il-import-target-module
+	   linker '(th-scheme-utilities stdutils))
+	  (tc-tree-il-import-target-module
+	   linker '(theme-d runtime theme-d-support))
+	  (tc-tree-il-import-target-module
+	   linker '(theme-d runtime theme-d-stdlib-support))
+	  (tc-tree-il-import-target-module
+	   linker '(theme-d runtime runtime-theme-d-environment))))
+	(s-call (tree-il-get-call-keyword linker)))
+    (if (not-null? l-str-custom-modules)
+	(set! l-result
+	      (append
+	       l-result
+	       (map (lambda (str-module)
+		      (tc-tree-il-import-target-module
+		       linker (parse-guile-module-name str-module)))
+		    l-str-custom-modules))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   `(,s-call (toplevel set-theme-d-script!)
+			     (const ,script?)))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   `(,s-call
+		     (toplevel set-pretty-backtrace-support!)
+		     (const
+		      ,(hfield-ref linker 'runtime-pretty-backtrace?))))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   `(,s-call (toplevel theme-set-command-line!)
+			     (,s-call (toplevel command-line))))))
+    l-result))
+
+
+(define (compile-program-prefix-guile linker script?
+				      l-str-custom-modules)
+  (assert (boolean? script?))
+  (assert (and (list? l-str-custom-modules)
+	       (for-all string? l-str-custom-modules)))
+  (let ((l-result
+	 (list
+	  '(import (rnrs))
+	  '(import (srfi srfi-1))
+	  '(import (oop goops))
+	  '(import (th-scheme-utilities stdutils))
+	  '(import (theme-d runtime theme-d-support))
+	  '(import (theme-d runtime theme-d-stdlib-support))
+	  '(import (theme-d runtime runtime-theme-d-environment)))))
+    (if (not-null? l-str-custom-modules)
+	(set! l-result
+	      (append l-result
+		      (list
+		       `(import ,@(map parse-guile-module-name
+				       l-str-custom-modules))))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   `(set-theme-d-script! ,script?))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   `(set-pretty-backtrace-support!
+		     ,(hfield-ref linker 'runtime-pretty-backtrace?)))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   '(theme-set-command-line! (command-line)))))
+    l-result))
+
+
+(define (compile-program-prefix-racket linker script?
+				       l-str-custom-modules
+				       l-str-custom-relative-modules)
+  (assert (and (list? l-str-custom-modules)
+	       (for-all string? l-str-custom-modules)))
+  (assert (and (list? l-str-custom-relative-modules)
+	       (for-all string? l-str-custom-relative-modules)))
+  (let ((l-result
+	 (if (not script?)
+	     (list '(provide main))
+	     '())))
+    (set! l-result
+	  (append
+	   l-result
+	   (list
+	    '(require (except-in rnrs assert))
+	    '(require rnrs/mutable-pairs-6)
+	    '(require theme-d-racket/th-scheme-utilities/stdutils)
+	    '(require theme-d-racket/runtime/runtime-theme-d-environment)
+	    '(require theme-d-racket/runtime/theme-d-alt-support)
+	    '(require theme-d-racket/runtime/theme-d-stdlib-support)
+	    `(set-pretty-backtrace-support!
+	      ,(hfield-ref linker 'runtime-pretty-backtrace?)))))
+    (if (not-null? l-str-custom-modules)
+	(set! l-result
+	      (append l-result
+		      (list
+		       `(require ,@(map string->symbol
+					l-str-custom-modules))))))
+    (if (not-null? l-str-custom-relative-modules)
+	(set! l-result
+	      (append l-result
+		      (list
+		       `(require ,@l-str-custom-relative-modules)))))
+    (set! l-result
+	  (append l-result
+		  (list
+		   '(theme-set-command-line!
+		     ;; The first argument is the program name.
+		     (cons "" (vector->list
+			       (current-command-line-arguments)))))))
+    l-result))
 
 
 (define (not-null-texpr? texpr)
@@ -129,8 +258,6 @@
 
 
 (define (write-module-body file texpr-list pretty-print?)
-  (dwl4 "write-module-body")
-  (dvar1-set! texpr-list)
   (if pretty-print?
       (for-each (lambda (texpr)
 		  (if (not-null-texpr? texpr)
@@ -140,8 +267,7 @@
       (for-each (lambda (texpr)
 		  (if (not-null-texpr? texpr)
 		      (begin (write texpr file) (newline file))))
-		texpr-list))
-  (dwl4 "write-module-body EXIT"))
+		texpr-list)))
 
 
 (define (write-target-expr linker file pretty-print? t-expr)
@@ -160,42 +286,47 @@
   
 
 (define (theme-target-compile-program linker lst-entities)
-  (dwl2 "theme-target-compile-program")
-  (if (use-tree-il? linker)
-      (map-in-order (lambda (entity)
-
-		      ;; TBR
-		      ;; (set! gl-counter28 (+ gl-counter28 1))
-		      ;; (dwl1 "theme-target-compile-program/1")
-		      ;; (dwl1 gl-counter28)
-		      ;; (if (= gl-counter28 600)
-		      ;; 	  (begin
-		      ;; 	    (dwl1 "HEP600")
-		      ;; 	    (set! gl-flag16? #t)))
-		      
-		      (let ((result (tc-tree-il-entity linker entity)))
-			(if (not-null? result) result '(void))))
-		    lst-entities)
-      (map-in-order (lambda (entity) (tc-scheme-entity linker entity))
-		    lst-entities)))
+  (cond
+   ((use-tree-il? linker)
+    (map-in-order (lambda (entity)
+		    (let ((result (tc-tree-il-entity linker entity)))
+		      (if (not-null? result) result '(void))))
+		  lst-entities))
+   ((memq (hfield-ref linker 's-intermediate-language)
+	  '(scheme racket bigloo))
+    (map-in-order (lambda (entity) (tc-scheme-entity linker entity))
+		  lst-entities))
+   ((eq? (hfield-ref linker 's-intermediate-language) 'scheme-no-opt)
+    (map-in-order (lambda (entity) (tcomp-entity linker entity))
+		  lst-entities))
+   (else (raise 'internal-error))))
 
 
 (define (compile-decl-param-proc-instances linker)
   ;; We compute the list in reversed order in order to optimize.
   (let ((instances (reverse (hfield-ref linker 'decl-proc-instances))))
-    (map-in-order (lambda (inst)
-		    (assert (= (length inst) 3))
-		    (let ((var (car inst))
-			  (param-proc (cadr inst))
-			  (type-var-values (caddr inst)))
-		      (if (use-tree-il? linker)
-			  (tc-tree-il-decl-proc-instance linker var
-							 param-proc
-							 type-var-values)
-			  (compile-decl-proc-instance linker var
-						      param-proc
-						      type-var-values))))
-		  instances)))
+    (map-in-order
+     (lambda (inst)
+       (assert (= (length inst) 3))
+       (let ((var (car inst))
+	     (param-proc (cadr inst))
+	     (type-var-values (caddr inst))
+	     (s-lang (hfield-ref linker 's-intermediate-language)))
+	 (cond
+	  ((memq s-lang gl-l-tree-il-lang)
+	   (tc-tree-il-decl-proc-instance linker var
+					  param-proc
+					  type-var-values))
+	  ((memq s-lang '(scheme racket bigloo))
+	   (tc-scheme-decl-proc-instance linker var
+					 param-proc
+					 type-var-values)) 
+	  ((eq? s-lang 'scheme-no-opt)
+	   (compile-decl-proc-instance linker var
+				       param-proc
+				       type-var-values))
+	  (else (raise 'internal-error)))))
+     instances)))
 
 
 (define (theme-link-program-imports linker address-env imports)
@@ -251,7 +382,6 @@
   (assert (is-address? address))
   (assert (hrecord-is-instance? method-def <method-definition>))
   (let ((gen-proc (hfield-ref method-def 'gen-proc)))
-    (dvar1-set! gen-proc)
     (assert (is-entity? gen-proc))
     ;; We may have to check globals-by-address her.
     (let ((ht-used (hfield-ref linker 'ht-used))
@@ -262,11 +392,18 @@
 	       (address-hash-ref ht-used-decls address))
 	(let ((t-var-name (get-target-var-name linker address))
 	      (repr-proc (hfield-ref method-def 'procexpr)))
-	  (if (use-tree-il? linker)
-	      (let ((t-proc (theme-target-tree-il-compile linker repr-proc)))
-		`(set! (toplevel ,t-var-name) ,t-proc))
+	  (cond
+	   ((use-tree-il? linker)
+	    (let ((t-proc (theme-target-tree-il-compile linker repr-proc)))
+	      `(set! (toplevel ,t-var-name) ,t-proc)))
+	   ((memq (hfield-ref linker 's-intermediate-language)
+		  '(scheme racket bigloo))
+	      (let ((t-proc (theme-target-scheme-compile linker repr-proc)))
+		(list 'set! t-var-name t-proc)))
+	   ((eq? (hfield-ref linker 's-intermediate-language) 'scheme-no-opt)
 	      (let ((t-proc (theme-target-compile linker repr-proc)))
-		(list 'set! t-var-name t-proc))))
+		(list 'set! t-var-name t-proc)))
+	   (else (raise 'internal-error))))
 	(if (use-tree-il? linker)
 	    '(void)
 	    '(quote ()))))))
@@ -388,7 +525,6 @@
 
 (define (theme-link-interfaces linker source-filename mod-name unit-type
 			       address-env hierarchy program?)
-  (dwl4 "theme-link-interfaces")
   (assert (hrecord-is-instance? linker <linker>))
   (assert (string? source-filename))
   ;; Module name has to be a list.
@@ -401,7 +537,6 @@
   (dw1 mod-name)
   (dw1 ", ")
   (dwl1 unit-type)
-;;  (dwl4 "*1*") (dp)
   (let ((prev-module (hfield-ref linker 'current-module)))
     (hfield-set! linker 'current-module mod-name)
     (cond
@@ -433,19 +568,15 @@
 	   (not program?))
       (raise 'invalid-program-linkage))
      (else
-      (dwl4 "theme-do-link/1")
-      (dwl4 "new module")
       (let* ((ext (get-pcode-suffix unit-type))
 	     (source-filename1
 	      (if (string-null? source-filename)
 		  (search-file (hfield-ref linker 'module-search-path)
 			       mod-name ext)
 		  source-filename)))
-	(dwl4 "theme-do-link/2")
 	(if (not (eqv? source-filename1 #f))
 	    (let ((source-file
 		   (theme-open-input-file source-filename1)))
-	      (dwl4 "theme-do-link/3")
 	      (let* ((name (theme-read source-file))
 		     (actual-name (if (symbol? name) (list name) name))
 		     (script0? (theme-read source-file))
@@ -461,7 +592,6 @@
 		(theme-close-input-port source-file)
 		(if (not-null? (cdr body))
 		    (raise 'extra-code-in-impl-file))
-		(dwl4 "theme-do-link/4")
 		(if (not (module-name=? mod-name actual-name))
 		    (begin
 		      (display mod-name)
@@ -570,7 +700,6 @@
   (dwl1 "Linking interfaces")
   (theme-link-interfaces linker source-filename mod-name unit-type
 			 address-env '() #t)
-  (dwl1 "Linking interfaces/2")
   (do () ((null? (hfield-ref linker 'l-bodies-to-process)))
     (let ((mn-cur-body (car (hfield-ref linker 'l-bodies-to-process))))
       (hfield-set! linker 'l-bodies-to-process
@@ -865,9 +994,13 @@
 
 
 (define (compile-main linker)
-  (if (use-tree-il? linker)
-      (tc-tree-il-define-main linker)
-      (tc-scheme-define-main linker)))
+  (cond
+   ((use-tree-il? linker)
+    (tc-tree-il-define-main linker))
+   ((use-racket? linker)
+    (tcomp-define-racket-main linker))
+   (else
+    (tcomp-define-main linker))))
 
 
 (define (theme-link-program linker program-name
@@ -876,6 +1009,8 @@
 			    target-filename
 			    module-search-path
 			    s-intermediate-language
+			    l-str-custom-modules
+			    l-str-custom-relative-modules
 			    final-compilation?
 			    keep-intermediate?
 			    link-to-cache?
@@ -943,9 +1078,18 @@
      (hfield-set! linker 'interm-filename interm-filename1)
      (hfield-set! linker 'target-filename target-filename1)
      (let ((l-prefix
-	    (if (use-tree-il? linker)
-		(compile-program-prefix-tree-il linker script?)
-		(compile-program-prefix-scheme linker script?))))
+	    (cond
+	     ((use-tree-il? linker)
+	      (compile-program-prefix-tree-il linker script?
+					      l-str-custom-modules))
+	     ((use-racket? linker)
+	      (compile-program-prefix-racket
+	       linker script?
+	       l-str-custom-modules
+	       l-str-custom-relative-modules))
+	     (else
+	      (compile-program-prefix-guile linker script?
+					    l-str-custom-modules)))))
        (set! l-comp l-prefix))
      (hfield-set! linker 'state 'pcode-reading)
      (theme-do-link-program linker source-filename program-name
@@ -986,14 +1130,12 @@
 	 (set! l-comp
 	       (append l-comp
 		       (compile-used-method-decls linker)))))
-
-     ;; TBR ?
      (dwl1 "Linked the target entities")
      
      (if (not script?)
-	 (set! l-comp (append l-comp (list (compile-main linker)))))
+	 (set! l-comp (append l-comp (compile-main linker))))
 
-     ;; TBR
+     ;; TBR?
      (for-each
       (lambda (sx)
 	(set! gl-counter24 (+ gl-counter24 1))
@@ -1009,6 +1151,9 @@
      
      (dwl1 "Making the intermediate file")
 
+     (if (use-racket? linker)
+	 (display "\n#lang racket\n\n" interm-file))
+     
      (if (use-tree-il? linker)
 	 (let ((l-comp2
 		(tc-tree-il-compile-sequence
@@ -1016,13 +1161,6 @@
 		 (filter-void (handle-tree-il-splices linker l-comp)))))
 	   (if pretty-print?
 	       (begin
-
-		 ;; TBR
-		 ;; (set! gl-counter26 (+ gl-counter26 1))
-		 ;; (dwl1 gl-counter26)
-		 ;; (if (not (is-primitive-value? l-comp2))
-		 ;;     (display "Illegal target expression detected/2.\n"))
-		 
 		 (pretty-print l-comp2 interm-file))
 	       (write l-comp2 interm-file))
 	   (newline interm-file))
@@ -1046,9 +1184,6 @@
 					       interm-filename1)))
 			   0))
 		   (raise 'error-in-final-compilation))
-	       ;; (dwl1 "xxx")
-	       ;; (dwl1 target-filename)
-	       ;; (dwl1 target-filename1)
 	       (if (not (= (system
 			    (if (use-tree-il? linker)
 				(string-append "guild compile "
@@ -1075,6 +1210,8 @@
 ;; so we set backtrace on.
 (define (theme-link-program1 main-module module-search-path
 			     s-intermediate-language
+			     l-str-custom-modules
+			     l-str-custom-relative-modules
 			     script?
 			     final-compilation?
 			     keep-intermediate?
@@ -1089,8 +1226,6 @@
 			     runtime-pretty-backtrace?
 			     module-debug-output?)
   (assert (or (symbol? main-module) (is-module-name? main-module)))
-  (dwl3 "theme-link-program1")
-  (dwl3 strip?)
   (let* ((actual-main-module (get-actual-module-name main-module))
 	 (ext (if script?
 		  (get-pcode-suffix 'script)
@@ -1106,6 +1241,8 @@
 			      source-filename interm-filename target-filename
 			      module-search-path
 			      s-intermediate-language
+			      l-str-custom-modules
+			      l-str-custom-relative-modules
 			      script?
 			      final-compilation?
 			      keep-intermediate?
