@@ -8,10 +8,7 @@
 
 
 (import (rnrs exceptions)
-	(srfi srfi-1)
-	(srfi srfi-35)
-	(th-scheme-utilities stdutils)
-	(th-scheme-utilities hrecord))
+	(srfi srfi-35))
 
 
 (define gl-error '())
@@ -77,7 +74,7 @@
   (let ((lst? (list? exc)))
     (cond
      ((eq? exc 'main-procedure-not-defined)
-      "Main procedure not defined.")
+      "Main procedure not defined")
      ((symbol? exc)
       (string-append "Error " (symbol->string exc)))
      ((null? exc) "Error")
@@ -123,10 +120,10 @@
 		       " in module "
 		       str-module)))
      ((eq? (car exc) 'param-proc-inst:invalid-number-of-parameters)
-      (let ((str-name (cadr exc))
+      (let ((s-name (cadr exc))
 	    (i-count (caddr exc)))
 	(string-append "Invalid number of type parameters for "
-		       str-name
+		       (symbol->string s-name)
 		       " ("
 		       (number->string i-count)
 		       ")")))
@@ -162,12 +159,17 @@
      ((eq? (car exc) 'static-cast-type-mismatch)
       "Type mismatch in a static cast")
      ((eq? (car exc) 'invalid-object-ref)
-      (let ((address (cdr (assq 'address (cdr exc)))))
-	(string-append "Invalid object reference to variable "
-		       (symbol->string (hfield-ref address 'source-name))
-		       " in module "
-		       (convert-module-to-text
-			(hfield-ref address 'module)))))
+      (let* ((address (cdr (assq 'address (cdr exc))))
+	     (s-source-name (hfield-ref address 'source-name)))
+	(if (not-null? s-source-name)
+	    (string-append "Invalid object reference to variable "
+			   (symbol->string s-source-name)
+			   " in module "
+			   (convert-module-to-text
+			    (hfield-ref address 'module)))
+	    (string-append "Invalid object reference in module "
+			   (convert-module-to-text
+			    (hfield-ref address 'module))))))
      ((eq? (car exc) 'module-body-not-found)
       (let ((x-name (cdr (assq 'module-name (cdr exc)))))
 	(string-append "Body for module "
@@ -221,7 +223,7 @@
 	(module (hfield-ref linker 'current-module))
 	(expr (hfield-ref linker 'current-expr))
 	(toplevel-expr (hfield-ref linker 'current-toplevel-expr)))
-    (let ((module-text
+    (let* ((module-text
 	   (if (not-null? module)
 	       (string-append
 		"from module "
@@ -236,8 +238,8 @@
 			 (string-append
 			  "while reading toplevel "
 			  toplevel-expr-text)
-			 "while reading"))
-		   "while reading")
+			 (if module-text "while reading" #f)))
+		   (if module-text "while reading" #f))
 	       (let ((expr-text (get-expr-text expr))
 		     (toplevel-expr-text
 		      (get-pcode-toplevel-expr-text toplevel-expr)))
@@ -256,7 +258,7 @@
 		   (string-append
 		    "while reading expression of type "
 		    expr-text))
-		  (else "while reading"))))))
+		  (else (if module-text "while reading" #f)))))))
       (string-append
        (make-message error-text whole-expr-text module-text) "."))))
 
@@ -507,7 +509,7 @@
 		  (make-instance-compilation-error-message linker exc))
 		 ((binding)
 		  (make-binding-error-message linker exc))
-		 ((()) (make-other-error-message linker exc))
+		 ((() initial) (make-other-error-message linker exc))
 		 (else
 		  "Internal error in error handling.")))))
       (display message)
