@@ -43,7 +43,6 @@
 
 
 (define (inst-handle-type-vars linker repr)
-  (dwli2 "inst-handle-type-vars")
   (let ((prev-state (hfield-ref linker 'state))
 	(binder (get-binder-for-inst linker)))
     (hfield-set! linker 'state 'binding)
@@ -142,27 +141,25 @@
 
 
 (define (factorize-subexprs linker repr fact visited)
-  (dwli2 "factorize-subexprs ENTER")
   (assert (is-linker? linker))
-  (dvar1-set! repr)
   (assert (or (null? repr) (pair? repr) (is-entity? repr)))
   (assert (hrecord-is-instance? fact <singleton>))
   (assert (list? visited))
 
-  (set! gl-counter25 (+ gl-counter25 1))
-  (dwli gl-counter25)
-  (dwi "fact ")
-  (dwc gl-counter25)
-  (dwc " ")
-  (dwc gl-indent)
-  (dwc " ")
-  (if (hrecord? repr)
-      (begin
-	(dwc (hrecord-type-name-of repr))
-	(dwc " ")))
-  (if (is-target-object? repr)
-      (dwc (debug-get-string repr)))
-  (dwli-newline)
+  ;; (set! gl-counter25 (+ gl-counter25 1))
+  ;; (dwli gl-counter25)
+  ;; (dwi "fact ")
+  ;; (dwc gl-counter25)
+  ;; (dwc " ")
+  ;; (dwc gl-indent)
+  ;; (dwc " ")
+  ;; (if (hrecord? repr)
+  ;;     (begin
+  ;; 	(dwc (hrecord-type-name-of repr))
+  ;; 	(dwc " ")))
+  ;; (if (is-target-object? repr)
+  ;;     (dwc (debug-get-string repr)))
+  ;; (dwli-newline)
 
   (let ((old-indent gl-indent))
     (set! gl-indent (+ gl-indent 1))
@@ -183,18 +180,14 @@
 	    ((is-target-object? repr)
 	     (factorize-object linker repr fact))
 	    (else
-	     (dwli2 "factorize-subexprs/1")
 	     (factorize-normal-entity linker repr fact visited)))))
       (set! gl-indent old-indent)
       result)))
 
 
 (define (factorize-instance linker inst fact)
-  (dwl4 "factorize-instance")
-  (dvar1-set! inst)
   (assert (list? inst))
   (assert (memv (car inst) '(class ltype proc raw-proc)))
-  (dwl4 "factorize-instance/1")
   (if (eq? (car inst) 'proc)
       (let* ((old-expr (caddr inst))
 	     (new-expr (factorize-subexprs linker old-expr fact '())))
@@ -242,8 +235,6 @@
 
 
 (define (theme-do-target-instantiate linker repr)
-  (dwl4 "theme-do-target-instantiate")
-  (dwl4 (hrecord-type-name-of repr))
   ;; We clear the ht-fact hash table when we start to process a new toplevel
   ;; expression.
   (hash-clear! (hfield-ref linker 'ht-fact))
@@ -275,12 +266,6 @@
 				(cdr bind-result)))
 		      (inst (make-linker-instances linker (cdr bind-result)))
 		      (bound-expr (car bind-result)))
-
-		 ;; TBR
-		 (dwl4 "theme-do-target-instantiate/1")
-		 (set! gl-ctr11 (+ gl-ctr11 1))
-		 (dwl4 gl-ctr11)
-
 		 (if (hfield-ref linker 'strip?)
 		     (begin
 		       (determine-cov-for-instances linker inst)
@@ -292,7 +277,6 @@
 
 
 (define (theme-target-instantiate linker repr)
-  (dwli2 "theme-target-instantiate ENTER")
   (assert (hrecord-is-instance? linker <linker>))
   (hfield-set! linker 'current-toplevel-repr repr)
   (let ((result
@@ -349,14 +333,12 @@
 	  (else
 	   (theme-do-target-instantiate linker repr)))))
     (hfield-set! linker 'current-toplevel-repr '())
-    (dwli2 "theme-target-instantiate EXIT")
     result))
 
 
 (define (theme-instantiate-program linker lst-reprs)
   (let ((lst-reprs1 (reverse lst-reprs))
 	(binder (hfield-ref linker 'binder-instantiation)))
-;;    (theme-instantiate-program1 linker lst-reprs1)))
     (let ((result '()))
       (do ((lst-cur lst-reprs1 (cdr lst-cur))
 	   (i 0 (+ i 1)))
@@ -386,18 +368,9 @@
 			     (if (not-null? address)
 				 (hfield-ref address 'source-name))
 				 '()))))
-      
-		;; TBR
-		;; (if (= i 429)
-		;;     (begin
-		;;       (dvar1-set! (car lst-cur))
-		;;       (raise 'stop429)))
-		
 		(set! result
 		      (append
 		       result
 		       (theme-target-instantiate linker (car lst-cur))))
 		(hfield-set! binder 's-cur-toplevel '()))
     result)))
-
-
