@@ -57,8 +57,6 @@
 
 
 (define (check-bindings bindings)
-  (dwl3 "check-bindings ENTER")
-  (dvar1-set! bindings)
   (assert (and-map? (lambda (binding)
 		      (and (pair? binding)
 			   (or
@@ -70,8 +68,7 @@
 			     (or
 			      (is-normal-variable? (cdr binding))
 			      (is-target-object? (cdr binding)))))))
-		    bindings))
-  (dwl3 "check-bindings EXIT"))
+		    bindings)))
 
 
 (define (get-param-cache binder)
@@ -106,7 +103,6 @@
 
   
 (define (do-bind-type-vars-apti binder type-vars repr visited)
-  (dwli2 "do-bind-type-vars-apti")
   (assert (is-t-apti? repr))
   (let* ((l-inst '())
 	 (l-subexprs (get-subexpressions repr))
@@ -129,8 +125,6 @@
 	      binder param-type type-args visited))
 	 (repr-new (car pr)))
     (set! l-inst (append l-inst (cdr pr)))
-    (dwli2 "do-bind-type-vars-apti/1")
-    (dwli2 (debug-get-string repr-new))
     (if (eq? repr repr-new)
 	;; Should we have l-inst in the following?
 	(cons repr '())
@@ -144,7 +138,6 @@
 
 ;; Should we handle abstract parametrized types and signatures, too?
 (define (handle-apti-result binder obj)
-  (dwli2 "handle-apti-result")
   (if (and (is-t-apti? obj) (is-t-param-class? (tno-field-ref obj 'type-meta))
 	   (not (equal? (tno-field-ref obj 'l-type-args) '(()))))
       (let ((type-args (tno-field-ref obj 'l-type-args)))
@@ -154,17 +147,14 @@
 	    ;; 			     type-args
 	    ;; 			     #t)
 	    (begin
-	      (dwli2 "handle-apti-result/1")
 	      (translate-param-class-instance-expr
 	       binder
 	       (tno-field-ref obj 'type-meta)
 	       type-args
 	       #f #t))
 	    (begin
-	      (dwli2 "handle-apti-result/2")
 	      obj)))
       (begin
-	(dwli2 "handle-apti-result/3")
 	obj)))
 
 
@@ -201,29 +191,20 @@
 		 repr
 		 translated-subexprs
 		 (hfield-ref binder 'type-check?))))))
-    (dwli2 "do-bind-type-vars00/8")
-    (if (is-target-object? repr)
-	(dwli2 (debug-get-string res2)))
     (cons res2 instantiations)))
 
 
 (define (do-bind-type-vars00 binder type-vars repr visited)
-  ;; (d2wli 'tvar-binding "do-bind-type-vars00")
-  (if (hrecord? repr) (dwli2 (hrecord-type-name-of repr)))
-  (set! gl-counter14 (+ gl-counter14 1))
-  (dwli2 gl-counter14)
   (let ((a (assq repr visited))
 	(i-counter gl-counter14))
     (if (not (eq? a #f))
 	(begin
-	  ;; (dwli2 "do-bind-type-vars00/1")
 	  (if (or (pair? repr) (is-expression? repr))
 	      (raise 'illegal-cycle-2)
 	      (cons (cdr a) '())))
 	(let ((result
 	       (cond
 		((null? repr)
-		 (dwli2 "do-bind-type-vars00/5-1")
 		 (cons '() '()))
 		((hrecord-is-instance? repr <normal-variable>)
 		 (let ((binding (assq repr type-vars)))
@@ -232,25 +213,20 @@
 		       (do-bind-repr binder type-vars repr visited
 				     i-counter))))
 		((is-t-type-variable? repr)
-		 (dwli2 "TVAR")
-		 (dwli2 (debug-get-string repr))
 		 (let ((res1
 			(let ((binding
 			       (assoc repr type-vars type-variable2=?)))
 			  (if (not (eqv? binding #f))
 			      (begin
-				(dwli2 "MATCH")
 				(cdr binding))
 			      repr))))
 		   (cons res1 '())))
 		((and (is-t-apti? repr)
 		      (is-t-param-logical-type?
 		       (tno-field-ref repr 'type-meta)))
-		 (dwli2 "do-bind-type-vars00/5-4")
 		 (do-bind-type-vars-apti binder type-vars repr
 					 visited))
 		((pair? repr)
-		 (dwli2 "do-bind-type-vars00/6-1")
 		 (let* ((l-new-visited (cons (cons repr #f) visited))
 			(pair-inst '())
 			(new-car
@@ -280,10 +256,8 @@
 		    ((hrecord-is-instance? repr <procedure-expression>)
 		     (inst-bind-procedure binder type-vars repr l-new-visited))
 		    ((and
-		      (begin (dwl3 "*1*") #t)
 		      (hrecord-is-instance? repr <proc-appl>)
 		      (proc-appl-is-param? binder repr)
-		      (begin (dwl3 "*2*") (dvar1-set! repr) #t)
 		      (let ((obj-proc-value
 			     (get-entity-value (hfield-ref repr 'proc))))
 			(and (not-null? obj-proc-value)
@@ -291,7 +265,6 @@
 			     (let ((repr-value
 				    (tno-field-ref obj-proc-value
 						   'x-value-expr)))
-			       (dwl3 "*3*")
 			       (and (not-null? repr-value)
 				    (or (hrecord-is-instance? repr-value
 							      <prim-proc-ref>)
@@ -300,13 +273,6 @@
 				    (is-t-instance? binder
 						    (get-entity-type repr-value)
 						    tpc-param-proc))))))
-		     (let ((address
-			    (hfield-ref
-			     (get-entity-value (hfield-ref repr 'proc))
-			     'address)))
-		       (if (not-null? address)
-			   (dwl2 (hfield-ref address 'source-name))))
-
 		     (bind-param-prim-proc-appl binder type-vars repr l-new-visited))
 		    ((and (hrecord-is-instance? repr <expr-param-proc-instance>)
 			  (is-known-object?
@@ -326,7 +292,6 @@
 			  (hfield-ref (hfield-ref (hfield-ref repr 'proc)
 						  'address)
 				      'toplevel?))
-		     (d2wli 'tvar-binding "do-bind-type-vars00/6-4")
 		     (if (and
 			  (hfield-ref repr 'runtime-arglist-typecheck?)
 			  (or (hfield-ref binder 'inside-param-proc?)
@@ -351,7 +316,6 @@
 				      inside-old?)
 			 result2))))))
 		((is-target-object? repr)
-		 (dwli2 "do-bind-type-vars00/5-5")
 		 (let* ((sgt (make-cycle-object repr))
 			(new-visited (cons (cons repr sgt) visited))
 			(result1
@@ -360,23 +324,19 @@
 			   (bind-type-vars-pair-class-fwd binder type-vars
 			  				  repr new-visited))
 			  ((is-tc-param-proc? repr)
-			   (dwli2 "do-bind-type-vars00/6-2")
 			   (inst-bind-param-proc-class binder type-vars repr
 						       new-visited))
 			  ((is-tc-gen-proc? repr)
 			   (inst-bind-gen-proc-class binder type-vars repr
 						     new-visited))
 			  ((is-t-param-class-instance? repr)
-			   (dwli2 "do-bind-type-vars00/6-5")
 			   (let ((res
 				  (bind-type-vars-param-class-fwd binder
 								  type-vars
 								  repr
 								  new-visited)))
-			     (dwli2 "do-bind-type-vars00/6-6")
 			     res))
 			  ((is-t-type-loop? repr)
-			   (dwli2 "do-bind-type-vars00/6-7")
 			   (let ((loop-result
 				  (bind-type-loop-fwd
 				   binder
@@ -384,10 +344,6 @@
 				     (let ((inst-result
 					    (do-bind-type-vars0
 					     binder tvars1 repr1 new-visited)))
-				       
-				       (dwli2 "lambda result:")
-				       (dwli2 (debug-get-string
-					       (car inst-result)))
 				       inst-result))
 				   type-vars
 				   repr
@@ -415,31 +371,24 @@
 			  (else
 			   (do-bind-repr binder type-vars repr
 					 new-visited i-counter)))))
-		   (dwli2 "do-bind-type-vars00/9")
 	 	   (let ((res1 (car result1)))
 		     (cond
 		      ((eq? res1 repr)
-		       (dwli "returning the original value")
 		       result1)
 		      ((is-normal-variable? res1)
-		       (dwli "returning a normal variable")
 		       result1)
 		      ((and
 			(is-target-object? res1)
 			(hfield-ref res1 'incomplete?)
 			(memq res1 (hfield-ref binder 'l-overwrite)))
-		       (dwli "special overwrite")
 		       result1)
 		      (else
-		       (dwli "returning singleton")
-		       (dwli i-counter)
 		       (let ((result2 (handle-apti-result binder
 							  (car result1))))
 			 (update-cycle-object! sgt result2)
 			 (cons sgt (cdr result1))))))))
 		(else
 		 (raise 'do-bind-type-vars00:invalid-input)))))
-	  (dwli "do-bind-type-vars00/10")
 	  result))))
 
 
@@ -477,7 +426,6 @@
 		     (let ((type (get-entity-type repr)))
 		       (or (is-tc-simple-proc? type)
 			   (is-tc-param-proc? type))))
-		(d2wli 'tvar-binding "do-bind-type-vars0/2")
 	       	(cons repr '()))
 	       (else
 		(do-bind-type-vars00 binder type-vars repr
@@ -497,7 +445,6 @@
 	;; 	  (dwli (hrecord-type-name-of repr-result))
 	;; 	  (dwli "?"))))
 	(set! gl-indent old-indent)
-	(dwli2 "do-bind-type-vars0 EXIT")
 	result))))
 
 
@@ -511,14 +458,12 @@
 
 
 (define (do-bind-type-vars binder type-vars repr)
-  (dwli2 "do-bind-type-vars")
   (let ((result
 	 (do-bind-type-vars1 binder type-vars repr '())))
     result))
 
 
 (define (inst-bind-type-vars binder type-vars repr)
-  (dwli2 "inst-bind-type-vars")
   (let ((old-instantiation? (hfield-ref binder 'instantiation?))
 	(old-make-instances? (hfield-ref binder 'make-instances?))
 	(old-type-check? (hfield-ref binder 'type-check?)))
@@ -534,7 +479,6 @@
 
 
 (define (inst-bind-type-vars0 binder type-vars repr)
-  (dwli2 "inst-bind-type-vars0")
   (let ((old-instantiation? (hfield-ref binder 'instantiation?))
 	(old-make-instances? (hfield-ref binder 'make-instances?))
 	(old-type-check? (hfield-ref binder 'type-check?)))
@@ -550,7 +494,6 @@
 
 
 (define (bind-type-vars binder type-vars repr)
-  (dwli2 "bind-type-vars")
   (let ((old-make-instances? (hfield-ref binder 'make-instances?))
 	(old-type-check? (hfield-ref binder 'type-check?)))
     (hfield-set! binder 'make-instances? #f)
@@ -566,7 +509,6 @@
 
 
 (define (bind-type-vars3 binder type-vars repr)
-  (dwli2 "bind-type-vars3")
   (let ((old-make-instances? (hfield-ref binder 'make-instances?))
 	(old-type-check? (hfield-ref binder 'type-check?)))
     (hfield-set! binder 'make-instances? #f)
@@ -581,7 +523,6 @@
 
 
 (define (bind-type-vars-no-check binder type-vars repr)
-  (dwli2 "bind-type-vars-no-check")
   (let ((old-make-instances? (hfield-ref binder 'make-instances?))
 	(old-type-check? (hfield-ref binder 'type-check?)))
     (hfield-set! binder 'make-instances? #f)
@@ -597,8 +538,6 @@
 
 
 (define (bind-type-loop binder bind tvars repr visited)
-  ;;  (dwli2 "bind-type-loop")
-  (dwli2 "bind-type-loop")
   (assert (is-binder? binder))
   (assert (procedure? bind))
   (check-bindings tvars)
@@ -609,19 +548,15 @@
 	(iter-expr (tno-field-ref repr 'x-iter-expr)))
     (let* ((br
 	    (do-bind-type-vars2 binder tvars subtype-list0 visited))
-	   (tmp1 (begin (dwli2 "bind-type-loop/1") 0))
 	   (subtype-list (car br)))
       (cond
        ((is-t-type-variable? subtype-list)
 	(if (eqv? subtype-list subtype-list0)
 	    (begin
-	      (dwli2 "bind-type-loop/2")
 	      (cons repr (cdr br)))
 	    (begin
-	      (dwli2 "bind-type-loop/3")
 	      (let* ((br1 (do-bind-type-vars2 binder tvars iter-expr visited))
 		     (iter-expr1 (car br1)))
-		(dwli2 "bind-type-loop/4")
 		(cons
 		 (make-type-loop-object iter-var subtype-list iter-expr1)
 		 (append (cdr br) (cdr br1)))))))
@@ -632,7 +567,6 @@
 	  (cons (make-tt-uniform-list (car br3))
 		(append (cdr br) (cdr br3)))))
        (else
-	(dwli2 "bind-type-loop/5")
 	(let ((subexprs
 	       (cond
 		((is-t-type-list? subtype-list)
@@ -646,16 +580,12 @@
 		 (dvar2-set! repr)
 		 (dvar3-set! subtype-list)
 		 (raise 'internal-error-in-type-loop-type-list)))))
-	  ;;	    (dwli2 "bind-type-loop/3")
-	  (dwli2 "bind-type-loop/6")
 	  (let* ((br2
 		  (do-bind-loop bind tvars iter-var
 				subexprs
 				iter-expr))
 		 (result
 		  (construct-normal-type-list-repr (car br2))))
-	    ;;	      (dwli2 "bind-type-loop EXIT 2")
-	    (dwli2 "bind-type-loop EXIT 2")
 	    (cons result (append (cdr br) (cdr br2))))))))))
 
 
@@ -702,8 +632,6 @@
 
 ;; This procedure does not accept generic procedure class arguments.
 (define (is-t-pure-proc-class? pc)
-  (dwl4 "is-t-pure-proc-class?")
-  (dvar1-set! pc)
   (cond
    ((or (is-tc-simple-proc? pc) 
 	(is-tt-procedure? pc))
@@ -717,7 +645,6 @@
 
 (define (handle-apply-expr binder deductions repr expr-proc args
 			   new-arg-types inst-type tvars cycles)
-  (d2wli 'tvar-binding "handle-apply-expr ENTER")
   (assert (is-binder? binder))
   (assert (hrecord-is-instance? deductions <type-var-assoc-table>))
   (assert (is-entity? expr-proc))
@@ -726,7 +653,6 @@
   (assert (is-target-object? inst-type))
   (assert (and (list? tvars) (and-map? is-t-type-variable? tvars)))
   (assert (list? cycles))
-  ;; (d2wli 'tvar-binding (tno-field-ref expr-proc 'name))
   (let* ((applied-proc (car args))
 	 (to-proc-type (get-entity-type applied-proc))
 	 ;; It might be sufficient to check only if
@@ -838,7 +764,6 @@
 		       (append new-instantiations
 			       (cdr bind-result2)))
 		 new-proc))))
-	(d2wli 'tvar-binding "handle-apply-expr EXIT 1")
 	(cons
 	 (make-hrecord <proc-appl>
 		       result-type
@@ -882,7 +807,6 @@
 			    #f
 			    '())
 	      '())))
-	(d2wli 'tvar-binding "handle-apply-expr/3-1")
 	result)))))
 
 
@@ -930,7 +854,6 @@
 
 
 (define (make-param-proc-appl1 binder proc arglist ppc r-type-var-values)
-  (dvar1-set! ppc)
   (let* ((inst-type (tno-field-ref ppc 'type-contents))
 	 (result-type
 	  (tno-field-ref inst-type 'type-result))
@@ -980,29 +903,21 @@
 				      new-type-vars all-tvars fixed-tvars
 				      cycles
 				      counter)
-  (d2wli 'tvar-binding "do-bind-type-vars-param-proc")
-  (set! gl-counter11 (+ gl-counter11 1))
-  (d2wli 'tvar-binding gl-counter11)
   (let ((instantiations '())
 	(i-counter gl-counter11))
     (if (and (is-pure-entity? param-proc)
 	     (memv (get-entity-value param-proc)
 		   (list tp-apply-fwd
 			 tp-apply-nonpure-fwd)))
-	(let* ((tmp1
-		(begin (d2wli 'tvar-binding "do-bind-type-vars-param-proc/5-1-1") 0))
-	       (result0
+	(let* ((result0
 		(handle-apply-expr binder deductions repr param-proc
 				   bound-args
 				   new-arg-types
 				   inst-type
 				   all-tvars cycles))
-	       (tmp2 
-		(begin (d2wli 'tvar-binding "do-bind-type-vars-param-proc/5-1-2") 0))
 	       (result1
 		(cons (car result0)
 		      (append instantiations (cdr result0)))))
-	  (d2wli 'tvar-binding "do-bind-type-vars-param-proc/5-1-3")
 	  result1)
 	(if (not-null? fixed-tvars)
 	    (let* ((type-var-bindings (map cons new-type-vars new-tvar-values))
@@ -1018,13 +933,11 @@
 	    ;; (let ((repr-appl (make-param-proc-appl binder param-proc bound-args
 	    ;; 					   inst-type new-tvar-values)))
 	    ;;   (cons repr-appl '()))
-	    (let* ((tmp1 (begin (d2wli 'tvar-binding "do-bind-type-vars-param-proc/5-2") 0))
-		   (param-cache (get-param-cache binder))
+	    (let* ((param-cache (get-param-cache binder))
 		   ;; It is essential that new-tvar-values is in the same order
 		   ;; as new-type-vars.
 		   (old-binding (param-cache-fetch2
 				 param-cache binder param-proc new-tvar-values))
-		   (tmp3 (begin (d2wli 'tvar-binding "do-bind-type-vars-param-proc/5-4") 0))
 		   (old-instance (if old-binding (cdr old-binding) #f))
 		   (new-instance
 		    (if old-instance
@@ -1050,7 +963,6 @@
 				     binder address inst-type new-type-vars
 				     new-tvar-values cycles)))
 			       (obj (car proc-instance))
-			       (tmp2 (begin (d2wli 'tvar-binding "do-bind-type-vars-param-proc/5-6") 0))
 			       (subinst (cadr proc-instance)))
 			  (param-cache-add-binding! param-cache
 						    param-proc
@@ -1087,7 +999,6 @@
 			  obj)))
 		   (new-repr
 		    (begin
-		      (d2wli 'tvar-binding "do-bind-type-vars-param-proc/6")
 		      (if (hfield-ref binder 'optimize-copying?)
 			  (translate-simple-proc-appl-expression1-fwd
 			   binder
@@ -1101,12 +1012,10 @@
 			   binder param-proc bound-args
 			   (get-entity-type new-instance)
 			   new-tvar-values)))))
-	      (debug-write-line-and-indent "do-bind-type-vars-param-proc/8")
 	      (cons new-repr instantiations))))))
 
 
 (define (bind-type-vars-param-proc binder type-vars repr cycles)
-  (d2wli 'tvar-binding "bind-type-vars-param-proc ENTER")
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
@@ -1115,11 +1024,6 @@
   (let ((old-indent gl-indent)
 	(i-counter gl-counter9))
     (set! gl-indent (+ gl-indent 1))
-
-    ;; (dwi2 "indent: ")
-    ;; (dwc2 gl-indent)
-    ;; (dwli-newline2)
-
     (let* ((instantiations '())
 	   (args (hfield-ref repr 'arglist))
 	   (bound-args
@@ -1148,24 +1052,19 @@
 		;; (subresult-pp (do-bind-type-vars binder type-vars param-proc))
 		;; (bound-param-proc (car subresult-pp))
 		;; (param-proc-value (get-expr-value bound-param-proc)))
-		(d2wli 'tvar-binding "bind-type-vars-param-proc/3")
 		(assert (is-target-object? param-proc))
 		(set! instantiations (append instantiations (cdr subresult-pp)))
 		(let* ((to-ppc (get-entity-type param-proc))
 		       (inst-type0 (tno-field-ref to-ppc 'type-contents))
 		       (new-type-vars0 (tno-field-ref to-ppc 'l-tvars))
-		       (tmp1 (begin (dwl2 "bind-type-vars-param-proc/3-1") 0))
 		       (uniq (make-tvars-unique-fwd binder new-type-vars0 inst-type0))
 		       (inst-type (car uniq))
 		       (new-type-vars (cdr uniq))
-		       (tmp2 (begin (dwl2 "bind-type-vars-param-proc/3-2") 0))
 		       (new-arg-types (make-tvars-unique2 binder arg-types))
-		       (tmp3 (begin (dwl2 "bind-type-vars-param-proc/3-3") 0))
 		       ;;	     (src-tvars (get-all-tvars new-arg-types))
 		       (arg-list-desc0
 			(tno-field-ref inst-type 'type-arglist)))
 
-		  (d2wli 'tvar-binding "bind-type-vars-param-proc/4")
 		  (let* ((deductions (get-new-type-var-assoc-table))
 			 (src-tvars (get-all-free-tvars new-arg-types))
 			 (fixed-tvars
@@ -1175,16 +1074,12 @@
 			 (all-tvars 
 			  (append src-tvars new-type-vars))
 			 (old-fixed-tvars (hfield-ref binder 'fixed-tvars)))
-		    (d2wli 'tvar-binding "bind-type-vars-param-proc/5")
 		    (hfield-set! binder 'fixed-tvars fixed-tvars)
 		    (deduce-argument-types binder deductions all-tvars
 					   new-arg-types arg-list-desc0)
 		    (hfield-set! binder 'fixed-tvars old-fixed-tvars)
-		    (d2wli 'tvar-binding
-		     "bind-type-vars-param-proc/5-1")
 		    (cond
 		     ((all-tvars-correct? deductions new-type-vars)
-		      (d2wli 'tvar-binding "bind-type-vars-param-proc/6")
 		      (let* ((new-tvar-values
 			      (get-type-var-values-from-deductions2-fwd
 			       new-type-vars deductions))
@@ -1203,7 +1098,6 @@
 			     (lst-inst (append instantiations (cdr res))))
 			(cons (car res) lst-inst)))
 		      ((not-null? l-bound-default-params)
-		       (d2wli 'tvar-binding "bind-type-vars-param-proc/7")
 		       (let* ((res
 			       (do-bind-type-vars-param-proc
 				binder deductions l-bound-default-params
@@ -1219,8 +1113,6 @@
 			      (lst-inst (append instantiations (cdr res))))
 			(cons (car res) lst-inst)))
 		      (else
-		       (d2wli 'tvar-binding "bind-type-vars-param-proc/8")
-		       (dwl2 i-counter)
 		       (raise (list 'did-not-deduce-all-type-vars-2
 				    (get-proc-name repr)
 				    (cons 'actual-type new-arg-types)
@@ -1237,7 +1129,6 @@
 
 
 (define (bind-type-vars-param-proc-runtime binder type-vars repr cycles)
-  (d2wli 'tvar-binding "bind-type-vars-param-proc-runtime ENTER")
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
@@ -1280,11 +1171,9 @@
 
 (define (inst-make-param-proc-instance2 binder address param-proc
 					type-var-values cycles)
-  (dwl4 "inst-make-param-proc-instance2")
   (assert (is-binder? binder))
   (assert (hrecord-is-instance? address <address>))
   (assert (is-target-object? param-proc))
-  (dwl4 (hrecord-type-name-of param-proc))
   (assert (list? type-var-values))
   (assert (and-map? is-target-object? type-var-values))
   (let* ((instantiations '())
@@ -1344,7 +1233,6 @@
 ;; and <expr-param-proc-dispatch>.
 (define (do-bind-type-vars-param-proc-instance binder type-vars
 					       bound-param-proc params cycles)
-  (dwl4 "do-bind-type-vars-param-proc-instance")
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
@@ -1486,7 +1374,6 @@
 
 
 (define (bind-param-prim-proc-appl binder type-vars repr cycles)
-  (d2wli 'tvar-binding "bind-param-prim-proc-appl ENTER")
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
@@ -1513,7 +1400,6 @@
 	   (new-subreprs (list proc new-arglist l-new-default-params))
 	   (new-repr (cwb-param-proc-appl binder repr new-subreprs #t)))
       (set! gl-indent old-indent)
-      (d2wli 'tvar-binding "bind-param-prim-proc-appl EXIT")
       (cons new-repr instantiations))))
 
 
@@ -1551,14 +1437,12 @@
 
 
 (define (bind-type-vars-param-class binder type-vars repr cycles)
-  (dwli2 "bind-type-vars-param-class ENTER")
   (assert (is-binder? binder))
   (assert (list? type-vars))
 
   (check-bindings type-vars)
 
   (assert (is-t-param-class-instance? repr))
-  (dwli2 "bind-type-vars-param-class/1")
 
   (if gl-test7
       (raise
@@ -1571,13 +1455,10 @@
 	(args (tno-field-ref repr 'l-tvar-values))
 	(old-indent gl-indent))
     (set! gl-indent (+ gl-indent 1))
-    (dwli2 "bind-type-vars-param-class/2")
     (let ((subresult-pc (do-bind-type-vars2 binder type-vars param-class
 					    cycles)))
-      (dwli2 "bind-type-vars-param-class/3")
       (set! instantiations (append instantiations (cdr subresult-pc)))
       (let ((bound-param-class (car subresult-pc)))
-	(dwli2 "bind-type-vars-param-class/4")
 	(let* ((bound-args
 		(let ((subresult (do-bind-type-vars2 binder type-vars args
 						     cycles)))
@@ -1588,22 +1469,14 @@
 		(if (and-map? eq? args bound-args)
 		    (cons repr '())
 		    (begin
-		      (dwli2 "bind-type-vars-param-class/5")
 		      ;; The following test should probably be removed.
 		      ;; (check-no-none-types bound-args)
-		      (dwli2 "bind-type-vars-param-class/5-1")
 		      (if (equal? bound-args '(()))
 			  (cons
 			   (make-apti bound-param-class bound-args)
 			   instantiations)
-			  (let* ((param-list (construct-toplevel-type-repr
-					      binder bound-args))
-				 (tmp0-1 (begin
-					   (dvar1-set! (list repr bound-param-class))
-					   (dvar2-set! bound-args)
-					   (dvar3-set! param-list)
-					   (dvar4-set! type-vars)
-					   (dwli2 "bind-type-vars-param-class/5-0-1") 0)))
+			  (let ((param-list (construct-toplevel-type-repr
+					     binder bound-args)))
 			    (if (is-tuple-type1? binder param-list)
 				(let ((res
 				       (bind-type-vars-normal-param-class
@@ -1630,7 +1503,6 @@
 				      #f #t)
 				     instantiations)))))))))
 	  (set! gl-indent old-indent)
-	  (dwli2 "bind-type-vars-param-class EXIT")
 	  result)))))
 
 
@@ -1681,17 +1553,12 @@
 
 
 (define (bind-type-vars-for-field binder type-vars field cycles)
-  (dwli2 "bind-type-vars-for-field ENTER")
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
-  (dvar1-set! field)
   (assert (is-t-field? field))
   (let ((old-indent gl-indent))
     (set! gl-indent (+ gl-indent 1))
-    ;; (dwli2 (tno-field-ref field 's-name))
-    ;; (dwli2 "original type:")
-    ;; (dwli2 (debug-get-string (tno-field-ref field 'type)))
     (let* ((inst '())
 	   (to-type (tno-field-ref field 'type))
 	   (has-init-value? (tno-field-ref field 'has-init-value?))
@@ -1725,7 +1592,6 @@
 		     (cons 'tt-field to-new-type)
 		     (cons 'tt-init (get-entity-type obj-new-init-value)))))
        (else
-	(dwli2 "bind-type-vars-for-field/2")
 	(let ((result
 	       (if (and (eqv? to-type to-new-type)
 			(eqv? obj-init-value obj-new-init-value))
@@ -1737,15 +1603,11 @@
 		      (make-field sym-name to-new-type acc-read acc-write
 				  has-init-value? obj-new-init-value)
 		      inst)))))
-	  ;; (dwli2 "result type:")
-	  ;; (dwli2 (debug-get-string (tno-field-ref (car result) 'type)))
 	  (set! gl-indent old-indent)
-	  (dwli2 "bind-type-vars-for-field EXIT")
 	  result))))))
 
 
 (define (bind-type-vars-for-field-list binder type-vars field-list cycles)
-  (dwl4 "bind-type-vars-for-field-list")
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
@@ -1768,7 +1630,6 @@
 (define (inst-make-param-class-instance! binder obj
 					 param-class type-var-values
 					 make-ctr? cycles)
-  (dwl4 "inst-make-param-class-instance! ENTER")
   (assert (is-binder? binder))
   (assert (is-target-object? obj))
   (assert (is-target-object? param-class))
@@ -1792,9 +1653,6 @@
       (assert (memq ctr-access gl-access-specifiers))
 					; HUOM. union ja tuple
       (assert (and-map? is-t-type-variable? type-vars))
-      (dvar1-set! param-class)
-      (dvar2-set! type-vars)
-      (dvar3-set! type-var-values)
       (let* ((type-var-bindings (map cons type-vars type-var-values))
 	     (r-superclass
 	      (let* ((binding-result (do-bind-type-vars2
@@ -1857,7 +1715,6 @@
 		(make-constructor-fwd!
 		 binder
 		 obj))
-	    (dwl4 "inst-make-param-class-instance! EXIT")
 	    instantiations)))))))
 
 
@@ -1867,7 +1724,6 @@
 
 (define (inst-make-param-proc-instance binder address inst-type tvars
 				       type-var-values cycles)
-  (dwl4 "inst-make-param-proc-instance")
   (assert (is-binder? binder))
   (assert (hrecord-is-instance? address <address>))
   (assert (list? type-var-values))
@@ -1897,7 +1753,6 @@
 						inst-type tvars
 						type-var-values fixed-tvars
 						cycles)
-  (dwl4 "inst-make-param-proc-instance-w-params")
   (assert (is-binder? binder))
   (assert (hrecord-is-instance? address <address>))
   (assert (string? str-name))
@@ -1930,14 +1785,9 @@
 					       type-var-values name cycles)
   (assert (is-binder? binder))
   (assert (is-target-object? param-proc))
-  (dwl4 (hrecord-type-name-of param-proc))
   (assert (list? type-var-values))
   (assert (and-map? is-target-object? type-var-values))
   (assert (or (symbol? name) (null? name)))
-
-  ;; (d2wli 'tvar-binding "inst-set-param-proc-instance-contents")
-  ;; (d2wli 'tvar-binding name)
-
   (let* ((instantiations '())
 	 (to-ppc (get-entity-type param-proc))
 	 (tvars (tno-field-ref to-ppc 'l-tvars))
@@ -1985,7 +1835,6 @@
 (define (inst-bind-param-proc-class binder type-vars repr cycles)
   (assert (is-binder? binder))
   ;; Note: type-vars contains bindings instead of plain type variables.
-  (d2wli 'tvar-binding "bind-param-proc-class ENTER")
   (let* ((inst-type (tno-field-ref repr 'type-contents))
 	 (bound-tvars (tno-field-ref repr 'l-tvars))
 	 (bind-result
@@ -2008,12 +1857,10 @@
 	     (tno-field-ref repr 'str-name)
 	     new-bound-tvars
 	     new-inst-type)))))
-    (d2wli 'tvar-binding "bind-param-proc-class EXIT")
     (cons new-ppc instantiations)))
 
 
 (define (inst-bind-gen-proc-class binder type-vars repr cycles)
-  (dwl4 "inst-bind-gen-proc-class ENTER")
   ;; Note: type-vars contains bindings instead of plain type variables.
   (assert (is-binder? binder))
   (assert (list? type-vars))
@@ -2034,7 +1881,6 @@
 	    repr
 	    new-method-classes
 	    #t)))
-      (dwl4 "inst-bind-gen-proc-class EXIT")
       (cons new-repr instantiations))))
 
 
@@ -2102,7 +1948,6 @@
 
 (define (inst-make-letrec-letvars binder type-vars letvars old-bindings
 				  readonly? cycles)
-  (dwl4 "inst-make-letrec-letvars")
   (assert (is-binder? binder))
   (check-bindings type-vars)
   (assert (and (list? letvars)
@@ -2151,14 +1996,10 @@
 		      bound-decl-types final-init-exprs
 		      bind-object)
 		 instantiations)))
-	  (dwl4 "inst-make-letrec-letvars EXIT")
 	  result))))
 
 
 (define (inst-bind-let-expression binder type-vars repr cycles)
-  (dwl2 "inst-bind-let-expression")
-  (dwl2 (hfield-ref binder 'type-check?))
-  (dwl2 (hfield-ref binder 'preserve-types?))
   (assert (is-binder? binder))
   (assert (list? type-vars))
   (check-bindings type-vars)
@@ -2185,13 +2026,10 @@
 		   (car bind-result))))
 	 (l-new-init-exprs (map* bind init-exprs))
 	 (l-new-declared-types (map* bind declared-types)))
-    (dwl2 "inst-bind-let-expression/2")
-    (dwl2 l-s-names)
     (for-each (lambda (to-decl-type ent-init-expr s-name)
 		(inst-check-let-variable binder to-decl-type ent-init-expr
 					 s-name))
 	      l-new-declared-types l-new-init-exprs l-s-names)
-    (dwl2 "inst-bind-let-expression/3")
     (let* ((l-new-vars
 	    (map* (lambda
 		      (var-old to-old-type expr-old-init to-new-type
@@ -2224,8 +2062,6 @@
 		    (else (raise 'internal-error)))))
 	      (set! instantiations (append instantiations (cdr result)))
 	      (car result))))
-      (dwl2 "inst-bind-let-expression/5")
-      (dwl2 (length type-vars))
       (if (not (check-no-none-types? binder
 		(map get-entity-type l-new-bindings)))
 	  (raise 'let:type-none))
@@ -2238,9 +2074,6 @@
 	(if (not-null? s-name-none)
 	    (raise (list 'let:initializer-none
 			 (cons 's-name s-name-none)))))
-      (dwl2 "inst-bind-let-expression/6")
-      ;; (set! gl-counter27 (+ gl-counter27 1))
-      ;; (dwl2 gl-counter27)
       (let* ((old-body (hfield-ref repr 'body))
 	     (l-subst (inst-make-let-subst old-bindings l-new-bindings))
 	     (new-body
@@ -2280,8 +2113,6 @@
 			    recursive? order?
 			    final-letvars
 			    new-body)))
-	(dwl2 i-counter)
-	(dwl2 "inst-bind-let-expression EXIT")
 	(cons result instantiations)))))
 
 
@@ -2318,8 +2149,6 @@
   (assert (list? type-vars))
   (check-bindings type-vars)
   (assert (hrecord-is-instance? repr <procedure-expression>))  
-  ;; (d2wli 'tvar-binding "inst-bind-procedure/1")
-  ;; (d2wli 'tvar-binding (hfield-ref binder 'type-check?))
   (let* ((instantiations '())
 	 (i-counter gl-counter26)
 	 (old-arg-descs (hfield-ref repr 'arg-descs))
@@ -2361,7 +2190,6 @@
 	      (let ((result (do-bind-type-vars2 binder type-vars body1 cycles)))
 		(set! instantiations (append instantiations (cdr result)))
 		(car result)))))
-    (d2wli 'tvar-binding "inst-bind-procedure/2")
     (if (or (not (= (length old-arg-descs) (length new-arg-descs)))
 	    (not (and-map? eqv? old-arg-descs new-arg-descs))
 	    (not (eqv? old-result-type new-result-type))
@@ -2389,7 +2217,6 @@
 			    (or (null? impl-arg-types)
 				(not (or-map? contains-type-variables-fwd?
 					      impl-arg-types))))))
-	  (d2wli 'tvar-binding (hfield-ref binder 'type-check?))
 	  (cond
 	   ((and 
 	     typecheck?
@@ -2413,7 +2240,6 @@
 	   (else
 	    ;; Formerly we created a new binder here.
 	    (let ((body-never-returns? (entity-never-returns? new-body)))
-	      (dwl2 "inst-bind-procedure/4")
 	      (if (and typecheck?
 		       (not body-never-returns?)
 		       (not (check-procedure-result-type?
@@ -2421,14 +2247,6 @@
 			     (get-entity-type new-body)
 			     new-result-type)))
 		  (begin
-		    (dvar1-set! new-body)
-		    (dvar2-set! new-result-type)
-		    (dvar3-set! repr)
-		    (dwl2 "mismatch")
-		    (let ((names (hfield-ref repr 'arg-names)))
-		      (dwl2 names))
-		    (dwl2 (debug-get-string (get-entity-type new-body)))
-		    (dwl2 (debug-get-string new-result-type))
 		    (raise
 		     (list 'result-type-mismatch
 			   (cons 'expr-appl repr)
@@ -2474,8 +2292,6 @@
 					appl-always-returns?
 					appl-never-returns?
 					static-method?)))
-		    (dwl2 "inst-bind-procedure EXIT 1")
 		    (cons result-expr instantiations)))))))
 	(begin
-	  (dwl2 "inst-bind-procedure EXIT 2")
 	  (cons repr instantiations)))))
