@@ -1569,15 +1569,6 @@
    member-expr))
 
 
-;; EOF object
-
-
-(define tc-eof (make-builtin-target-class '<eof> tc-object '()
-					  #f #t #t 'public))
-
-(define var-tc-eof (make-object-var tc-eof))
-
-
 ;; Exceptions
 
 (define tc-exception
@@ -1644,7 +1635,7 @@
 
 (define (is-t-atomic-class? tc)
   (if (memv tc (list tc-symbol tc-boolean tc-real tc-integer
-		     tc-string tc-char tc-nil tc-eof))
+		     tc-string tc-char tc-nil))
       #t
       #f))
 
