@@ -299,8 +299,6 @@
 	      (list s-pred x-arg1 x-arg2)))
 	   ((or (not cl1?) (not cl2?))
 	    (scm-make-normal-equiv-expression linker s-kind x-arg1 x-arg2))
-	   ((or (eq? type1 tc-eof) (eq? type2 tc-eof))
-	    (list 'eq? x-arg1 x-arg2))
 	   ((and (is-tc-pair? type1) (is-tc-pair? type2))
 	    (cond
 	     ((eq? s-kind 'equal-objects?)
