@@ -20,16 +20,13 @@
 
 
 (define (make-t-simple-proc t-name tt)
-  (dwl4 "make-t-simple-proc ENTER")
   (assert (symbol? t-name))
   (assert (is-target-object? tt))
   (assert (is-tc-simple-proc? tt))
-  (dvar3-set! tt)
   (let* ((address (alloc-builtin-loc t-name))
 	 (addr-raw-proc (alloc-builtin-raw-loc t-name))
 	 (to (make-procedure tt #t #f address
 			     t-name addr-raw-proc)))
-    (dwl4 "make-t-simple-proc EXIT")
     to))
 
 
@@ -37,7 +34,6 @@
   (assert (symbol? t-name))
   (assert (is-target-object? tt))
   (assert (is-tc-param-proc? tt))
-  (dvar3-set! tt)
   (let* ((address (alloc-builtin-loc t-name))
 	 (to
 	  (make-param-proc-object t-name
@@ -410,7 +406,6 @@
 
 
 (define (translate-const-field-ref binder obj-expr field-name)
-  (dwl4 "translate-const-field-ref")
   (assert (is-binder? binder))
   (assert (is-entity? obj-expr))
   (strong-assert (symbol? field-name))
@@ -450,7 +445,6 @@
 
 (define (translate-const-field-set binder obj-expr field-name
 				   value type-check? inside-param-def?)
-  (dwl4 "translate-const-field-set")
   (assert (is-binder? binder))
   (assert (is-entity? obj-expr))
   (strong-assert (symbol? field-name))
@@ -458,7 +452,6 @@
   (assert (boolean? type-check?))
   (strong-assert (and (not (entity-type-is-none1? binder obj-expr))
 		      (not (entity-type-is-none1? binder value))))
-  (dwl4 "translate-const-field-set/1")
   (let* ((type-expr (get-entity-type obj-expr))
 	 (type-dispatched? (entity-type-dispatched? obj-expr))
 	 (always-returns?
@@ -488,16 +481,13 @@
 		    value))
      ((is-t-instance? binder type-expr tc-class)
       (let ((field (get-field-spec type-expr field-name)))
-	(dwl4 "translate-const-field-set/2")
 	(if (not-null? field)
 	    (let* ((field-type (tno-field-ref field 'type))
 		   (value-type (get-entity-type value)))
-	      (dwl4 "translate-const-field-set/3")
 	      (if (or
 		   (not type-check?)
 		   (is-t-subtype? binder value-type field-type))
 		  (begin
-		    (dwl4 "translate-const-field-set/4")
 		    (make-hrecord <field-set-expr>
 				  tt-none
 				  #t
@@ -602,7 +592,6 @@
 	       (and-map? is-entity? arguments)))
   (assert (boolean? inside-param-def?))
   (check-no-none-arguments binder arguments 'is-subtype?)
-  (dwl1 "translate-is-subtype-appl")
   (if (= (length arguments) 2)
       (let* ((r-type1 (car arguments))
 	     (r-type2 (cadr arguments))
@@ -718,7 +707,6 @@
 
 (define (translate-tuple-ref-appl binder arguments
 				  type-check? inside-param-def?)
-  (dwl4 "translate-tuple-ref-appl")
   (assert (is-binder? binder))
   (strong-assert (and (list? arguments)
 		      (and-map? is-entity? arguments)
@@ -748,7 +736,6 @@
 	  (and inside-param-def?
 	       (or (contains-free-tvars-fwd? r-type)
 		   (contains-free-tvars-fwd? (get-entity-type r-index)))))
-      (dwl4 "translate-tuple-ref-appl/1")
       (make-hrecord <proc-appl>
 		    tc-object
 		    #f
@@ -769,7 +756,6 @@
 		    #t
 		    '()))
      (else
-      (dwl4 "translate-tuple-ref-appl/2")
       (let ((index (hfield-ref r-index 'obj-prim-contents)))
 	;; assert might be sufficient.
 	(strong-assert (integer? index))
@@ -798,7 +784,6 @@
 (define (translate-make-vector-appl binder
 				    proc arguments mutable? eq-by-value?
 				    type-check? inside-param-def?)
-  (dwl3 "translate-make-vector-appl")
   (assert (is-binder? binder))
   (assert (is-entity? proc))
   (assert (and (list? arguments)
@@ -893,7 +878,6 @@
 (define (translate-vector-appl binder
 			       proc arguments mutable? eq-by-value?
 			       type-check? inside-param-def?)
-  (dwl4 "translate-vector-appl")
   (assert (is-binder? binder))
   (assert (is-entity? proc))
   (assert (and (list? arguments)
@@ -1150,7 +1134,6 @@
 (define (translate-cast-vector-metaclass binder
 					 proc arguments mutable? value-vector?
 					 type-check? inside-param-def?)
-  (dwl4 "translate-cast-vector-metaclass")
   (assert (is-binder? binder))
   (assert (is-entity? proc))
   (assert (and (list? arguments)
@@ -1165,7 +1148,6 @@
 			       (if value-vector?
 				   'cast-value-vector-metaclass
 				   'cast-vector-metaclass)))
-  (dvar1-set! arguments)
   (if (= (length arguments) 1)
       (let* ((source-vector (car arguments))
 	     (source-vector-type (get-entity-type source-vector))
