@@ -23,26 +23,10 @@
 
 
 (define (mark-repr-used! repr)
-
-  ;; TBR
-  ;; (if (and (hrecord-is-instance? repr <variable-definition>)
-  ;; 	   (has-name? (hfield-ref repr 'variable) 'matrix-))
-  ;;     (begin
-  ;; 	(dvar1-set! repr)
-  ;; 	(raise 'stop-mark)))
-
   (hfield-set! repr 'include? #t))
 
 
 (define (determine-address-coverage linker address lst-new-visited)
-  (dwli2 "determine-address-coverage ENTER")
-
-  ;; (if (eq? (hfield-ref address 'source-name)
-  ;; 	   'gtk-calendar-select-month)
-  ;;     (begin
-  ;; 	(dvar1-set! address)
-  ;; 	(raise 'cal-stop3)))
-
   (let ((old-indent gl-indent))
     (set! gl-indent (+ gl-indent 1))
     (let ((ht-var-defs (hfield-ref linker 'ht-var-defs))
@@ -65,20 +49,18 @@
 		     linker
 		     (hfield-ref method-def 'procexpr)
 		     lst-new-visited)))))))
-    (set! gl-indent old-indent)
-    (dwli2 "determine-address-coverage EXIT")))
+    (set! gl-indent old-indent)))
 
 
-;; TBR
-(define (address-to-string address)
-  (let ((source-name (hfield-ref address 'source-name)))
-    (string-append
-     (if (not-null? source-name)
-	 (symbol->string (hfield-ref address 'source-name))
-	 "()")
-     "["
-     (number->string (hfield-ref address 'number))
-     "]")))
+;; (define (address-to-string address)
+;;   (let ((source-name (hfield-ref address 'source-name)))
+;;     (string-append
+;;      (if (not-null? source-name)
+;; 	 (symbol->string (hfield-ref address 'source-name))
+;; 	 "()")
+;;      "["
+;;      (number->string (hfield-ref address 'number))
+;;      "]")))
 
 
 (define (determine-coverage linker repr lst-visited)
@@ -86,48 +68,12 @@
 	(ht-method-decls (hfield-ref linker 'ht-method-decls))
 	(ht-used-decls (hfield-ref linker 'ht-used-decls))
 	(ht-used (hfield-ref linker 'ht-used)))
-    (dwli2 "determine-coverage ENTER")
-
-    ;; TBR
-    ;; (if (and (is-target-object? repr)
-    ;; 	     (let ((address (hfield-ref repr 'address)))
-    ;; 	       (and
-    ;; 		(not-null? address)
-    ;; 		(= (hfield-ref address 'number) 155)
-    ;; 		(eq? (hfield-ref address 'source-name) '-))))
-    ;; 	(begin
-    ;; 	  (dwl3 "cov HEP")))
-
     (let ((old-indent gl-indent))
       (set! gl-indent (+ gl-indent 1))
-
-      ;; (dwi2 "column: ")
-      ;; (dwc2 gl-indent)
-      ;; (dwli-newline2)
-
-      ;; TBR
-      ;; (if (hrecord? repr)
-      ;; 	  (begin
-      ;; 	    (dwli2 (hrecord-type-name-of repr)))
-      ;; 	  (begin
-      ;; 	    (dwli2 "?")))
-      ;; (if (is-target-object? repr)
-      ;; 	  (dwli2 (debug-get-string repr)))
-      ;; (if (and (is-entity? repr)
-      ;; 	       (not-null? (hfield-ref repr 'address)))
-      ;; 	  (begin
-      ;; 	    (dwli2 "address: ")
-      ;; 	    (dwli2 (address-to-string (hfield-ref repr 'address)))))
-      ;; (if (and (is-target-object? repr)
-      ;; 	       (not (is-known-object? repr)))
-      ;; 	  (dwli2 "unknown"))
-
       (cond
        ((null? repr)
-	(dwli2 "determine-coverage/1")
 	'())
        ((memq repr lst-visited)
-	(dwli2 "determine-coverage/2")
 	'())
        ;; The following test is an optimization.
        ((and (hrecord-is-instance? repr <variable-definition>)
@@ -142,7 +88,6 @@
 	  (determine-coverage linker (cdr repr) lst-new-visited)))
        ;; We have to check subclasses of <variable-definition> before that.
        ((hrecord-is-instance? repr <generic-procedure-definition>)
-	(dwli2 "determine-coverage/3")
 	(let ((address (hfield-ref (hfield-ref repr 'variable) 'address)))
 	  (if (not (address-hash-ref ht-used address))
 	      (begin
@@ -155,7 +100,6 @@
 	    (hrecord-is-instance? repr <param-logical-type-def>)
 	    (hrecord-is-instance? repr <param-class-definition>)
 	    (hrecord-is-instance? repr <generic-procedure-definition>))
-	(dwli2 "determine-coverage/4")
 	(let ((address (hfield-ref (hfield-ref repr 'variable) 'address)))
 	  (mark-repr-used! repr)
 	  (address-hash-set! ht-used address repr)
@@ -165,29 +109,13 @@
 			(determine-coverage linker repr1 lst-new-visited))
 		      lst-subreprs))))
        ((hrecord-is-instance? repr <prim-class-def>)
-	(dwli2 "determine-coverage/5")
 	(let ((address (hfield-ref (hfield-ref repr 'variable) 'address)))
-
-	  ;; TBR
-	  ;; (if (eq? (hfield-ref address 'source-name) '<gtk-calendar>)
-	  ;;     (begin
-	  ;; 	(dvar1-set! repr)
-	  ;; 	(raise 'cal-stop2)))
-
 	  (address-hash-set! ht-used address repr))
 	(mark-repr-used! repr)
 	(let ((var-superclass (hfield-ref repr 'superclass))
 	      (lst-new-visited (cons repr lst-visited)))
 	  (determine-coverage linker var-superclass lst-new-visited)))
        ((hrecord-is-instance? repr <variable-definition>)
-	(dwli2 "determine-coverage/6")
-
-	;; TBR
-	;; (if (has-name? (hfield-ref repr 'variable) 'gtk-calendar-select-month)
-	;;      (begin
-	;;        (dvar1-set! repr)
-	;;        (raise 'cal-stop1)))
-
 	(let ((address (hfield-ref (hfield-ref repr 'variable) 'address))
 	      (lst-new-visited (cons repr lst-visited)))
 	  (mark-repr-used! repr)
@@ -195,7 +123,6 @@
 	  (determine-coverage linker (hfield-ref repr 'value-expr)
 			      lst-new-visited)))
        ((hrecord-is-instance? repr <variable-reference>)
-	(dwli2 "determine-coverage/7")
 	(let ((var (hfield-ref repr 'variable)))
 	  ;; Variables without a toplevel definition
 	  ;; need not be checked for coverage.
@@ -205,19 +132,10 @@
 	      (let ((lst-new-visited (cons repr lst-visited)))
 		(determine-coverage linker var lst-new-visited)))))
        ((hrecord-is-instance? repr <normal-variable>)
-	(dwli2 "determine-coverage/8")
 	(let ((address (hfield-ref repr 'address))
 	      (lst-new-visited (cons repr lst-visited)))
 	  (determine-address-coverage linker address lst-new-visited)))
        ((is-entity? repr)
-	(dwli2 "determine-coverage/9")
-
-	;; TBR
-	;; (if (has-name? repr 'gtk-calendar-select-month)
-	;;      (begin
-	;;        (dvar1-set! repr)
-	;;        (raise 'cal-stop2)))
-
 	(let ((lst-subreprs (get-subexpressions repr))
 	      (lst-new-visited (cons repr lst-visited))
 	      (address (hfield-ref repr 'address)))
@@ -229,8 +147,7 @@
        (else
 	(dvar1-set! repr)
 	(raise 'determine-coverage:invalid-object)))
-      (set! gl-indent old-indent)
-      (dwli2 "determine-coverage EXIT"))))
+      (set! gl-indent old-indent))))
 
 
 (define (mark-method-for-coverage linker repr def? lst-visited)
@@ -269,8 +186,6 @@
 	     (if (null? address)
 		 (begin
 		   ;; This is an error situation.
-		   (dwl4 "null 2")
-		   (dvar1-set! repr)
 		   (raise 'error-with-prevent-stripping-expr)))
 	     (determine-address-coverage linker address '()))))
      lst-reprs)))
@@ -309,14 +224,6 @@
 
 
 (define (include-in-stripping? expr)
-
-  ;; TBR
-  ;; (if (and (hrecord-is-instance? expr <variable-definition>)
-  ;; 	   (has-name? (hfield-ref expr 'variable) 'console-write))
-  ;;     (begin
-  ;; 	(dvar1-set! expr)
-  ;; 	(raise 'stop-write)))
-
   (not (or
 	(and (hrecord-is-instance? expr <variable-definition>)
 	     (let ((expr-value (hfield-ref expr 'value-expr)))
@@ -345,5 +252,3 @@
 		(if (include-in-stripping? repr)
 		    (determine-coverage linker repr '())))
 	      l-reprs)))
-
-	
