@@ -9,6 +9,9 @@
 (import (th-scheme-utilities stdutils))
 
 
+(define gl-i-max-ebv-opt 10)
+
+
 (define gl-l-prim-pred
   (list (cons tc-nil 'null?)
 	(cons tc-symbol 'symbol?)
@@ -19,6 +22,50 @@
 	(cons tc-char 'char?)))
 
 
+(define gl-al-prim-equal
+  (list (cons tc-nil 'eq?)
+	(cons tc-boolean 'eq?)
+	(cons tc-integer 'eqv?)
+	(cons tc-real 'eqv?)
+	(cons tc-symbol 'eq?)
+	(cons tc-string 'equal?)
+	(cons tc-char 'eqv?)))
+
+
+(define gl-al-prim-equal-contents gl-al-prim-equal)
+
+
+(define gl-al-prim-equal-objects
+  (list (cons tc-nil 'eq?)
+	(cons tc-boolean 'eq?)
+	(cons tc-integer 'eqv?)
+	(cons tc-real 'eqv?)
+	(cons tc-symbol 'eq?)
+	(cons tc-string 'eqv?)
+	(cons tc-char 'eqv?)))
+
+
+(define gl-al-target-eq-pred
+  (list (cons 'equal-values? 'theme-equal?)
+	(cons 'equal-objects? 'theme-equal-objects?)
+	(cons 'equal-contents? 'theme-equal-contents?)))
+
+
+(define (get-equiv-pred s-kind cl)
+  (let* ((al
+	  (case s-kind
+	    ((equal-values?) gl-al-prim-equal)
+	    ((equal-objects?) gl-al-prim-equal-objects)
+	    ((equal-contents?) gl-al-prim-equal-contents)
+	   (else (raise 'internal-error))))
+	 (p (assq cl al)))
+    (if p (cdr p) #f)))
+
+
+(define (get-ht-raw-procs linker)
+  (hfield-ref (hfield-ref linker 'binder-instantiation) 'ht-raw-procs))
+
+
 (define (get-target-new-name linker module number source-name)
   (cond
    ((and (not (eqv? module #f)) (>= number 0))
@@ -63,10 +110,8 @@
 
 
 (define (get-target-var-name linker address)
-  (dwl4 "get-target-var-name")
   (assert (hrecord-is-instance? linker <linker>))
   (assert (hrecord-is-instance? address <address>))
-  (dwl4 "get-target-var-name/1")
   (let* ((ht-lexical-vars (hfield-ref linker 'ht-lexical-vars))
 	 (sym-var-name (address-hash-ref ht-lexical-vars address)))
     (if sym-var-name
@@ -74,20 +119,10 @@
 	(let ((module (hfield-ref address 'module))
 	      (number (hfield-ref address 'number))
 	      (source-name (hfield-ref address 'source-name)))
-	  (dwl4 "get-target-var-name/2")
-
-	  ;; TBR
-	  (if (not (or (boolean? module) (eqv? module 'builtins)
-		       (is-module-name? module)))
-	      (begin
-		(dwl1 module)
-		(dwl1 source-name)))
-	  
 	  (assert (or (boolean? module) (eqv? module 'builtins)
 		      (is-module-name? module)))
 	  (assert (integer? number))
 	  (assert (or (null? source-name) (symbol? source-name)))
-	  (dwl4 "get-target-var-name/3")
 	  (let ((sym-new-name (get-target-new-name linker module number
 						   source-name)))
 	    (address-hash-set! ht-lexical-vars address sym-new-name)
@@ -98,8 +133,6 @@
 
 
 (define (do-compile-value obj)
-  (dwli2 "do-compile-value")
-  (dvar1-set! obj)
   (assert (is-target-object? obj))
   (cond
    ((eqv? obj to-nil) '())
@@ -135,7 +168,6 @@
 
 
 (define (get-constructor-field-args fields)
-  (dwli2 "get-constructor-field-args")
   (let ((len (length fields))
 	(args '()))
     (do ((i 1 (+ i 1)) (cur-lst fields (cdr cur-lst)))
@@ -186,3 +218,26 @@
 
 (define (linker-entity-is-none? linker ent)
   (entity-is-none1? (get-binder-for-tc linker) ent))
+
+
+(define (is-simple-arg-list2? arg-descs)
+  ;; The following expression is #t for an empty list.
+  (not (or-map? (lambda (ent)
+		  (or (is-t-rest? ent) (is-t-splice? ent)))
+		arg-descs)))
+
+
+(define (is-simple-arg-list-with-tail? arg-descs)
+  (and (not-null? arg-descs)
+       (let ((ent-last (last arg-descs)))
+	 (or (is-t-rest? ent-last) (is-t-splice? ent-last)))
+       ;; The following expression is #t for a single element list.
+       (not (or-map? (lambda (ent)
+		       (or (is-t-rest? ent) (is-t-splice? ent)))
+		     (drop-right arg-descs 1)))))
+
+
+(define (get-gensyms linker lst-args)
+  (map (lambda (arg)
+	 (get-target-var-name linker (hfield-ref arg 'address)))
+       lst-args))
