@@ -32,7 +32,6 @@
 
 
 (define (translate-actual-arglist-type arglist)
-  (dwl4 "translate-actual-arglist-type")
   (let* ((arg-types (map
 		     (lambda (arg) (get-entity-type arg))
 		     arglist)))
@@ -43,7 +42,6 @@
 
 
 (define (get-arglist-type-from-list arg-types)
-  (dwl4 "get-arglist-type-from-list")
   (if (not-null? arg-types)
       (apply make-tuple-type arg-types)
       ;; Formerly we had tt-none here.
@@ -51,7 +49,6 @@
 
 
 (define (check-arglist-types? binder tt-actual tt-declared)
-  (dwl4 "check-arglist-types?")
   (assert (is-binder? binder))
   (let ((decl-none? (entity-is-none1? binder tt-declared)))
     (cond
@@ -83,48 +80,13 @@
       contains-duplicate-field-names?)
 
 
-(define (compute-quoted-object expr expr-opt)
-  (dwl4 "compute-quoted-object")
-  (dwl4 expr)
-  (cond
-   ((null? expr)
-    (cons to-nil tc-nil))
-   ((pair? expr)
-    (let* ((first (compute-quoted-object (car expr) '()))
-	   (first-value (car first))
-	   (first-type (cdr first))
-           (second (compute-quoted-object (cdr expr) '()))
-	   (second-value (car second))
-	   (second-type (cdr second))
-	   (type
-	    (make-tpci-pair first-type second-type))
-	   (exact-type?
-	    (and (hfield-ref first-value 'exact-type?)
-		 (hfield-ref second-value 'exact-type?)))
-	   (to
-	    ;; This works also when expr-opt is null.
-	    (make-target-object-w-opt
-	     type
-	     #t exact-type? '()
-	     #t #f
-	     `((first . ,first-value)
-	       (second . ,second-value))
-	     '()
-	     expr-opt)))
-      (cons to type)))
-   (else
-    (let* ((type (get-primitive-type expr))
-	   (to (make-primitive-object type expr)))
-      (cons to type)))))
-
-
 (define (translate-quoted-expression expr)
-  (dwl4 "translate-quoted-expression")
-  (car (compute-quoted-object expr expr)))
+  (let* ((type (get-primitive-type expr))
+	 (to (make-primitive-object type expr)))
+    to))
 
 
 (define (make-new-gen-proc address exported?)
-  (dwl4 "make-new-gen-proc")
   (let* ((to-clas (make-gen-proc-class-object '()))
 	 (name (hfield-ref address 'source-name))
 	 (str-name (symbol->string name))
@@ -140,7 +102,7 @@
     var))
 
 
-(define (get-method-declaration-repr genproc method-obj)
+(define (get-method-declaration-repr genproc method-obj static?)
   (assert (is-t-gen-proc? genproc))
   (assert (is-target-object? method-obj))
   (make-hrecord
@@ -149,10 +111,12 @@
    #f #f #f '()
    genproc
    method-obj
+   static?
    #f))
 
 
-(define (get-method-definition-repr genproc procexpr declared? old-address)
+(define (get-method-definition-repr genproc procexpr static? declared?
+				    old-address)
   (assert (is-target-object? genproc))
   (assert (is-entity? procexpr))
   (assert (boolean? declared?))
@@ -169,6 +133,7 @@
    '()
    genproc
    procexpr
+   static?
    declared?
    old-address
    #f))
