@@ -132,7 +132,6 @@
 
 
 (define (gen-tuple-type->list0 binder tuple-type visited)
-  (dwl4 "gen-tuple-type->list0")
   (cond
    ((or (null? tuple-type) (eqv? tuple-type tc-nil))
     '())
@@ -166,9 +165,6 @@
     (tuple-type-ref (tt-cdr tuple-type) (- index 1)))))
 
 
-(dwl4 "*1*")
-
-
 (define (make-irregular-union lst-members)
   (make-apti tmt-union lst-members))
 
@@ -216,7 +212,6 @@
 
 (define (translate-pair-class-expression binder
 					 type-args)
-  (dwl4 "translate-pair-class-expression ENTER")
   (assert (is-binder? binder))
   (assert (and (list? type-args)
 	       (and-map? is-entity? type-args)))
@@ -292,7 +287,6 @@
 
 
 (define (join-tuple-types . tuple-types)
-  (dwl4 "join-tuple-types")
   (if (null? tuple-types)
       tc-nil
       (join-two-tuple-types (car tuple-types)
@@ -314,7 +308,6 @@
   (assert (boolean? always-returns?))
   (assert (boolean? never-returns?))
   (assert (boolean? static-method?))
-  (dwl4 "translate-general-proc-type-expression0/0-1")
   (make-tpti-general-proc simple? arg-list-desc result-type
 			  pure? always-returns? never-returns?
 			  static-method?))
@@ -325,7 +318,6 @@
 	 arg-desc-exprs result-type-desc pure?
 	 always-returns? never-returns?
 	 static-method?)
-  (dwl4 "translate-general-proc-type-expression")
   (assert (is-binder? binder))
   (assert (boolean? simple?))
   (assert (list? arg-desc-exprs))
@@ -335,10 +327,8 @@
   (assert (boolean? always-returns?))
   (assert (boolean? never-returns?))
   (assert (boolean? static-method?))
-  (dwl4 "translate-general-proc-type-expression/1")
   (let ((arg-list-desc
 	 (construct-toplevel-type-repr binder arg-desc-exprs)))
-    (dwl4 "translate-general-proc-type-expression/2")
     (translate-general-proc-type-expression0
      simple?
      arg-list-desc result-type-desc pure?
@@ -362,9 +352,6 @@
    always-returns? never-returns? static-method?))
 
 
-(dwl4 "*4*")
-
-
 (define tt-general-procedure
   (make-tpti-general-proc
    #f
@@ -397,9 +384,6 @@
    #f #f #f #f))
 
 
-(dwl4 "2-1")
-
-
 (define tt-general-function
   (make-tpti-general-proc
    #f
@@ -434,9 +418,6 @@
    #t #f #f #f))
 
 
-(dwl4 "3*")
-
-
 (define (translate-vector-expression0 member-type)
   (make-tpci-vector member-type member-type))
 
@@ -533,28 +514,6 @@
 (define (translate-param-class-instance-expr binder param-class type-args
 					     inside-param-def?
 					     make-ctr?)
-  (dwl3 "translate-param-class-instance-expr")
-
-  ;; TBR
-  ;; (set! gl-counter13 (+ gl-counter13 1))
-  ;; (dwl3 gl-counter13)
-  ;; (if (= gl-ctr 21)
-  ;;     (begin
-  ;; 	(dvar1-set! param-class)
-  ;; 	(dvar2-set! type-args)
-  ;; 	(raise 'stop151)))
-  ;; (dwl3 (hfield-ref (hfield-ref param-class 'address) 'source-name))
-  ;; (if (is-t-type-variable? (car type-args))
-  ;;     (dwl3 (var-to-string (car type-args))))
-  ;; (if (= gl-counter13 23)
-  ;;     (begin
-  ;; 	(dvar1-set! binder)
-  ;; 	(dvar2-set! param-class)
-  ;; 	(dvar3-set! type-args)
-  ;; 	(dwl3 inside-param-def?)
-  ;; 	(dwl3 make-ctr?)
-  ;; 	(raise 'stop23)))
-
   (assert (is-binder? binder))
   (assert (is-target-object? param-class))
   (dvar1-set! type-args)
@@ -574,50 +533,24 @@
 	  (if regular?
 	      (tuple-type->list-reject-cycles type-arg-list)
 	      '())))
-    (dwli2 "translate-param-class-instance-expr/1")
-
-    ;; TO BE REMOVED
-    ;; (set! gl-ctr3 (+ gl-ctr3 1))
-    ;; (dwl4 gl-ctr3)
-    ;; (if (= gl-ctr3 21)
-    ;; 	(begin
-    ;; 	  (dwl4 regular?)
-    ;; 	  (dvar1-set! type-arg-list)
-    ;; 	  (raise 'r-stop)))
-
     (cond
      ((not regular?)
       (make-apti param-class type-args))
      (tuple?
-      (dwli2 "translate-param-class-instance-expr/2")
       (let ((type-params (tuple-type->list-reject-cycles type-arg-list)))
 	(cond
 	 ((hfield-ref param-class 'incomplete?)
-	  (dwli2 "translate-param-class-instance-expr/2-1")
 	  (make-apti param-class type-params))
 	 ;; We allow <none> as a value of a type parameters.
 	 ;; ((and (not-null? type-params)
 	 ;;       (or-map? entity-is-none? type-params))
 	 ;;  (raise 'invalid-use-of-none-1))
 	 (else
-	  (dwli2 "translate-param-class-instance-expr/3")	  
-	  (dwli2 make-ctr?)
-
-	  ;; TBR
-	  ;; (set! gl-ctr (+ gl-ctr 1))
-	  ;; (dwli2 gl-ctr)
-	  ;; (if (= gl-ctr 52)
-	  ;;     (begin
-	  ;; 	(dvar1-set! param-class)
-	  ;; 	(dvar2-set! type-params)
-	  ;; 	(raise 'stop52)))
-
 	  (let ((to
 		 (binder-get-instance-fwd
 		  binder param-class
 		  type-params
 		  make-ctr?)))
-	    (dwli2 "translate-param-class-instance-expr/4")
 	    ;; Not sure if it is necessary to make the constructor
 	    ;; here.
 	    ;; Procedure binder-get-instance contains code
@@ -634,7 +567,6 @@
 		 to))
 	    (if (not (hfield-ref to 'incomplete?))
 		(tno-field-set! to 'l-param-exprs type-params))
-	    (dwli2 "to HEP2")
 	    to)))))
      (else
       ;; This is logically impossible.
@@ -642,7 +574,6 @@
 
 
 (define (translate-param-sgn-instance-expr binder param-sgn type-args)
-  (dwl4 "translate-param-sgn-instance-expr")
   (assert (is-binder? binder))
   (assert (is-target-object? param-sgn))
   (assert (and (list? type-args)
@@ -676,24 +607,10 @@
 
 
 (define (translate-param-ltype-instance-expr binder param-ltype type-args)
-  (dwl2 "translate-param-ltype-instance-expr")
   (assert (is-binder? binder))
   (assert (is-target-object? param-ltype))
   (assert (and (list? type-args)
 	       (and-map? is-target-object? type-args)))
-
-  ;; TO BE REMOVED
-  ;; (dvar1-set! binder)
-  ;; (dvar2-set! param-ltype)
-  ;; (dvar3-set! type-args)
-  ;; (raise 'stop-plti)
-
-  (set! gl-counter17 (+ gl-counter17 1))
-  (dwl2 gl-counter17)
-  (dwl2 (hfield-ref (hfield-ref param-ltype 'address) 'source-name))
-  (if (is-t-type-variable? (car type-args))
-      (dwl3 (var-to-string (car type-args))))
-
   (let* ((type-arg-list (construct-toplevel-type-repr binder
 						      type-args))
 	 (tuple? (is-tuple-type? binder type-arg-list))
@@ -705,7 +622,6 @@
 	  (if tuple?
 	      (tuple-type->list-reject-cycles type-arg-list)
 	      type-args)))
-    (dwl3 "translate-param-ltype-instance-expr/1")
     (cond
      ((not regular?) (make-apti param-ltype type-args))
      (tuple?
@@ -730,26 +646,10 @@
 
 (define (translate-param-ltype-instance-expr2 binder param-ltype type-args
 					      visited)
-  (dwl3 "translate-param-ltype-instance-expr2")
   (assert (is-binder? binder))
   (assert (is-target-object? param-ltype))
   (assert (and (list? type-args)
 	       (and-map? is-target-object? type-args)))
-
-  ;; TBR
-  (set! gl-counter17 (+ gl-counter17 1))
-  (dwl3 gl-counter17)
-  (dwl3 (hfield-ref (hfield-ref param-ltype 'address) 'source-name))
-  (if (is-t-type-variable? (car type-args))
-      (dwl3 (var-to-string (car type-args))))
-  ;; (if (= gl-counter17 2)
-  ;;     (begin
-  ;; 	(dvar1-set! binder)
-  ;; 	(dvar2-set! param-ltype)
-  ;; 	(dvar3-set! type-args)
-  ;; 	(dvar4-set! visited)
-  ;; 	(raise 'stop2)))
-
   (let* ((type-arg-list (construct-toplevel-type-repr binder
 						      type-args))
 	 (tuple? (is-tuple-type? binder type-arg-list))
@@ -761,7 +661,6 @@
 	  (if regular?
 	      (tuple-type->list-reject-cycles type-arg-list)
 	      '())))
-    (dwl3 "translate-param-ltype-instance-expr2/1")
     (cond
      ((not regular?) (cons (make-apti param-ltype type-args) '()))
      (tuple?
@@ -789,26 +688,10 @@
 
 (define (translate-param-ltype-instance-expr3 binder param-ltype type-args
 					      visited)
-  (dwli "translate-param-ltype-instance-expr3")
   (assert (is-binder? binder))
   (assert (is-target-object? param-ltype))
   (assert (and (list? type-args)
 	       (and-map? is-target-object? type-args)))
-
-  ;; TBR
-  (set! gl-counter17 (+ gl-counter17 1))
-  (dwli gl-counter17)
-  (dwli (hfield-ref (hfield-ref param-ltype 'address) 'source-name))
-  (if (is-t-type-variable? (car type-args))
-      (dwl3 (var-to-string (car type-args))))
-  ;; (if (= gl-counter17 2)
-  ;;     (begin
-  ;; 	(dvar1-set! binder)
-  ;; 	(dvar2-set! param-ltype)
-  ;; 	(dvar3-set! type-args)
-  ;; 	(dvar4-set! visited)
-  ;; 	(raise 'stop2)))
-
   (let* ((type-arg-list (construct-toplevel-type-repr binder
 						      type-args))
 	 (tuple? (is-tuple-type? binder type-arg-list))
@@ -820,7 +703,6 @@
 	  (if regular?
 	      (tuple-type->list-reject-cycles type-arg-list)
 	      '())))
-    (dwli "translate-param-ltype-instance-expr3/1")
     (cond
      ((and
        (eq? param-ltype tmt-union)
@@ -831,11 +713,6 @@
       (let ((tt-param
 	     (get-uniform-list-param
 	      binder (tno-field-ref (car type-args) 'type-component))))
-	
-	;; TBR
-;;	(dvar1-set! tt-param)
-;;	(raise 'stop-param)
-
 	(cons tt-param '())))
      ((not regular?) (cons (make-apti param-ltype type-args) '()))
      (tuple?
@@ -843,9 +720,6 @@
        ((let* ((param-cache (hfield-ref binder 'param-cache))
 	       (binding (param-cache-fetch param-cache
 					   param-ltype type-params)))
-	  (dwli "translate-param-ltype-instance-expr3/2")
-;;	  (set! gl-counter18 (+ gl-counter18 1))
-;;	  (dwli gl-counter18)
 	  binding)
 	=>
 	(lambda (pr1)
@@ -858,7 +732,6 @@
        ((eq? param-ltype tmt-union)
 	(cons (get-union-of-types0-fwd binder type-params) '()))
        (else
-	(dwli "translate-param-ltype-instance-expr3/3")
 	(let ((tvars (tno-field-ref param-ltype 'l-tvars)))
 	  (if (not (= (length tvars) (length type-params)))
 	      (raise 'invalid-number-of-type-parameters))
@@ -896,7 +769,6 @@
 ;; If any of the types is none return none.
 
 (define (get-union-of-types0 binder types)
-  (dwl4 "get-union-of-types0")
   (assert (is-binder? binder))
   ;; and-map? returns #t on empty argument list.
   (assert (and (list? types)
@@ -945,17 +817,7 @@
 
 
 (define (get-union-of-types binder args)
-  (dwl4 "get-union-of-types ENTER")
   (assert (is-binder? binder))
-
-  ;; TO BE REMOVED
-  ;; (dvar1-set! binder)
-  ;; (dvar2-set! args)
-  ;; (set! gl-ctr (+ gl-ctr 1))
-  ;; (dwl4 gl-ctr)
-  ;; (if (= gl-ctr 6)
-  ;;     (raise 'stop-6))
-
   (let ((arg-list (construct-toplevel-type-repr
 		    binder
 		    args)))
@@ -972,7 +834,4 @@
 		    (get-union-of-types0 binder
 					 params)
 		    (make-irregular-union args))))
-	  (dwl4 "get-union-of-types EXIT")
 	  result))))
-
-
