@@ -225,7 +225,9 @@ See `run-hooks'."
 		   "\\|\\(define-param-class\\)"
 		   "\\|\\(define-param-logical-type\\)"
 		   "\\|\\(define-simple-method\\)"
+		   "\\|\\(define-static-simple-method\\)"
 		   "\\|\\(define-param-method\\)"
+		   "\\|\\(define-static-param-method\\)"
 		   "\\|\\(define-generic-proc\\)"
 		   "\\|\\(define-simple-proc\\)"
 		   "\\|\\(define-param-proc\\)"
@@ -242,9 +244,11 @@ See `run-hooks'."
 		   "\\|\\(define-syntax\\)"
 		   "\\|\\(declare\\)"
 		   "\\|\\(declare-method\\)"
+		   "\\|\\(declare-static-method\\)"
 		   "\\|\\(declare-mutable\\)"
 		   "\\|\\(declare-volatile\\)"
-		   "\\|\\(add-method\\)\\)"
+		   "\\|\\(add-method\\)"
+		   "\\|\\(add-static-method\\)\\)"
 		   "\\>"
 		   ;; Any whitespace and declared object.
 		   "[ \t]*(?"
@@ -294,12 +298,19 @@ See `run-hooks'."
 	       "do" "else"
 	       "exec/cc"
 	       "execute-with-current-continuation"
+	       "exec/cc-nonpure"
+	       "execute-with-current-continuation-nonpure"
+	       "exec/cc-without-result"
+	       "execute-with-current-continuation-without-result"
 	       "field-set!" "field-ref"
 ;;	       "force"
 	       "force-pure-expr"
 	       "generic-proc-dispatch"
 	       "generic-proc-dispatch-without-result"
-	       "guard" "guard-general" "if"
+	       "guard" "guard-general"
+	       "guard-nonpure" "guard-general-nonpure"
+	       "guard-without-result" "guard-general-without-result"
+	       "if"
 	       "import" "import-and-reexport"
 	       "join-tuple-types"
 	       "lambda"
